package java.awt;

import java.awt.GraphicsCallback.PeerPaintCallback;
import java.awt.GraphicsCallback.PeerPrintCallback;
import java.awt.dnd.DropTarget;
import java.awt.event.ComponentEvent;
import java.awt.event.ComponentListener;
import java.awt.event.FocusEvent;
import java.awt.event.FocusListener;
import java.awt.event.HierarchyBoundsListener;
import java.awt.event.HierarchyEvent;
import java.awt.event.HierarchyListener;
import java.awt.event.InputEvent;
import java.awt.event.InputMethodEvent;
import java.awt.event.InputMethodListener;
import java.awt.event.KeyEvent;
import java.awt.event.KeyListener;
import java.awt.event.MouseEvent;
import java.awt.event.MouseListener;
import java.awt.event.MouseMotionListener;
import java.awt.event.PaintEvent;
import java.awt.event.WindowEvent;
import java.awt.im.InputContext;
import java.awt.im.InputMethodRequests;
import java.awt.image.ColorModel;
import java.awt.image.ImageObserver;
import java.awt.image.ImageProducer;
import java.awt.peer.ComponentPeer;
import java.awt.peer.LightweightPeer;
import java.beans.PropertyChangeListener;
import java.beans.PropertyChangeSupport;
import java.io.IOException;
import java.io.ObjectInputStream;
import java.io.ObjectOutputStream;
import java.io.OptionalDataException;
import java.io.PrintStream;
import java.io.PrintWriter;
import java.io.Serializable;
import java.security.AccessController;
import java.util.EventListener;
import java.util.Hashtable;
import java.util.Locale;
import java.util.Vector;
import javax.accessibility.Accessible;
import javax.accessibility.AccessibleContext;
import javax.accessibility.AccessibleSelection;
import javax.accessibility.AccessibleState;
import javax.accessibility.AccessibleStateSet;
import javax.swing.JComponent;
import sun.awt.AppContext;
import sun.awt.ConstrainableGraphics;
import sun.awt.DebugHelper;
import sun.awt.GlobalCursorManager;
import sun.awt.SunToolkit;
import sun.awt.WindowClosingListener;
import sun.awt.im.CompositionArea;
import sun.java2d.loops.RasterOutputManager;
import sun.security.action.GetPropertyAction;

public abstract class Component implements ImageObserver, MenuContainer, Serializable {
   transient ComponentPeer peer;
   transient Container parent;
   transient AppContext appContext;
   // $FF: renamed from: x int
   int field_0;
   // $FF: renamed from: y int
   int field_1;
   int width;
   int height;
   Color foreground;
   Color background;
   Font font;
   Font peerFont;
   Cursor cursor;
   Locale locale;
   transient GraphicsConfiguration graphicsConfig = null;
   boolean visible = true;
   boolean enabled = true;
   boolean valid = false;
   DropTarget dropTarget;
   boolean hasFocus = false;
   Vector popups;
   private String name;
   private boolean nameExplicitlySet = false;
   static final Object LOCK = new AWTTreeLock();
   Dimension minSize;
   Dimension prefSize;
   transient ComponentOrientation componentOrientation;
   boolean newEventsOnly;
   transient ComponentListener componentListener;
   transient FocusListener focusListener;
   transient HierarchyListener hierarchyListener;
   transient HierarchyBoundsListener hierarchyBoundsListener;
   transient KeyListener keyListener;
   transient MouseListener mouseListener;
   transient MouseMotionListener mouseMotionListener;
   transient InputMethodListener inputMethodListener;
   transient RuntimeException windowClosingException;
   static final String actionListenerK = "actionL";
   static final String adjustmentListenerK = "adjustmentL";
   static final String componentListenerK = "componentL";
   static final String containerListenerK = "containerL";
   static final String focusListenerK = "focusL";
   static final String itemListenerK = "itemL";
   static final String keyListenerK = "keyL";
   static final String mouseListenerK = "mouseL";
   static final String mouseMotionListenerK = "mouseMotionL";
   static final String textListenerK = "textL";
   static final String ownedWindowK = "ownedL";
   static final String windowListenerK = "windowL";
   static final String inputMethodListenerK = "inputMethodL";
   static final String hierarchyListenerK = "hierarchyL";
   static final String hierarchyBoundsListenerK = "hierarchyBoundsL";
   long eventMask;
   private static final DebugHelper dbg;
   static boolean isInc;
   static int incRate;
   public static final float TOP_ALIGNMENT = 0.0F;
   public static final float CENTER_ALIGNMENT = 0.5F;
   public static final float BOTTOM_ALIGNMENT = 1.0F;
   public static final float LEFT_ALIGNMENT = 0.0F;
   public static final float RIGHT_ALIGNMENT = 1.0F;
   private static final long serialVersionUID = -7644114512714619750L;
   private PropertyChangeSupport changeSupport;
   boolean isPacked;
   private transient Object privateKey;
   static Hashtable metrics;
   private int componentSerializedDataVersion;
   AccessibleContext accessibleContext;
   // $FF: synthetic field
   static Class class$java$awt$Component;
   // $FF: synthetic field
   static Class class$java$awt$event$ComponentListener;
   // $FF: synthetic field
   static Class class$java$awt$event$FocusListener;
   // $FF: synthetic field
   static Class class$java$awt$event$HierarchyListener;
   // $FF: synthetic field
   static Class class$java$awt$event$HierarchyBoundsListener;
   // $FF: synthetic field
   static Class class$java$awt$event$KeyListener;
   // $FF: synthetic field
   static Class class$java$awt$event$MouseListener;
   // $FF: synthetic field
   static Class class$java$awt$event$MouseMotionListener;
   // $FF: synthetic field
   static Class class$java$awt$event$InputMethodListener;

   protected Component() {
      this.componentOrientation = ComponentOrientation.UNKNOWN;
      this.newEventsOnly = false;
      this.windowClosingException = null;
      this.eventMask = 4096L;
      this.isPacked = false;
      this.privateKey = new Object();
      this.componentSerializedDataVersion = 3;
      this.accessibleContext = null;
      this.appContext = AppContext.getAppContext();
      SunToolkit.insertTargetMapping(this, this.appContext);
   }

   String constructComponentName() {
      return null;
   }

   public String getName() {
      if (this.name == null && !this.nameExplicitlySet) {
         synchronized(this) {
            if (this.name == null && !this.nameExplicitlySet) {
               this.name = this.constructComponentName();
            }
         }
      }

      return this.name;
   }

   public void setName(String var1) {
      synchronized(this) {
         this.name = var1;
         this.nameExplicitlySet = true;
      }
   }

   public Container getParent() {
      return this.getParent_NoClientCode();
   }

   final Container getParent_NoClientCode() {
      return this.parent;
   }

   public ComponentPeer getPeer() {
      return this.peer;
   }

   public synchronized void setDropTarget(DropTarget var1) {
      if (var1 != this.dropTarget && (this.dropTarget == null || !this.dropTarget.equals(var1))) {
         DropTarget var2;
         if ((var2 = this.dropTarget) != null) {
            if (this.peer != null) {
               this.dropTarget.removeNotify(this.peer);
            }

            DropTarget var3 = this.dropTarget;
            this.dropTarget = null;

            try {
               var3.setComponent((Component)null);
            } catch (IllegalArgumentException var6) {
            }
         }

         if ((this.dropTarget = var1) != null) {
            try {
               this.dropTarget.setComponent(this);
               if (this.peer != null) {
                  this.dropTarget.addNotify(this.peer);
               }
            } catch (IllegalArgumentException var7) {
               if (var2 != null) {
                  try {
                     var2.setComponent(this);
                     if (this.peer != null) {
                        this.dropTarget.addNotify(this.peer);
                     }
                  } catch (IllegalArgumentException var5) {
                  }
               }
            }
         }

      }
   }

   public synchronized DropTarget getDropTarget() {
      return this.dropTarget;
   }

   public GraphicsConfiguration getGraphicsConfiguration() {
      Object var1 = this.getTreeLock();
      synchronized(var1) {
         if (this.graphicsConfig != null) {
            GraphicsConfiguration var6 = this.graphicsConfig;
            return var6;
         } else if (this.getParent() != null) {
            GraphicsConfiguration var5 = this.getParent().getGraphicsConfiguration();
            return var5;
         } else {
            Object var2 = null;
            return (GraphicsConfiguration)var2;
         }
      }
   }

   void resetGC() {
      Object var1 = this.getTreeLock();
      synchronized(var1) {
         this.graphicsConfig = null;
      }
   }

   void checkGD(String var1) {
      if (this.graphicsConfig != null && !this.graphicsConfig.getDevice().getIDstring().equals(var1)) {
         throw new IllegalArgumentException("adding a container to a container on a different GraphicsDevice");
      }
   }

   public final Object getTreeLock() {
      return LOCK;
   }

   public Toolkit getToolkit() {
      return this.getToolkitImpl();
   }

   final Toolkit getToolkitImpl() {
      ComponentPeer var1 = this.peer;
      if (var1 != null && !(var1 instanceof LightweightPeer)) {
         return var1.getToolkit();
      } else {
         Container var2 = this.parent;
         return var2 != null ? ((Component)var2).getToolkitImpl() : Toolkit.getDefaultToolkit();
      }
   }

   public boolean isValid() {
      return this.peer != null && this.valid;
   }

   public boolean isDisplayable() {
      return this.getPeer() != null;
   }

   public boolean isVisible() {
      return this.visible;
   }

   boolean isRecursivelyVisible() {
      return this.visible && (this.parent == null || this.parent.isRecursivelyVisible());
   }

   public boolean isShowing() {
      if (this.visible && this.peer != null) {
         Container var1 = this.parent;
         return var1 == null || ((Component)var1).isShowing();
      } else {
         return false;
      }
   }

   public boolean isEnabled() {
      return this.isEnabledImpl();
   }

   final boolean isEnabledImpl() {
      return this.enabled;
   }

   public void setEnabled(boolean var1) {
      this.enable(var1);
   }

   public void enable() {
      if (!this.enabled) {
         Object var1 = this.getTreeLock();
         synchronized(var1) {
            this.enabled = true;
            ComponentPeer var2 = this.peer;
            if (var2 != null) {
               var2.enable();
               if (this.visible) {
                  GlobalCursorManager.updateCursorImmediately();
               }
            }
         }

         if (this.accessibleContext != null) {
            this.accessibleContext.firePropertyChange("AccessibleState", (Object)null, AccessibleState.ENABLED);
         }
      }

   }

   public void enable(boolean var1) {
      if (var1) {
         this.enable();
      } else {
         this.disable();
      }

   }

   public void disable() {
      if (this.enabled) {
         Object var1 = this.getTreeLock();
         synchronized(var1) {
            this.enabled = false;
            ComponentPeer var2 = this.peer;
            if (var2 != null) {
               var2.disable();
               if (this.visible) {
                  GlobalCursorManager.updateCursorImmediately();
               }
            }
         }

         if (this.accessibleContext != null) {
            this.accessibleContext.firePropertyChange("AccessibleState", (Object)null, AccessibleState.ENABLED);
         }
      }

   }

   public boolean isDoubleBuffered() {
      return false;
   }

   public void enableInputMethods(boolean var1) {
      if (var1) {
         if ((this.eventMask & 4096L) != 0L) {
            return;
         }

         if (this.hasFocus()) {
            InputContext var2 = this.getInputContext();
            if (var2 != null) {
               FocusEvent var3 = new FocusEvent(this, 1004);
               var2.dispatchEvent(var3);
            }
         }

         this.eventMask |= 4096L;
      } else {
         if (this.areInputMethodsEnabled()) {
            InputContext var4 = this.getInputContext();
            if (var4 != null) {
               var4.endComposition();
               var4.removeNotify(this);
            }
         }

         this.eventMask &= -4097L;
      }

   }

   public void setVisible(boolean var1) {
      this.show(var1);
   }

   public void show() {
      if (!this.visible) {
         Object var1 = this.getTreeLock();
         synchronized(var1) {
            this.visible = true;
            ComponentPeer var2 = this.peer;
            if (var2 != null) {
               var2.show();
               this.createHierarchyEvents(1400, this, this.parent, 4L);
               if (var2 instanceof LightweightPeer) {
                  this.repaint();
               }

               GlobalCursorManager.updateCursorImmediately();
            }

            if (this.componentListener != null || (this.eventMask & 1L) != 0L) {
               ComponentEvent var3 = new ComponentEvent(this, 102);
               Toolkit.getEventQueue().postEvent(var3);
            }
         }

         Container var6 = this.parent;
         if (var6 != null) {
            var6.invalidate();
         }
      }

   }

   public void show(boolean var1) {
      if (var1) {
         this.show();
      } else {
         this.hide();
      }

   }

   public void hide() {
      if (this.visible) {
         Object var1 = this.getTreeLock();
         synchronized(var1) {
            this.visible = false;
            ComponentPeer var2 = this.peer;
            if (var2 != null) {
               var2.hide();
               this.createHierarchyEvents(1400, this, this.parent, 4L);
               if (var2 instanceof LightweightPeer) {
                  this.repaint();
               }

               GlobalCursorManager.updateCursorImmediately();
            }

            if (this.componentListener != null || (this.eventMask & 1L) != 0L) {
               ComponentEvent var3 = new ComponentEvent(this, 103);
               Toolkit.getEventQueue().postEvent(var3);
            }
         }

         Container var6 = this.parent;
         if (var6 != null) {
            var6.invalidate();
         }
      }

   }

   public Color getForeground() {
      Color var1 = this.foreground;
      if (var1 != null) {
         return var1;
      } else {
         Container var2 = this.parent;
         return var2 != null ? ((Component)var2).getForeground() : null;
      }
   }

   public void setForeground(Color var1) {
      Color var2 = this.foreground;
      ComponentPeer var3 = this.peer;
      this.foreground = var1;
      if (var3 != null) {
         var1 = this.getForeground();
         if (var1 != null) {
            var3.setForeground(var1);
         }
      }

      this.firePropertyChange("foreground", var2, var1);
   }

   public Color getBackground() {
      Color var1 = this.background;
      if (var1 != null) {
         return var1;
      } else {
         Container var2 = this.parent;
         return var2 != null ? ((Component)var2).getBackground() : null;
      }
   }

   public void setBackground(Color var1) {
      Color var2 = this.background;
      ComponentPeer var3 = this.peer;
      this.background = var1;
      if (var3 != null) {
         var1 = this.getBackground();
         if (var1 != null) {
            var3.setBackground(var1);
         }
      }

      this.firePropertyChange("background", var2, var1);
   }

   public Font getFont() {
      return this.getFont_NoClientCode();
   }

   final Font getFont_NoClientCode() {
      Font var1 = this.font;
      if (var1 != null) {
         return var1;
      } else {
         Container var2 = this.parent;
         return var2 != null ? ((Component)var2).getFont_NoClientCode() : null;
      }
   }

   public void setFont(Font var1) {
      Font var2;
      Font var3;
      synchronized(this) {
         var2 = this.font;
         ComponentPeer var5 = this.peer;
         var3 = this.font = var1;
         if (var5 != null) {
            var1 = this.getFont();
            if (var1 != null) {
               var5.setFont(var1);
               this.peerFont = var1;
            }
         }
      }

      this.firePropertyChange("font", var2, var3);
      if (this.valid) {
         this.invalidate();
      }

   }

   public Locale getLocale() {
      Locale var1 = this.locale;
      if (var1 != null) {
         return var1;
      } else {
         Container var2 = this.parent;
         if (var2 == null) {
            throw new IllegalComponentStateException("This component must have a parent in order to determine its locale");
         } else {
            return ((Component)var2).getLocale();
         }
      }
   }

   public void setLocale(Locale var1) {
      this.locale = var1;
      if (this.valid) {
         this.invalidate();
      }

   }

   public ColorModel getColorModel() {
      ComponentPeer var1 = this.peer;
      return var1 != null && !(var1 instanceof LightweightPeer) ? var1.getColorModel() : this.getToolkit().getColorModel();
   }

   public Point getLocation() {
      return this.location();
   }

   public Point getLocationOnScreen() {
      Object var1 = this.getTreeLock();
      synchronized(var1) {
         Point var2 = this.getLocationOnScreen_NoTreeLock();
         return var2;
      }
   }

   final Point getLocationOnScreen_NoTreeLock() {
      if (this.peer != null && this.isShowing()) {
         if (!(this.peer instanceof LightweightPeer)) {
            Point var4 = this.peer.getLocationOnScreen();
            return var4;
         } else {
            Container var1 = this.getNativeContainer();
            Point var2 = var1.peer.getLocationOnScreen();

            for(Object var3 = this; var3 != var1; var3 = ((Component)var3).getParent()) {
               var2.x += ((Component)var3).field_0;
               var2.y += ((Component)var3).field_1;
            }

            return var2;
         }
      } else {
         throw new IllegalComponentStateException("component must be showing on the screen to determine its location");
      }
   }

   public Point location() {
      return new Point(this.field_0, this.field_1);
   }

   public void setLocation(int var1, int var2) {
      this.move(var1, var2);
   }

   public void move(int var1, int var2) {
      this.setBounds(var1, var2, this.width, this.height);
   }

   public void setLocation(Point var1) {
      this.setLocation(var1.x, var1.y);
   }

   public Dimension getSize() {
      return this.size();
   }

   public Dimension size() {
      return new Dimension(this.width, this.height);
   }

   public void setSize(int var1, int var2) {
      this.resize(var1, var2);
   }

   public void resize(int var1, int var2) {
      this.setBounds(this.field_0, this.field_1, var1, var2);
   }

   public void setSize(Dimension var1) {
      this.resize(var1);
   }

   public void resize(Dimension var1) {
      this.setSize(var1.width, var1.height);
   }

   public Rectangle getBounds() {
      return this.bounds();
   }

   public Rectangle bounds() {
      return new Rectangle(this.field_0, this.field_1, this.width, this.height);
   }

   public void setBounds(int var1, int var2, int var3, int var4) {
      this.reshape(var1, var2, var3, var4);
   }

   public void reshape(int var1, int var2, int var3, int var4) {
      Object var5 = this.getTreeLock();
      synchronized(var5) {
         boolean var6 = this.width != var3 || this.height != var4;
         boolean var7 = this.field_0 != var1 || this.field_1 != var2;
         boolean var8 = this.peer instanceof LightweightPeer;
         if (var6) {
            this.isPacked = false;
         }

         if (var6 || var7) {
            if (var8 && this.visible) {
               this.repaint();
            }

            this.field_0 = var1;
            this.field_1 = var2;
            this.width = var3;
            this.height = var4;
            if (this.peer != null) {
               if (var8) {
                  this.peer.setBounds(var1, var2, var3, var4);
               } else {
                  int var9 = var1;
                  int var10 = var2;

                  for(Container var11 = this.parent; var11 != null && var11.peer instanceof LightweightPeer; var11 = var11.parent) {
                     var9 += var11.field_0;
                     var10 += var11.field_1;
                  }

                  this.peer.setBounds(var9, var10, var3, var4);
               }

               if (var6) {
                  this.invalidate();
               }

               if (this.parent != null && this.parent.valid) {
                  this.parent.invalidate();
               }
            }

            if (var6) {
               if (this.componentListener == null && (this.eventMask & 1L) == 0L) {
                  this.createChildHierarchyEvents(1402, 0L);
               } else {
                  ComponentEvent var14 = new ComponentEvent(this, 101);
                  Toolkit.getEventQueue().postEvent(var14);
               }
            }

            if (var7) {
               if (this.componentListener == null && (this.eventMask & 1L) == 0L) {
                  this.createChildHierarchyEvents(1401, 0L);
               } else {
                  ComponentEvent var15 = new ComponentEvent(this, 100);
                  Toolkit.getEventQueue().postEvent(var15);
               }
            }

            if (var8 && this.visible) {
               this.repaint();
            }
         }

      }
   }

   public void setBounds(Rectangle var1) {
      this.setBounds(var1.x, var1.y, var1.width, var1.height);
   }

   public int getX() {
      return this.field_0;
   }

   public int getY() {
      return this.field_1;
   }

   public int getWidth() {
      return this.width;
   }

   public int getHeight() {
      return this.height;
   }

   public Rectangle getBounds(Rectangle var1) {
      if (var1 == null) {
         return new Rectangle(this.getX(), this.getY(), this.getWidth(), this.getHeight());
      } else {
         var1.setBounds(this.getX(), this.getY(), this.getWidth(), this.getHeight());
         return var1;
      }
   }

   public Dimension getSize(Dimension var1) {
      if (var1 == null) {
         return new Dimension(this.getWidth(), this.getHeight());
      } else {
         var1.setSize(this.getWidth(), this.getHeight());
         return var1;
      }
   }

   public Point getLocation(Point var1) {
      if (var1 == null) {
         return new Point(this.getX(), this.getY());
      } else {
         var1.setLocation(this.getX(), this.getY());
         return var1;
      }
   }

   public boolean isOpaque() {
      return !this.isLightweight();
   }

   public boolean isLightweight() {
      return this.getPeer() instanceof LightweightPeer;
   }

   public Dimension getPreferredSize() {
      return this.preferredSize();
   }

   public Dimension preferredSize() {
      Dimension var1 = this.prefSize;
      if (var1 != null && this.isValid()) {
         return var1;
      } else {
         Object var2 = this.getTreeLock();
         synchronized(var2) {
            this.prefSize = this.peer != null ? this.peer.preferredSize() : this.getMinimumSize();
            Dimension var3 = this.prefSize;
            return var3;
         }
      }
   }

   public Dimension getMinimumSize() {
      return this.minimumSize();
   }

   public Dimension minimumSize() {
      Dimension var1 = this.minSize;
      if (var1 != null && this.isValid()) {
         return var1;
      } else {
         Object var2 = this.getTreeLock();
         synchronized(var2) {
            this.minSize = this.peer != null ? this.peer.minimumSize() : this.size();
            Dimension var3 = this.minSize;
            return var3;
         }
      }
   }

   public Dimension getMaximumSize() {
      return new Dimension(32767, 32767);
   }

   public float getAlignmentX() {
      return 0.5F;
   }

   public float getAlignmentY() {
      return 0.5F;
   }

   public void doLayout() {
      this.layout();
   }

   public void layout() {
   }

   public void validate() {
      if (!this.valid) {
         Object var1 = this.getTreeLock();
         synchronized(var1) {
            ComponentPeer var2 = this.peer;
            if (!this.valid && var2 != null) {
               Font var3 = this.getFont();
               Font var4 = this.peerFont;
               if (var3 != var4 && (var4 == null || !var4.equals(var3))) {
                  var2.setFont(var3);
                  this.peerFont = var3;
               }
            }
         }

         this.valid = true;
      }

   }

   public void invalidate() {
      Object var1 = this.getTreeLock();
      synchronized(var1) {
         this.valid = false;
         this.prefSize = null;
         this.minSize = null;
         if (this.parent != null && this.parent.valid) {
            this.parent.invalidate();
         }

      }
   }

   public Graphics getGraphics() {
      if (this.peer instanceof LightweightPeer) {
         if (this.parent == null) {
            return null;
         } else {
            Graphics var2 = this.parent.getGraphics();
            if (var2 == null) {
               return null;
            } else {
               if (var2 instanceof ConstrainableGraphics) {
                  ((ConstrainableGraphics)var2).constrain(this.field_0, this.field_1, this.width, this.height);
               } else {
                  var2.translate(this.field_0, this.field_1);
                  var2.setClip(0, 0, this.width, this.height);
               }

               var2.setFont(this.getFont());
               return var2;
            }
         }
      } else {
         ComponentPeer var1 = this.peer;
         return var1 != null ? var1.getGraphics() : null;
      }
   }

   public FontMetrics getFontMetrics(Font var1) {
      FontMetrics var2 = (FontMetrics)metrics.get(var1);
      if (var2 != null) {
         return var2;
      } else if (RasterOutputManager.usesPlatformFont() && this.peer != null && !(this.peer instanceof LightweightPeer)) {
         var2 = this.peer.getFontMetrics(var1);
         metrics.put(var1, var2);
         return var2;
      } else {
         if (this.parent != null) {
            Graphics var3 = this.parent.getGraphics();
            if (var3 != null) {
               FontMetrics var4;
               try {
                  var2 = var3.getFontMetrics(var1);
                  metrics.put(var1, var2);
                  var4 = var2;
               } finally {
                  var3.dispose();
               }

               return var4;
            }
         }

         var2 = this.getToolkit().getFontMetrics(var1);
         metrics.put(var1, var2);
         return var2;
      }
   }

   public void setCursor(Cursor var1) {
      this.cursor = var1;
      if (this.peer != null) {
         GlobalCursorManager.updateCursorImmediately();
      }

   }

   public Cursor getCursor() {
      Cursor var1 = this.cursor;
      if (var1 != null) {
         return var1;
      } else {
         Container var2 = this.parent;
         return var2 != null ? ((Component)var2).getCursor() : Cursor.getPredefinedCursor(0);
      }
   }

   public void paint(Graphics var1) {
   }

   public void update(Graphics var1) {
      if (this instanceof Canvas || this instanceof Panel || this instanceof Frame || this instanceof Dialog || this instanceof Window) {
         var1.clearRect(0, 0, this.width, this.height);
      }

      this.paint(var1);
   }

   public void paintAll(Graphics var1) {
      if (this.isShowing()) {
         PeerPaintCallback.getInstance().runOneComponent(this, new Rectangle(0, 0, this.width, this.height), var1, var1.getClip(), 3);
      }

   }

   void lightweightPaint(Graphics var1) {
      this.paint(var1);
   }

   void paintHeavyweightComponents(Graphics var1) {
   }

   public void repaint() {
      this.repaint(0L, 0, 0, this.width, this.height);
   }

   public void repaint(long var1) {
      this.repaint(var1, 0, 0, this.width, this.height);
   }

   public void repaint(int var1, int var2, int var3, int var4) {
      this.repaint(0L, var1, var2, var3, var4);
   }

   public void repaint(long var1, int var3, int var4, int var5, int var6) {
      if (this.peer instanceof LightweightPeer) {
         if (this.parent != null) {
            int var7 = this.field_0 + (var3 < 0 ? 0 : var3);
            int var8 = this.field_1 + (var4 < 0 ? 0 : var4);
            int var9 = var5 > this.width ? this.width : var5;
            int var10 = var6 > this.height ? this.height : var6;
            this.parent.repaint(var1, var7, var8, var9, var10);
         }
      } else {
         if (!this.isVisible()) {
            return;
         }

         ComponentPeer var11 = this.peer;
         if (var11 != null && var5 > 0 && var6 > 0) {
            var11.repaint(var1, var3, var4, var5, var6);
         }
      }

   }

   public void print(Graphics var1) {
      this.paint(var1);
   }

   public void printAll(Graphics var1) {
      if (this.isShowing()) {
         PeerPrintCallback.getInstance().runOneComponent(this, new Rectangle(0, 0, this.width, this.height), var1, var1.getClip(), 3);
      }

   }

   void lightweightPrint(Graphics var1) {
      this.print(var1);
   }

   void printHeavyweightComponents(Graphics var1) {
   }

   public boolean imageUpdate(Image var1, int var2, int var3, int var4, int var5, int var6) {
      int var7 = -1;
      if ((var2 & 48) != 0) {
         var7 = 0;
      } else if ((var2 & 8) != 0 && isInc) {
         try {
            var7 = incRate;
            if (var7 < 0) {
               var7 = 0;
            }
         } catch (Exception var9) {
            var7 = 100;
         }
      }

      if (var7 >= 0) {
         this.repaint((long)var7, 0, 0, this.width, this.height);
      }

      return (var2 & 160) == 0;
   }

   public Image createImage(ImageProducer var1) {
      ComponentPeer var2 = this.peer;
      return var2 != null && !(var2 instanceof LightweightPeer) ? var2.createImage(var1) : this.getToolkit().createImage(var1);
   }

   public Image createImage(int var1, int var2) {
      ComponentPeer var3 = this.peer;
      if (var3 instanceof LightweightPeer) {
         return this.parent != null ? this.parent.createImage(var1, var2) : null;
      } else {
         return var3 != null ? var3.createImage(var1, var2) : null;
      }
   }

   public boolean prepareImage(Image var1, ImageObserver var2) {
      return this.prepareImage(var1, -1, -1, var2);
   }

   public boolean prepareImage(Image var1, int var2, int var3, ImageObserver var4) {
      ComponentPeer var5 = this.peer;
      if (var5 instanceof LightweightPeer) {
         return this.parent != null ? this.parent.prepareImage(var1, var2, var3, var4) : this.getToolkit().prepareImage(var1, var2, var3, var4);
      } else {
         return var5 != null ? var5.prepareImage(var1, var2, var3, var4) : this.getToolkit().prepareImage(var1, var2, var3, var4);
      }
   }

   public int checkImage(Image var1, ImageObserver var2) {
      return this.checkImage(var1, -1, -1, var2);
   }

   public int checkImage(Image var1, int var2, int var3, ImageObserver var4) {
      ComponentPeer var5 = this.peer;
      if (var5 instanceof LightweightPeer) {
         return this.parent != null ? this.parent.checkImage(var1, var2, var3, var4) : this.getToolkit().checkImage(var1, var2, var3, var4);
      } else {
         return var5 != null ? var5.checkImage(var1, var2, var3, var4) : this.getToolkit().checkImage(var1, var2, var3, var4);
      }
   }

   public boolean contains(int var1, int var2) {
      return this.inside(var1, var2);
   }

   public boolean inside(int var1, int var2) {
      return var1 >= 0 && var1 < this.width && var2 >= 0 && var2 < this.height;
   }

   public boolean contains(Point var1) {
      return this.contains(var1.x, var1.y);
   }

   public Component getComponentAt(int var1, int var2) {
      return this.locate(var1, var2);
   }

   public Component locate(int var1, int var2) {
      return this.contains(var1, var2) ? this : null;
   }

   public Component getComponentAt(Point var1) {
      return this.getComponentAt(var1.x, var1.y);
   }

   public void deliverEvent(Event var1) {
      this.postEvent(var1);
   }

   public final void dispatchEvent(AWTEvent var1) {
      this.dispatchEventImpl(var1);
   }

   void dispatchEventImpl(AWTEvent var1) {
      int var2 = var1.getID();
      Toolkit var3 = Toolkit.getDefaultToolkit();
      var3.notifyAWTEventListeners(var1);
      if (this.areInputMethodsEnabled() && (var1 instanceof InputMethodEvent && !(this instanceof CompositionArea) || var1 instanceof InputEvent || var1 instanceof FocusEvent)) {
         InputContext var4 = this.getInputContext();
         if (var4 != null) {
            var4.dispatchEvent(var1);
            if (var1.isConsumed()) {
               return;
            }
         }
      }

      switch (var2) {
         case 201:
            if (var3 instanceof WindowClosingListener) {
               this.windowClosingException = ((WindowClosingListener)var3).windowClosingNotify((WindowEvent)var1);
               if (this.checkWindowClosingException()) {
                  return;
               }
            }
            break;
         case 401:
         case 402:
            Container var8 = (Container)(this instanceof Container ? this : this.parent);
            if (var8 != null) {
               var8.preProcessKeyEvent((KeyEvent)var1);
               if (var1.isConsumed()) {
                  return;
               }
            }
            break;
         case 1004:
            if (this.parent != null && !(this instanceof Window)) {
               this.parent.setFocusOwner(this);
            }
         case 1005:
      }

      if (this.newEventsOnly) {
         if (this.eventEnabled(var1)) {
            this.processEvent(var1);
         }
      } else if (!(var1 instanceof MouseEvent) || this.postsOldMouseEvents()) {
         Event var5 = var1.convertToOld();
         if (var5 != null) {
            int var6 = var5.key;
            int var7 = var5.modifiers;
            this.postEvent(var5);
            if (var5.isConsumed()) {
               var1.consume();
            }

            switch (var5.id) {
               case 401:
               case 402:
               case 403:
               case 404:
                  if (var5.key != var6) {
                     ((KeyEvent)var1).setKeyChar(var5.getKeyEventChar());
                  }

                  if (var5.modifiers != var7) {
                     ((KeyEvent)var1).setModifiers(var5.modifiers);
                  }
            }
         }
      }

      if (!var1.isConsumed()) {
         if (var1 instanceof KeyEvent) {
            Container var9 = (Container)(this instanceof Container ? this : this.parent);
            if (var9 != null) {
               var9.postProcessKeyEvent((KeyEvent)var1);
            }
         } else {
            switch (var2) {
               case 201:
                  if (var3 instanceof WindowClosingListener) {
                     this.windowClosingException = ((WindowClosingListener)var3).windowClosingDelivered((WindowEvent)var1);
                     if (this.checkWindowClosingException()) {
                        return;
                     }
                  }
            }
         }
      }

      if (this.peer != null) {
         this.peer.handleEvent(var1);
      }

   }

   boolean checkWindowClosingException() {
      if (this.windowClosingException != null) {
         if (this instanceof Dialog) {
            ((Dialog)this).interruptBlocking();
         } else {
            this.windowClosingException.fillInStackTrace();
            this.windowClosingException.printStackTrace();
            this.windowClosingException = null;
         }

         return true;
      } else {
         return false;
      }
   }

   boolean areInputMethodsEnabled() {
      return (this.eventMask & 4096L) != 0L && ((this.eventMask & 8L) != 0L || this.keyListener != null);
   }

   boolean eventEnabled(AWTEvent var1) {
      switch (var1.id) {
         case 100:
         case 101:
         case 102:
         case 103:
            if ((this.eventMask & 1L) != 0L || this.componentListener != null) {
               return true;
            }
            break;
         case 400:
         case 401:
         case 402:
            if ((this.eventMask & 8L) != 0L || this.keyListener != null) {
               return true;
            }
            break;
         case 500:
         case 501:
         case 502:
         case 504:
         case 505:
            if ((this.eventMask & 16L) != 0L || this.mouseListener != null) {
               return true;
            }
            break;
         case 503:
         case 506:
            if ((this.eventMask & 32L) != 0L || this.mouseMotionListener != null) {
               return true;
            }
            break;
         case 1004:
         case 1005:
            if ((this.eventMask & 4L) != 0L || this.focusListener != null) {
               return true;
            }
            break;
         case 1100:
         case 1101:
            if ((this.eventMask & 2048L) != 0L || this.inputMethodListener != null) {
               return true;
            }
            break;
         case 1400:
            if ((this.eventMask & 32768L) != 0L || this.hierarchyListener != null) {
               return true;
            }
            break;
         case 1401:
         case 1402:
            if ((this.eventMask & 65536L) != 0L || this.hierarchyBoundsListener != null) {
               return true;
            }
      }

      if (var1.id > 1999) {
         return true;
      } else {
         return false;
      }
   }

   private Window getWindowForObject(Object var1) {
      if (var1 instanceof Component) {
         while(var1 != null) {
            if (var1 instanceof Window) {
               return (Window)var1;
            }

            var1 = ((Component)var1).getParent();
         }
      }

      return null;
   }

   public boolean postEvent(Event var1) {
      ComponentPeer var2 = this.peer;
      if (this.handleEvent(var1)) {
         var1.consume();
         return true;
      } else {
         Container var3 = this.parent;
         int var4 = var1.x;
         int var5 = var1.y;
         if (var3 != null) {
            var1.translate(this.field_0, this.field_1);
            if (((Component)var3).postEvent(var1)) {
               var1.consume();
               return true;
            }

            var1.x = var4;
            var1.y = var5;
         }

         return false;
      }
   }

   public synchronized void addComponentListener(ComponentListener var1) {
      if (var1 != null) {
         this.componentListener = AWTEventMulticaster.add(this.componentListener, var1);
         this.newEventsOnly = true;
      }
   }

   public synchronized void removeComponentListener(ComponentListener var1) {
      if (var1 != null) {
         this.componentListener = AWTEventMulticaster.remove(this.componentListener, var1);
      }
   }

   public synchronized void addFocusListener(FocusListener var1) {
      if (var1 != null) {
         this.focusListener = AWTEventMulticaster.add(this.focusListener, var1);
         this.newEventsOnly = true;
         if (this.peer instanceof LightweightPeer) {
            this.parent.proxyEnableEvents(4L);
         }

      }
   }

   public synchronized void removeFocusListener(FocusListener var1) {
      if (var1 != null) {
         this.focusListener = AWTEventMulticaster.remove(this.focusListener, var1);
      }
   }

   public void addHierarchyListener(HierarchyListener var1) {
      if (var1 != null) {
         boolean var8;
         synchronized(this) {
            var8 = this.hierarchyListener == null && (this.eventMask & 32768L) == 0L;
            this.hierarchyListener = AWTEventMulticaster.add(this.hierarchyListener, var1);
            var8 = var8 && this.hierarchyListener != null;
            this.newEventsOnly = true;
         }

         if (var8) {
            Object var4 = this.getTreeLock();
            synchronized(var4) {
               if (this.parent != null) {
                  this.parent.adjustListeningChildren(32768L, 1);
               }
            }
         }

      }
   }

   public void removeHierarchyListener(HierarchyListener var1) {
      if (var1 != null) {
         boolean var8;
         synchronized(this) {
            var8 = this.hierarchyListener != null && (this.eventMask & 32768L) == 0L;
            this.hierarchyListener = AWTEventMulticaster.remove(this.hierarchyListener, var1);
            var8 = var8 && this.hierarchyListener == null;
         }

         if (var8) {
            Object var4 = this.getTreeLock();
            synchronized(var4) {
               if (this.parent != null) {
                  this.parent.adjustListeningChildren(32768L, -1);
               }
            }
         }

      }
   }

   public void addHierarchyBoundsListener(HierarchyBoundsListener var1) {
      if (var1 != null) {
         boolean var8;
         synchronized(this) {
            var8 = this.hierarchyBoundsListener == null && (this.eventMask & 65536L) == 0L;
            this.hierarchyBoundsListener = AWTEventMulticaster.add(this.hierarchyBoundsListener, var1);
            var8 = var8 && this.hierarchyBoundsListener != null;
            this.newEventsOnly = true;
         }

         if (var8) {
            Object var4 = this.getTreeLock();
            synchronized(var4) {
               if (this.parent != null) {
                  this.parent.adjustListeningChildren(65536L, 1);
               }
            }
         }

      }
   }

   public void removeHierarchyBoundsListener(HierarchyBoundsListener var1) {
      if (var1 != null) {
         boolean var8;
         synchronized(this) {
            var8 = this.hierarchyBoundsListener != null && (this.eventMask & 65536L) == 0L;
            this.hierarchyBoundsListener = AWTEventMulticaster.remove(this.hierarchyBoundsListener, var1);
            var8 = var8 && this.hierarchyBoundsListener == null;
         }

         if (var8) {
            Object var4 = this.getTreeLock();
            synchronized(var4) {
               if (this.parent != null) {
                  this.parent.adjustListeningChildren(65536L, -1);
               }
            }
         }

      }
   }

   int numListening(long var1) {
      return (var1 != 32768L || this.hierarchyListener == null && (this.eventMask & 32768L) == 0L) && (var1 != 65536L || this.hierarchyBoundsListener == null && (this.eventMask & 65536L) == 0L) ? 0 : 1;
   }

   int createHierarchyEvents(int var1, Component var2, Container var3, long var4) {
      switch (var1) {
         case 1400:
            if (this.hierarchyListener != null || (this.eventMask & 32768L) != 0L) {
               HierarchyEvent var7 = new HierarchyEvent(this, var1, var2, var3, var4);
               this.dispatchEvent(var7);
               return 1;
            }
            break;
         case 1401:
         case 1402:
            if (this.hierarchyBoundsListener != null || (this.eventMask & 65536L) != 0L) {
               HierarchyEvent var6 = new HierarchyEvent(this, var1, var2, var3);
               this.dispatchEvent(var6);
               return 1;
            }
      }

      return 0;
   }

   void createChildHierarchyEvents(int var1, long var2) {
   }

   public synchronized void addKeyListener(KeyListener var1) {
      if (var1 != null) {
         this.keyListener = AWTEventMulticaster.add(this.keyListener, var1);
         this.newEventsOnly = true;
         if (this.peer instanceof LightweightPeer) {
            this.parent.proxyEnableEvents(8L);
         }

      }
   }

   public synchronized void removeKeyListener(KeyListener var1) {
      if (var1 != null) {
         this.keyListener = AWTEventMulticaster.remove(this.keyListener, var1);
      }
   }

   public synchronized void addMouseListener(MouseListener var1) {
      if (var1 != null) {
         this.mouseListener = AWTEventMulticaster.add(this.mouseListener, var1);
         this.newEventsOnly = true;
         if (this.peer instanceof LightweightPeer) {
            this.parent.proxyEnableEvents(16L);
         }

      }
   }

   public synchronized void removeMouseListener(MouseListener var1) {
      if (var1 != null) {
         this.mouseListener = AWTEventMulticaster.remove(this.mouseListener, var1);
      }
   }

   public synchronized void addMouseMotionListener(MouseMotionListener var1) {
      if (var1 != null) {
         this.mouseMotionListener = AWTEventMulticaster.add(this.mouseMotionListener, var1);
         this.newEventsOnly = true;
         if (this.peer instanceof LightweightPeer) {
            this.parent.proxyEnableEvents(32L);
         }

      }
   }

   public synchronized void removeMouseMotionListener(MouseMotionListener var1) {
      if (var1 != null) {
         this.mouseMotionListener = AWTEventMulticaster.remove(this.mouseMotionListener, var1);
      }
   }

   public synchronized void addInputMethodListener(InputMethodListener var1) {
      if (var1 != null) {
         this.inputMethodListener = AWTEventMulticaster.add(this.inputMethodListener, var1);
         this.newEventsOnly = true;
      }
   }

   public synchronized void removeInputMethodListener(InputMethodListener var1) {
      if (var1 != null) {
         this.inputMethodListener = AWTEventMulticaster.remove(this.inputMethodListener, var1);
      }
   }

   public EventListener[] getListeners(Class var1) {
      Object var2 = null;
      if (var1 == (class$java$awt$event$ComponentListener == null ? (class$java$awt$event$ComponentListener = class$("java.awt.event.ComponentListener")) : class$java$awt$event$ComponentListener)) {
         var2 = this.componentListener;
      } else if (var1 == (class$java$awt$event$FocusListener == null ? (class$java$awt$event$FocusListener = class$("java.awt.event.FocusListener")) : class$java$awt$event$FocusListener)) {
         var2 = this.focusListener;
      } else if (var1 == (class$java$awt$event$HierarchyListener == null ? (class$java$awt$event$HierarchyListener = class$("java.awt.event.HierarchyListener")) : class$java$awt$event$HierarchyListener)) {
         var2 = this.hierarchyListener;
      } else if (var1 == (class$java$awt$event$HierarchyBoundsListener == null ? (class$java$awt$event$HierarchyBoundsListener = class$("java.awt.event.HierarchyBoundsListener")) : class$java$awt$event$HierarchyBoundsListener)) {
         var2 = this.hierarchyBoundsListener;
      } else if (var1 == (class$java$awt$event$KeyListener == null ? (class$java$awt$event$KeyListener = class$("java.awt.event.KeyListener")) : class$java$awt$event$KeyListener)) {
         var2 = this.keyListener;
      } else if (var1 == (class$java$awt$event$MouseListener == null ? (class$java$awt$event$MouseListener = class$("java.awt.event.MouseListener")) : class$java$awt$event$MouseListener)) {
         var2 = this.mouseListener;
      } else if (var1 == (class$java$awt$event$MouseMotionListener == null ? (class$java$awt$event$MouseMotionListener = class$("java.awt.event.MouseMotionListener")) : class$java$awt$event$MouseMotionListener)) {
         var2 = this.mouseMotionListener;
      } else if (var1 == (class$java$awt$event$InputMethodListener == null ? (class$java$awt$event$InputMethodListener = class$("java.awt.event.InputMethodListener")) : class$java$awt$event$InputMethodListener)) {
         var2 = this.inputMethodListener;
      }

      return AWTEventMulticaster.getListeners((EventListener)var2, var1);
   }

   public InputMethodRequests getInputMethodRequests() {
      return null;
   }

   public InputContext getInputContext() {
      Container var1 = this.parent;
      return var1 == null ? null : ((Component)var1).getInputContext();
   }

   protected final void enableEvents(long var1) {
      long var3 = 0L;
      synchronized(this) {
         if ((var1 & 32768L) != 0L && this.hierarchyListener == null && (this.eventMask & 32768L) == 0L) {
            var3 |= 32768L;
         }

         if ((var1 & 65536L) != 0L && this.hierarchyBoundsListener == null && (this.eventMask & 65536L) == 0L) {
            var3 |= 65536L;
         }

         this.eventMask |= var1;
         this.newEventsOnly = true;
      }

      if (this.peer instanceof LightweightPeer) {
         this.parent.proxyEnableEvents(this.eventMask);
      }

      if (var3 != 0L) {
         Object var6 = this.getTreeLock();
         synchronized(var6) {
            if (this.parent != null) {
               this.parent.adjustListeningChildren(var3, 1);
            }
         }
      }

   }

   protected final void disableEvents(long var1) {
      long var3 = 0L;
      synchronized(this) {
         if ((var1 & 32768L) != 0L && this.hierarchyListener == null && (this.eventMask & 32768L) != 0L) {
            var3 |= 32768L;
         }

         if ((var1 & 65536L) != 0L && this.hierarchyBoundsListener == null && (this.eventMask & 65536L) != 0L) {
            var3 |= 65536L;
         }

         this.eventMask &= ~var1;
      }

      if (var3 != 0L) {
         Object var6 = this.getTreeLock();
         synchronized(var6) {
            if (this.parent != null) {
               this.parent.adjustListeningChildren(var3, -1);
            }
         }
      }

   }

   protected AWTEvent coalesceEvents(AWTEvent var1, AWTEvent var2) {
      int var3 = var1.getID();
      switch (var3) {
         case 503:
         case 506:
            MouseEvent var8 = (MouseEvent)var1;
            if (((InputEvent)var8).getModifiers() == ((MouseEvent)var2).getModifiers()) {
               return var2;
            }
            break;
         case 800:
         case 801:
            if (this.peer != null) {
               this.peer.coalescePaintEvent((PaintEvent)var2);
               return var2;
            }

            PaintEvent var4 = (PaintEvent)var1;
            PaintEvent var5 = (PaintEvent)var2;
            Rectangle var6 = var4.getUpdateRect();
            Rectangle var7 = var5.getUpdateRect();
            if (var6.contains(var7)) {
               return var1;
            }

            if (var7.contains(var6)) {
               return var2;
            }
      }

      return null;
   }

   protected void processEvent(AWTEvent var1) {
      if (var1 instanceof FocusEvent) {
         this.processFocusEvent((FocusEvent)var1);
      } else if (var1 instanceof MouseEvent) {
         switch (var1.getID()) {
            case 500:
            case 501:
            case 502:
            case 504:
            case 505:
               this.processMouseEvent((MouseEvent)var1);
               break;
            case 503:
            case 506:
               this.processMouseMotionEvent((MouseEvent)var1);
         }
      } else if (var1 instanceof KeyEvent) {
         this.processKeyEvent((KeyEvent)var1);
      } else if (var1 instanceof ComponentEvent) {
         this.processComponentEvent((ComponentEvent)var1);
      } else if (var1 instanceof InputMethodEvent) {
         this.processInputMethodEvent((InputMethodEvent)var1);
      } else if (var1 instanceof HierarchyEvent) {
         switch (var1.getID()) {
            case 1400:
               this.processHierarchyEvent((HierarchyEvent)var1);
               break;
            case 1401:
            case 1402:
               this.processHierarchyBoundsEvent((HierarchyEvent)var1);
         }
      }

   }

   protected void processComponentEvent(ComponentEvent var1) {
      ComponentListener var2 = this.componentListener;
      if (var2 != null) {
         int var3 = ((AWTEvent)var1).getID();
         switch (var3) {
            case 100:
               var2.componentMoved(var1);
               break;
            case 101:
               var2.componentResized(var1);
               break;
            case 102:
               var2.componentShown(var1);
               break;
            case 103:
               var2.componentHidden(var1);
         }
      }

   }

   protected void processFocusEvent(FocusEvent var1) {
      FocusListener var2 = this.focusListener;
      if (var2 != null) {
         int var3 = ((AWTEvent)var1).getID();
         switch (var3) {
            case 1004:
               var2.focusGained(var1);
               break;
            case 1005:
               var2.focusLost(var1);
         }
      }

   }

   protected void processKeyEvent(KeyEvent var1) {
      KeyListener var2 = this.keyListener;
      if (var2 != null) {
         int var3 = ((AWTEvent)var1).getID();
         switch (var3) {
            case 400:
               var2.keyTyped(var1);
               break;
            case 401:
               var2.keyPressed(var1);
               break;
            case 402:
               var2.keyReleased(var1);
         }
      }

   }

   protected void processMouseEvent(MouseEvent var1) {
      MouseListener var2 = this.mouseListener;
      if (var2 != null) {
         int var3 = ((AWTEvent)var1).getID();
         switch (var3) {
            case 500:
               var2.mouseClicked(var1);
               break;
            case 501:
               var2.mousePressed(var1);
               break;
            case 502:
               var2.mouseReleased(var1);
            case 503:
            default:
               break;
            case 504:
               var2.mouseEntered(var1);
               break;
            case 505:
               var2.mouseExited(var1);
         }
      }

   }

   protected void processMouseMotionEvent(MouseEvent var1) {
      MouseMotionListener var2 = this.mouseMotionListener;
      if (var2 != null) {
         int var3 = ((AWTEvent)var1).getID();
         switch (var3) {
            case 503:
               var2.mouseMoved(var1);
               break;
            case 506:
               var2.mouseDragged(var1);
         }
      }

   }

   boolean postsOldMouseEvents() {
      return false;
   }

   protected void processInputMethodEvent(InputMethodEvent var1) {
      InputMethodListener var2 = this.inputMethodListener;
      if (var2 != null) {
         int var3 = ((AWTEvent)var1).getID();
         switch (var3) {
            case 1100:
               var2.inputMethodTextChanged(var1);
               break;
            case 1101:
               var2.caretPositionChanged(var1);
         }
      }

   }

   protected void processHierarchyEvent(HierarchyEvent var1) {
      HierarchyListener var2 = this.hierarchyListener;
      if (var2 != null) {
         int var3 = ((AWTEvent)var1).getID();
         switch (var3) {
            case 1400:
               var2.hierarchyChanged(var1);
         }
      }

   }

   protected void processHierarchyBoundsEvent(HierarchyEvent var1) {
      HierarchyBoundsListener var2 = this.hierarchyBoundsListener;
      if (var2 != null) {
         int var3 = ((AWTEvent)var1).getID();
         switch (var3) {
            case 1401:
               var2.ancestorMoved(var1);
               break;
            case 1402:
               var2.ancestorResized(var1);
         }
      }

   }

   public boolean handleEvent(Event var1) {
      switch (var1.id) {
         case 401:
         case 403:
            return this.keyDown(var1, var1.key);
         case 402:
         case 404:
            return this.keyUp(var1, var1.key);
         case 501:
            return this.mouseDown(var1, var1.x, var1.y);
         case 502:
            return this.mouseUp(var1, var1.x, var1.y);
         case 503:
            return this.mouseMove(var1, var1.x, var1.y);
         case 504:
            return this.mouseEnter(var1, var1.x, var1.y);
         case 505:
            return this.mouseExit(var1, var1.x, var1.y);
         case 506:
            return this.mouseDrag(var1, var1.x, var1.y);
         case 1001:
            return this.action(var1, var1.arg);
         case 1004:
            return this.gotFocus(var1, var1.arg);
         case 1005:
            return this.lostFocus(var1, var1.arg);
         default:
            return false;
      }
   }

   public boolean mouseDown(Event var1, int var2, int var3) {
      return false;
   }

   public boolean mouseDrag(Event var1, int var2, int var3) {
      return false;
   }

   public boolean mouseUp(Event var1, int var2, int var3) {
      return false;
   }

   public boolean mouseMove(Event var1, int var2, int var3) {
      return false;
   }

   public boolean mouseEnter(Event var1, int var2, int var3) {
      return false;
   }

   public boolean mouseExit(Event var1, int var2, int var3) {
      return false;
   }

   public boolean keyDown(Event var1, int var2) {
      return false;
   }

   public boolean keyUp(Event var1, int var2) {
      return false;
   }

   public boolean action(Event var1, Object var2) {
      return false;
   }

   public void addNotify() {
      Object var1 = this.getTreeLock();
      synchronized(var1) {
         Object var2 = this.peer;
         if (var2 != null && !(var2 instanceof LightweightPeer)) {
            Container var8 = this.parent;
            if (var8 != null && var8.peer instanceof LightweightPeer) {
               new NativeInLightFixer(this);
            }
         } else {
            if (var2 == null) {
               this.peer = (ComponentPeer)(var2 = this.getToolkit().createComponent(this));
            }

            if (this.parent != null) {
               long var3 = 0L;
               if (this.mouseListener != null || (this.eventMask & 16L) != 0L) {
                  var3 |= 16L;
               }

               if (this.mouseMotionListener != null || (this.eventMask & 32L) != 0L) {
                  var3 |= 32L;
               }

               if (this.focusListener != null || (this.eventMask & 4L) != 0L) {
                  var3 |= 4L;
               }

               if (this.keyListener != null || (this.eventMask & 8L) != 0L) {
                  var3 |= 8L;
               }

               if (var3 != 0L) {
                  this.parent.proxyEnableEvents(var3);
               }
            }
         }

         this.invalidate();
         int var9 = this.popups != null ? this.popups.size() : 0;

         for(int var4 = 0; var4 < var9; ++var4) {
            PopupMenu var5 = (PopupMenu)this.popups.elementAt(var4);
            var5.addNotify();
         }

         if (this.dropTarget != null) {
            this.dropTarget.addNotify((ComponentPeer)var2);
         }

         this.peerFont = this.getFont();
         if (this.hierarchyListener != null || (this.eventMask & 32768L) != 0L) {
            HierarchyEvent var10 = new HierarchyEvent(this, 1400, this, this.parent, (long)(2 | (this.isRecursivelyVisible() ? 4 : 0)));
            this.dispatchEvent(var10);
         }

      }
   }

   public void removeNotify() {
      Object var1 = this.getTreeLock();
      synchronized(var1) {
         int var2 = this.popups != null ? this.popups.size() : 0;

         for(int var3 = 0; var3 < var2; ++var3) {
            PopupMenu var4 = (PopupMenu)this.popups.elementAt(var3);
            ((Menu)var4).removeNotify();
         }

         if (this.areInputMethodsEnabled()) {
            InputContext var8 = this.getInputContext();
            if (var8 != null) {
               var8.removeNotify(this);
            }
         }

         ComponentPeer var9 = this.peer;
         if (var9 != null) {
            if (this.dropTarget != null) {
               this.dropTarget.removeNotify(this.peer);
            }

            if (this.visible) {
               var9.hide();
            }

            this.peer = null;
            this.peerFont = null;
            Toolkit.getEventQueue().removeSourceEvents(this);
            var9.dispose();
         }

         if ((var9 instanceof LightweightPeer || var9 == null) && this.hasFocus()) {
            this.dispatchEvent(new FocusEvent(this, 1005));
         }

         if (this.hierarchyListener != null || (this.eventMask & 32768L) != 0L) {
            HierarchyEvent var5 = new HierarchyEvent(this, 1400, this, this.parent, (long)(2 | (this.isRecursivelyVisible() ? 4 : 0)));
            this.dispatchEvent(var5);
         }

      }
   }

   public boolean gotFocus(Event var1, Object var2) {
      return false;
   }

   public boolean lostFocus(Event var1, Object var2) {
      return false;
   }

   public boolean isFocusTraversable() {
      ComponentPeer var1 = this.peer;
      return var1 != null ? var1.isFocusTraversable() : false;
   }

   public void requestFocus() {
      ComponentPeer var1 = this.peer;
      if (var1 != null) {
         if (var1 instanceof LightweightPeer) {
            if (this.parent != null) {
               this.parent.proxyRequestFocus(this);
            }
         } else {
            var1.requestFocus();
            Toolkit.getEventQueue().changeKeyEventFocus(this);
         }
      }

   }

   public void transferFocus() {
      this.nextFocus();
   }

   public void nextFocus() {
      Container var1 = this.parent;
      if (var1 != null) {
         var1.transferFocus(this);
      }

   }

   public boolean hasFocus() {
      if ((this.eventMask & 4L) != 0L) {
         return this.hasFocus;
      } else {
         for(Container var1 = this.getParent(); var1 != null; var1 = ((Component)var1).getParent()) {
            if (var1 instanceof Window) {
               return ((Window)var1).getFocusOwner() == this;
            }
         }

         return false;
      }
   }

   public synchronized void add(PopupMenu var1) {
      if (var1.parent != null) {
         var1.parent.remove(var1);
      }

      if (this.popups == null) {
         this.popups = new Vector();
      }

      this.popups.addElement(var1);
      var1.parent = this;
      if (this.peer != null && var1.peer == null) {
         var1.addNotify();
      }

   }

   public synchronized void remove(MenuComponent var1) {
      if (this.popups != null) {
         int var2 = this.popups.indexOf(var1);
         if (var2 >= 0) {
            PopupMenu var3 = (PopupMenu)var1;
            if (var3.peer != null) {
               ((Menu)var3).removeNotify();
            }

            var3.parent = null;
            this.popups.removeElementAt(var2);
            if (this.popups.size() == 0) {
               this.popups = null;
            }
         }
      }

   }

   protected String paramString() {
      String var1 = this.getName();
      String var2 = (var1 != null ? var1 : "") + "," + this.field_0 + "," + this.field_1 + "," + this.width + "x" + this.height;
      if (!this.valid) {
         var2 = var2 + ",invalid";
      }

      if (!this.visible) {
         var2 = var2 + ",hidden";
      }

      if (!this.enabled) {
         var2 = var2 + ",disabled";
      }

      return var2;
   }

   public String toString() {
      return this.getClass().getName() + "[" + this.paramString() + "]";
   }

   public void list() {
      this.list((PrintStream)System.out, 0);
   }

   public void list(PrintStream var1) {
      this.list((PrintStream)var1, 0);
   }

   public void list(PrintStream var1, int var2) {
      for(int var3 = 0; var3 < var2; ++var3) {
         var1.print("  ");
      }

      var1.println(this);
   }

   public void list(PrintWriter var1) {
      this.list((PrintWriter)var1, 0);
   }

   public void list(PrintWriter var1, int var2) {
      for(int var3 = 0; var3 < var2; ++var3) {
         var1.print("  ");
      }

      var1.println(this);
   }

   Container getNativeContainer() {
      Container var1;
      for(var1 = this.parent; var1 != null && var1.peer instanceof LightweightPeer; var1 = ((Component)var1).getParent()) {
      }

      return var1;
   }

   public synchronized void addPropertyChangeListener(PropertyChangeListener var1) {
      if (var1 != null) {
         if (this.changeSupport == null) {
            this.changeSupport = new PropertyChangeSupport(this);
         }

         this.changeSupport.addPropertyChangeListener(var1);
      }
   }

   public synchronized void removePropertyChangeListener(PropertyChangeListener var1) {
      if (var1 != null) {
         if (this.changeSupport != null) {
            this.changeSupport.removePropertyChangeListener(var1);
         }
      }
   }

   public synchronized void addPropertyChangeListener(String var1, PropertyChangeListener var2) {
      if (var2 != null) {
         if (this.changeSupport == null) {
            this.changeSupport = new PropertyChangeSupport(this);
         }

         this.changeSupport.addPropertyChangeListener(var1, var2);
      }
   }

   public synchronized void removePropertyChangeListener(String var1, PropertyChangeListener var2) {
      if (var2 != null) {
         if (this.changeSupport != null) {
            this.changeSupport.removePropertyChangeListener(var1, var2);
         }
      }
   }

   protected void firePropertyChange(String var1, Object var2, Object var3) {
      PropertyChangeSupport var4 = this.changeSupport;
      if (var4 != null) {
         var4.firePropertyChange(var1, var2, var3);
      }
   }

   private void writeObject(ObjectOutputStream var1) throws IOException {
      var1.defaultWriteObject();
      AWTEventMulticaster.save(var1, "componentL", this.componentListener);
      AWTEventMulticaster.save(var1, "focusL", this.focusListener);
      AWTEventMulticaster.save(var1, "keyL", this.keyListener);
      AWTEventMulticaster.save(var1, "mouseL", this.mouseListener);
      AWTEventMulticaster.save(var1, "mouseMotionL", this.mouseMotionListener);
      AWTEventMulticaster.save(var1, "inputMethodL", this.inputMethodListener);
      var1.writeObject((Object)null);
      var1.writeObject(this.componentOrientation);
      AWTEventMulticaster.save(var1, "hierarchyL", this.hierarchyListener);
      AWTEventMulticaster.save(var1, "hierarchyBoundsL", this.hierarchyBoundsListener);
      var1.writeObject((Object)null);
   }

   private void readObject(ObjectInputStream var1) throws ClassNotFoundException, IOException {
      var1.defaultReadObject();
      this.privateKey = new Object();
      this.appContext = AppContext.getAppContext();
      SunToolkit.insertTargetMapping(this, this.appContext);

      Object var2;
      while(null != (var2 = var1.readObject())) {
         String var3 = ((String)var2).intern();
         if ("componentL" == var3) {
            this.addComponentListener((ComponentListener)var1.readObject());
         } else if ("focusL" == var3) {
            this.addFocusListener((FocusListener)var1.readObject());
         } else if ("keyL" == var3) {
            this.addKeyListener((KeyListener)var1.readObject());
         } else if ("mouseL" == var3) {
            this.addMouseListener((MouseListener)var1.readObject());
         } else if ("mouseMotionL" == var3) {
            this.addMouseMotionListener((MouseMotionListener)var1.readObject());
         } else if ("inputMethodL" == var3) {
            this.addInputMethodListener((InputMethodListener)var1.readObject());
         } else {
            var1.readObject();
         }
      }

      Object var10 = null;

      try {
         var10 = var1.readObject();
      } catch (OptionalDataException var8) {
         if (!var8.eof) {
            throw var8;
         }
      }

      if (var10 != null) {
         this.componentOrientation = (ComponentOrientation)var10;
      } else {
         this.componentOrientation = ComponentOrientation.UNKNOWN;
      }

      try {
         while(null != (var2 = var1.readObject())) {
            String var4 = ((String)var2).intern();
            if ("hierarchyL" == var4) {
               this.addHierarchyListener((HierarchyListener)var1.readObject());
            } else if ("hierarchyBoundsL" == var4) {
               this.addHierarchyBoundsListener((HierarchyBoundsListener)var1.readObject());
            } else {
               var1.readObject();
            }
         }
      } catch (OptionalDataException var7) {
         if (!var7.eof) {
            throw var7;
         }
      }

      if (this.popups != null) {
         int var11 = this.popups.size();

         for(int var5 = 0; var5 < var11; ++var5) {
            PopupMenu var6 = (PopupMenu)this.popups.elementAt(var5);
            var6.parent = this;
         }
      }

   }

   public void setComponentOrientation(ComponentOrientation var1) {
      ComponentOrientation var2 = this.componentOrientation;
      this.componentOrientation = var1;
      this.firePropertyChange("componentOrientation", var2, var1);
      if (this.valid) {
         this.invalidate();
      }

   }

   public ComponentOrientation getComponentOrientation() {
      return this.componentOrientation;
   }

   private static native void initIDs();

   public AccessibleContext getAccessibleContext() {
      return this.accessibleContext;
   }

   int getAccessibleIndexInParent() {
      Object var1 = this.getTreeLock();
      synchronized(var1) {
         int var2 = -1;
         Container var3 = this.getParent();
         if (var3 != null && var3 instanceof Accessible) {
            Component[] var4 = var3.getComponents();

            for(int var5 = 0; var5 < var4.length; ++var5) {
               if (var4[var5] instanceof Accessible) {
                  ++var2;
               }

               if (this.equals(var4[var5])) {
                  return var2;
               }
            }
         }

         byte var9 = -1;
         return var9;
      }
   }

   AccessibleStateSet getAccessibleStateSet() {
      Object var1 = this.getTreeLock();
      synchronized(var1) {
         AccessibleStateSet var2 = new AccessibleStateSet();
         if (this.isEnabled()) {
            var2.add(AccessibleState.ENABLED);
         }

         if (this.isFocusTraversable()) {
            var2.add(AccessibleState.FOCUSABLE);
         }

         if (this.isVisible()) {
            var2.add(AccessibleState.VISIBLE);
         }

         if (this.isShowing()) {
            var2.add(AccessibleState.SHOWING);
         }

         if (this.hasFocus()) {
            var2.add(AccessibleState.FOCUSED);
         }

         if (this instanceof Accessible) {
            AccessibleContext var3 = ((Accessible)this).getAccessibleContext();
            if (var3 != null) {
               Accessible var4 = var3.getAccessibleParent();
               if (var4 != null) {
                  AccessibleContext var5 = var4.getAccessibleContext();
                  if (var5 != null) {
                     AccessibleSelection var6 = var5.getAccessibleSelection();
                     if (var6 != null) {
                        var2.add(AccessibleState.SELECTABLE);
                        int var7 = var3.getAccessibleIndexInParent();
                        if (var7 >= 0 && var6.isAccessibleChildSelected(var7)) {
                           var2.add(AccessibleState.SELECTED);
                        }
                     }
                  }
               }
            }
         }

         if (this instanceof JComponent && ((JComponent)this).isOpaque()) {
            var2.add(AccessibleState.OPAQUE);
         }

         return var2;
      }
   }

   // $FF: synthetic method
   static Class class$(String var0) {
      try {
         return Class.forName(var0);
      } catch (ClassNotFoundException var2) {
         throw new NoClassDefFoundError(((Throwable)var2).getMessage());
      }
   }

   static {
      dbg = DebugHelper.create(class$java$awt$Component == null ? (class$java$awt$Component = class$("java.awt.Component")) : class$java$awt$Component);
      Toolkit.loadLibraries();
      initIDs();
      String var0 = (String)AccessController.doPrivileged(new GetPropertyAction("awt.image.incrementaldraw"));
      isInc = var0 == null || var0.equals("true");
      var0 = (String)AccessController.doPrivileged(new GetPropertyAction("awt.image.redrawrate"));
      incRate = var0 != null ? Integer.parseInt(var0) : 100;
      metrics = new Hashtable();
   }
}
