package java.awt;

import java.io.Serializable;

class FocusManager implements Serializable {
   Container focusRoot;
   Component focusOwner;
   static final long serialVersionUID = 2491878825643557906L;

   FocusManager(Container var1) {
      this.focusRoot = var1;
   }

   void activateFocus() {
      boolean var1 = false;
      if (this.focusOwner != null) {
         if (!(var1 = this.assignFocus(this.focusOwner, false))) {
            var1 = this.focusNext(this.focusOwner);
         }
      } else {
         var1 = this.focusForward(this.focusRoot);
      }

      if (!var1) {
         this.focusRoot.requestFocus();
      }

   }

   synchronized void setFocusOwner(Component var1) {
      this.focusOwner = var1;
   }

   Component getFocusOwner() {
      return this.focusOwner;
   }

   boolean focusNext() {
      return this.focusNext(this.focusOwner);
   }

   boolean focusNext(Component var1) {
      Object var2 = this.focusRoot.getTreeLock();
      synchronized(var2) {
         Object var3 = var1;
         Container var5;
         if (var1 != null && var1.parent != null) {
            do {
               boolean var4 = false;
               var5 = ((Component)var3).parent;

               for(int var7 = 0; var7 < var5.ncomponents; ++var7) {
                  Component var6 = var5.component[var7];
                  if (var4) {
                     if (this.assignFocus(var6)) {
                        boolean var13 = true;
                        return var13;
                     }

                     if (var6 instanceof Container && var6.isVisible() && var6.isEnabled() && this.focusForward((Container)var6)) {
                        boolean var8 = true;
                        return var8;
                     }
                  } else if (var6 == var3) {
                     var4 = true;
                  }
               }

               var3 = var5;
            } while(var5 != this.focusRoot && var5.parent != null);
         }

         if (this.focusForward(this.focusRoot)) {
            boolean var12 = true;
            return var12;
         } else {
            boolean var11 = false;
            return var11;
         }
      }
   }

   boolean focusPrevious() {
      return this.focusPrevious(this.focusOwner);
   }

   boolean focusPrevious(Component var1) {
      Object var2 = this.focusRoot.getTreeLock();
      synchronized(var2) {
         Object var3 = var1;
         Container var5;
         if (var1 != null && var1.parent != null) {
            do {
               boolean var4 = false;
               var5 = ((Component)var3).parent;
               if (var5 != null) {
                  for(int var7 = var5.ncomponents - 1; var7 >= 0; --var7) {
                     Component var6 = var5.component[var7];
                     if (var4) {
                        if (this.assignFocus(var6)) {
                           boolean var13 = true;
                           return var13;
                        }

                        if (var6 instanceof Container && var6.isVisible() && var6.isEnabled() && this.focusBackward((Container)var6)) {
                           boolean var8 = true;
                           return var8;
                        }
                     } else if (var6 == var3) {
                        var4 = true;
                     }
                  }
               }

               var3 = var5;
            } while(var5 != null && var5 != this.focusRoot);
         }

         if (this.focusBackward(this.focusRoot)) {
            boolean var12 = true;
            return var12;
         } else {
            boolean var11 = false;
            return var11;
         }
      }
   }

   boolean assignFocus(Component var1) {
      return this.assignFocus(var1, true);
   }

   synchronized boolean assignFocus(Component var1, boolean var2) {
      if (!var1.isVisible() || !var1.isEnabled() || var2 && !var1.isFocusTraversable()) {
         return false;
      } else {
         var1.requestFocus();
         return true;
      }
   }

   synchronized boolean focusForward(Container var1) {
      for(int var2 = 0; var2 < var1.ncomponents; ++var2) {
         Component var3 = var1.component[var2];
         if (this.assignFocus(var3)) {
            return true;
         }

         if (var3 instanceof Container && var3.isVisible() && var3.isEnabled() && this.focusForward((Container)var3)) {
            return true;
         }
      }

      return false;
   }

   synchronized boolean focusBackward(Container var1) {
      for(int var2 = var1.ncomponents - 1; var2 >= 0; --var2) {
         Component var3 = var1.component[var2];
         if (this.assignFocus(var3)) {
            return true;
         }

         if (var3 instanceof Container && var3.isVisible() && var3.isEnabled() && this.focusBackward((Container)var3)) {
            return true;
         }
      }

      return false;
   }
}
