package java.awt;

import java.io.Serializable;
import java.util.Hashtable;

public class GridBagLayout implements LayoutManager2, Serializable {
   protected static final int MAXGRIDSIZE = 512;
   protected static final int MINSIZE = 1;
   protected static final int PREFERREDSIZE = 2;
   protected Hashtable comptable = new Hashtable();
   protected GridBagConstraints defaultConstraints = new GridBagConstraints();
   protected GridBagLayoutInfo layoutInfo;
   public int[] columnWidths;
   public int[] rowHeights;
   public double[] columnWeights;
   public double[] rowWeights;

   public void setConstraints(Component var1, GridBagConstraints var2) {
      this.comptable.put(var1, var2.clone());
   }

   public GridBagConstraints getConstraints(Component var1) {
      GridBagConstraints var2 = (GridBagConstraints)this.comptable.get(var1);
      if (var2 == null) {
         this.setConstraints(var1, this.defaultConstraints);
         var2 = (GridBagConstraints)this.comptable.get(var1);
      }

      return (GridBagConstraints)var2.clone();
   }

   protected GridBagConstraints lookupConstraints(Component var1) {
      GridBagConstraints var2 = (GridBagConstraints)this.comptable.get(var1);
      if (var2 == null) {
         this.setConstraints(var1, this.defaultConstraints);
         var2 = (GridBagConstraints)this.comptable.get(var1);
      }

      return var2;
   }

   private void removeConstraints(Component var1) {
      this.comptable.remove(var1);
   }

   public Point getLayoutOrigin() {
      Point var1 = new Point(0, 0);
      if (this.layoutInfo != null) {
         var1.x = this.layoutInfo.startx;
         var1.y = this.layoutInfo.starty;
      }

      return var1;
   }

   public int[][] getLayoutDimensions() {
      if (this.layoutInfo == null) {
         return new int[2][0];
      } else {
         int[][] var1 = new int[][]{new int[this.layoutInfo.width], new int[this.layoutInfo.height]};
         System.arraycopy(this.layoutInfo.minWidth, 0, var1[0], 0, this.layoutInfo.width);
         System.arraycopy(this.layoutInfo.minHeight, 0, var1[1], 0, this.layoutInfo.height);
         return var1;
      }
   }

   public double[][] getLayoutWeights() {
      if (this.layoutInfo == null) {
         return new double[2][0];
      } else {
         double[][] var1 = new double[][]{new double[this.layoutInfo.width], new double[this.layoutInfo.height]};
         System.arraycopy(this.layoutInfo.weightX, 0, var1[0], 0, this.layoutInfo.width);
         System.arraycopy(this.layoutInfo.weightY, 0, var1[1], 0, this.layoutInfo.height);
         return var1;
      }
   }

   public Point location(int var1, int var2) {
      Point var3 = new Point(0, 0);
      if (this.layoutInfo == null) {
         return var3;
      } else {
         int var5 = this.layoutInfo.startx;

         int var4;
         for(var4 = 0; var4 < this.layoutInfo.width; ++var4) {
            var5 += this.layoutInfo.minWidth[var4];
            if (var5 > var1) {
               break;
            }
         }

         var3.x = var4;
         var5 = this.layoutInfo.starty;

         for(var4 = 0; var4 < this.layoutInfo.height; ++var4) {
            var5 += this.layoutInfo.minHeight[var4];
            if (var5 > var2) {
               break;
            }
         }

         var3.y = var4;
         return var3;
      }
   }

   public void addLayoutComponent(String var1, Component var2) {
   }

   public void addLayoutComponent(Component var1, Object var2) {
      if (var2 instanceof GridBagConstraints) {
         this.setConstraints(var1, (GridBagConstraints)var2);
      } else if (var2 != null) {
         throw new IllegalArgumentException("cannot add to layout: constraint must be a GridBagConstraint");
      }

   }

   public void removeLayoutComponent(Component var1) {
      this.removeConstraints(var1);
   }

   public Dimension preferredLayoutSize(Container var1) {
      GridBagLayoutInfo var2 = this.GetLayoutInfo(var1, 2);
      return this.GetMinSize(var1, var2);
   }

   public Dimension minimumLayoutSize(Container var1) {
      GridBagLayoutInfo var2 = this.GetLayoutInfo(var1, 1);
      return this.GetMinSize(var1, var2);
   }

   public Dimension maximumLayoutSize(Container var1) {
      return new Dimension(Integer.MAX_VALUE, Integer.MAX_VALUE);
   }

   public float getLayoutAlignmentX(Container var1) {
      return 0.5F;
   }

   public float getLayoutAlignmentY(Container var1) {
      return 0.5F;
   }

   public void invalidateLayout(Container var1) {
   }

   public void layoutContainer(Container var1) {
      this.ArrangeGrid(var1);
   }

   public String toString() {
      return this.getClass().getName();
   }

   protected GridBagLayoutInfo GetLayoutInfo(Container var1, int var2) {
      Object var3 = ((Component)var1).getTreeLock();
      synchronized(var3) {
         GridBagLayoutInfo var4 = new GridBagLayoutInfo();
         Component[] var8 = var1.getComponents();
         var4.width = var4.height = 0;
         int var22 = -1;
         int var21 = -1;
         int[] var31 = new int[512];
         int[] var32 = new int[512];

         for(int var9 = 0; var9 < var8.length; ++var9) {
            Component var5 = var8[var9];
            if (var5.isVisible()) {
               GridBagConstraints var6 = this.lookupConstraints(var5);
               int var17 = var6.gridx;
               int var18 = var6.gridy;
               int var19 = var6.gridwidth;
               if (var19 <= 0) {
                  var19 = 1;
               }

               int var20 = var6.gridheight;
               if (var20 <= 0) {
                  var20 = 1;
               }

               if (var17 < 0 && var18 < 0) {
                  if (var21 >= 0) {
                     var18 = var21;
                  } else if (var22 >= 0) {
                     var17 = var22;
                  } else {
                     var18 = 0;
                  }
               }

               if (var17 < 0) {
                  int var13 = 0;

                  for(int var10 = var18; var10 < var18 + var20; ++var10) {
                     var13 = Math.max(var13, var31[var10]);
                  }

                  var17 = var13 - var17 - 1;
                  if (var17 < 0) {
                     var17 = 0;
                  }
               } else if (var18 < 0) {
                  int var14 = 0;

                  for(int var45 = var17; var45 < var17 + var19; ++var45) {
                     var14 = Math.max(var14, var32[var45]);
                  }

                  var18 = var14 - var18 - 1;
                  if (var18 < 0) {
                     var18 = 0;
                  }
               }

               int var64;
               for(var64 = var17 + var19; var4.width < var64; ++var4.width) {
               }

               int var68;
               for(var68 = var18 + var20; var4.height < var68; ++var4.height) {
               }

               for(int var46 = var17; var46 < var17 + var19; ++var46) {
                  var32[var46] = var68;
               }

               for(int var47 = var18; var47 < var18 + var20; ++var47) {
                  var31[var47] = var64;
               }

               Dimension var7;
               if (var2 == 2) {
                  var7 = var5.getPreferredSize();
               } else {
                  var7 = var5.getMinimumSize();
               }

               var6.minWidth = var7.width;
               var6.minHeight = var7.height;
               if (var6.gridheight == 0 && var6.gridwidth == 0) {
                  var22 = -1;
                  var21 = -1;
               }

               if (var6.gridheight == 0 && var21 < 0) {
                  var22 = var17 + var19;
               } else if (var6.gridwidth == 0 && var22 < 0) {
                  var21 = var18 + var20;
               }
            }
         }

         if (this.columnWidths != null && var4.width < this.columnWidths.length) {
            var4.width = this.columnWidths.length;
         }

         if (this.rowHeights != null && var4.height < this.rowHeights.length) {
            var4.height = this.rowHeights.length;
         }

         var22 = -1;
         var21 = -1;
         var31 = new int[512];
         var32 = new int[512];

         for(int var43 = 0; var43 < var8.length; ++var43) {
            Component var39 = var8[var43];
            if (var39.isVisible()) {
               GridBagConstraints var41 = this.lookupConstraints(var39);
               int var73 = var41.gridx;
               int var74 = var41.gridy;
               int var75 = var41.gridwidth;
               int var76 = var41.gridheight;
               if (var73 < 0 && var74 < 0) {
                  if (var21 >= 0) {
                     var74 = var21;
                  } else if (var22 >= 0) {
                     var73 = var22;
                  } else {
                     var74 = 0;
                  }
               }

               if (var73 < 0) {
                  if (var76 <= 0) {
                     var76 += var4.height - var74;
                     if (var76 < 1) {
                        var76 = 1;
                     }
                  }

                  int var65 = 0;

                  for(int var48 = var74; var48 < var74 + var76; ++var48) {
                     var65 = Math.max(var65, var31[var48]);
                  }

                  var73 = var65 - var73 - 1;
                  if (var73 < 0) {
                     var73 = 0;
                  }
               } else if (var74 < 0) {
                  if (var75 <= 0) {
                     var75 += var4.width - var73;
                     if (var75 < 1) {
                        var75 = 1;
                     }
                  }

                  int var69 = 0;

                  for(int var49 = var73; var49 < var73 + var75; ++var49) {
                     var69 = Math.max(var69, var32[var49]);
                  }

                  var74 = var69 - var74 - 1;
                  if (var74 < 0) {
                     var74 = 0;
                  }
               }

               if (var75 <= 0) {
                  var75 += var4.width - var73;
                  if (var75 < 1) {
                     var75 = 1;
                  }
               }

               if (var76 <= 0) {
                  var76 += var4.height - var74;
                  if (var76 < 1) {
                     var76 = 1;
                  }
               }

               int var66 = var73 + var75;
               int var70 = var74 + var76;

               for(int var50 = var73; var50 < var73 + var75; ++var50) {
                  var32[var50] = var70;
               }

               for(int var51 = var74; var51 < var74 + var76; ++var51) {
                  var31[var51] = var66;
               }

               if (var41.gridheight == 0 && var41.gridwidth == 0) {
                  var22 = -1;
                  var21 = -1;
               }

               if (var41.gridheight == 0 && var21 < 0) {
                  var22 = var73 + var75;
               } else if (var41.gridwidth == 0 && var22 < 0) {
                  var21 = var74 + var76;
               }

               var41.tempX = var73;
               var41.tempY = var74;
               var41.tempWidth = var75;
               var41.tempHeight = var76;
            }
         }

         if (this.columnWidths != null) {
            System.arraycopy(this.columnWidths, 0, var4.minWidth, 0, this.columnWidths.length);
         }

         if (this.rowHeights != null) {
            System.arraycopy(this.rowHeights, 0, var4.minHeight, 0, this.rowHeights.length);
         }

         if (this.columnWeights != null) {
            System.arraycopy(this.columnWeights, 0, var4.weightX, 0, this.columnWeights.length);
         }

         if (this.rowWeights != null) {
            System.arraycopy(this.rowWeights, 0, var4.weightY, 0, this.rowWeights.length);
         }

         int var16 = Integer.MAX_VALUE;

         for(int var52 = 1; var52 != Integer.MAX_VALUE; var16 = Integer.MAX_VALUE) {
            for(int var44 = 0; var44 < var8.length; ++var44) {
               Component var40 = var8[var44];
               if (var40.isVisible()) {
                  GridBagConstraints var42 = this.lookupConstraints(var40);
                  if (var42.tempWidth == var52) {
                     int var67 = var42.tempX + var42.tempWidth;
                     double var23 = var42.weightx;

                     for(int var12 = var42.tempX; var12 < var67; ++var12) {
                        var23 -= var4.weightX[var12];
                     }

                     if (var23 > (double)0.0F) {
                        double var25 = (double)0.0F;

                        for(int var53 = var42.tempX; var53 < var67; ++var53) {
                           var25 += var4.weightX[var53];
                        }

                        for(int var54 = var42.tempX; var25 > (double)0.0F && var54 < var67; ++var54) {
                           double var33 = var4.weightX[var54];
                           double var35 = var33 * var23 / var25;
                           double[] var10000 = var4.weightX;
                           var10000[var54] += var35;
                           var23 -= var35;
                           var25 -= var33;
                        }

                        double[] var91 = var4.weightX;
                        var91[var67 - 1] += var23;
                     }

                     int var15 = var42.minWidth + var42.ipadx + var42.insets.left + var42.insets.right;

                     for(int var55 = var42.tempX; var55 < var67; ++var55) {
                        var15 -= var4.minWidth[var55];
                     }

                     if (var15 > 0) {
                        double var80 = (double)0.0F;

                        for(int var56 = var42.tempX; var56 < var67; ++var56) {
                           var80 += var4.weightX[var56];
                        }

                        for(int var57 = var42.tempX; var80 > (double)0.0F && var57 < var67; ++var57) {
                           double var85 = var4.weightX[var57];
                           int var88 = (int)(var85 * (double)var15 / var80);
                           int[] var92 = var4.minWidth;
                           var92[var57] += var88;
                           var15 -= var88;
                           var80 -= var85;
                        }

                        int[] var93 = var4.minWidth;
                        var93[var67 - 1] += var15;
                     }
                  } else if (var42.tempWidth > var52 && var42.tempWidth < var16) {
                     var16 = var42.tempWidth;
                  }

                  if (var42.tempHeight != var52) {
                     if (var42.tempHeight > var52 && var42.tempHeight < var16) {
                        var16 = var42.tempHeight;
                     }
                  } else {
                     int var71 = var42.tempY + var42.tempHeight;
                     double var79 = var42.weighty;

                     for(int var58 = var42.tempY; var58 < var71; ++var58) {
                        var79 -= var4.weightY[var58];
                     }

                     if (var79 > (double)0.0F) {
                        double var81 = (double)0.0F;

                        for(int var59 = var42.tempY; var59 < var71; ++var59) {
                           var81 += var4.weightY[var59];
                        }

                        for(int var60 = var42.tempY; var81 > (double)0.0F && var60 < var71; ++var60) {
                           double var86 = var4.weightY[var60];
                           double var89 = var86 * var79 / var81;
                           double[] var94 = var4.weightY;
                           var94[var60] += var89;
                           var79 -= var89;
                           var81 -= var86;
                        }

                        double[] var95 = var4.weightY;
                        var95[var71 - 1] += var79;
                     }

                     int var72 = var42.minHeight + var42.ipady + var42.insets.top + var42.insets.bottom;

                     for(int var61 = var42.tempY; var61 < var71; ++var61) {
                        var72 -= var4.minHeight[var61];
                     }

                     if (var72 > 0) {
                        double var82 = (double)0.0F;

                        for(int var62 = var42.tempY; var62 < var71; ++var62) {
                           var82 += var4.weightY[var62];
                        }

                        for(int var63 = var42.tempY; var82 > (double)0.0F && var63 < var71; ++var63) {
                           double var87 = var4.weightY[var63];
                           int var90 = (int)(var87 * (double)var72 / var82);
                           int[] var96 = var4.minHeight;
                           var96[var63] += var90;
                           var72 -= var90;
                           var82 -= var87;
                        }

                        int[] var97 = var4.minHeight;
                        var97[var71 - 1] += var72;
                     }
                  }
               }
            }

            var52 = var16;
         }

         return var4;
      }
   }

   protected void AdjustForGravity(GridBagConstraints var1, Rectangle var2) {
      var2.x += var1.insets.left;
      var2.width -= var1.insets.left + var1.insets.right;
      var2.y += var1.insets.top;
      var2.height -= var1.insets.top + var1.insets.bottom;
      int var3 = 0;
      if (var1.fill != 2 && var1.fill != 1 && var2.width > var1.minWidth + var1.ipadx) {
         var3 = var2.width - (var1.minWidth + var1.ipadx);
         var2.width = var1.minWidth + var1.ipadx;
      }

      int var4 = 0;
      if (var1.fill != 3 && var1.fill != 1 && var2.height > var1.minHeight + var1.ipady) {
         var4 = var2.height - (var1.minHeight + var1.ipady);
         var2.height = var1.minHeight + var1.ipady;
      }

      switch (var1.anchor) {
         case 10:
            var2.x += var3 / 2;
            var2.y += var4 / 2;
            break;
         case 11:
            var2.x += var3 / 2;
            break;
         case 12:
            var2.x += var3;
            break;
         case 13:
            var2.x += var3;
            var2.y += var4 / 2;
            break;
         case 14:
            var2.x += var3;
            var2.y += var4;
            break;
         case 15:
            var2.x += var3 / 2;
            var2.y += var4;
            break;
         case 16:
            var2.y += var4;
            break;
         case 17:
            var2.y += var4 / 2;
         case 18:
            break;
         default:
            throw new IllegalArgumentException("illegal anchor value");
      }

   }

   protected Dimension GetMinSize(Container var1, GridBagLayoutInfo var2) {
      Dimension var3 = new Dimension();
      Insets var6 = var1.getInsets();
      int var5 = 0;

      for(int var4 = 0; var4 < var2.width; ++var4) {
         var5 += var2.minWidth[var4];
      }

      var3.width = var5 + var6.left + var6.right;
      var5 = 0;

      for(int var7 = 0; var7 < var2.height; ++var7) {
         var5 += var2.minHeight[var7];
      }

      var3.height = var5 + var6.top + var6.bottom;
      return var3;
   }

   protected void ArrangeGrid(Container var1) {
      Insets var5 = var1.getInsets();
      Component[] var6 = var1.getComponents();
      Rectangle var8 = new Rectangle();
      if (var6.length != 0 || this.columnWidths != null && this.columnWidths.length != 0 || this.rowHeights != null && this.rowHeights.length != 0) {
         GridBagLayoutInfo var14 = this.GetLayoutInfo(var1, 2);
         Dimension var7 = this.GetMinSize(var1, var14);
         if (var1.width < var7.width || var1.height < var7.height) {
            var14 = this.GetLayoutInfo(var1, 1);
            var7 = this.GetMinSize(var1, var14);
         }

         this.layoutInfo = var14;
         var8.width = var7.width;
         var8.height = var7.height;
         int var10 = var1.width - var8.width;
         if (var10 != 0) {
            double var12 = (double)0.0F;

            for(int var9 = 0; var9 < var14.width; ++var9) {
               var12 += var14.weightX[var9];
            }

            if (var12 > (double)0.0F) {
               for(int var16 = 0; var16 < var14.width; ++var16) {
                  int var15 = (int)((double)var10 * var14.weightX[var16] / var12);
                  int[] var10000 = var14.minWidth;
                  var10000[var16] += var15;
                  var8.width += var15;
                  if (var14.minWidth[var16] < 0) {
                     var8.width -= var14.minWidth[var16];
                     var14.minWidth[var16] = 0;
                  }
               }
            }

            var10 = var1.width - var8.width;
         } else {
            var10 = 0;
         }

         int var11 = var1.height - var8.height;
         if (var11 != 0) {
            double var25 = (double)0.0F;

            for(int var17 = 0; var17 < var14.height; ++var17) {
               var25 += var14.weightY[var17];
            }

            if (var25 > (double)0.0F) {
               for(int var18 = 0; var18 < var14.height; ++var18) {
                  int var26 = (int)((double)var11 * var14.weightY[var18] / var25);
                  int[] var27 = var14.minHeight;
                  var27[var18] += var26;
                  var8.height += var26;
                  if (var14.minHeight[var18] < 0) {
                     var8.height -= var14.minHeight[var18];
                     var14.minHeight[var18] = 0;
                  }
               }
            }

            var11 = var1.height - var8.height;
         } else {
            var11 = 0;
         }

         var14.startx = var10 / 2 + var5.left;
         var14.starty = var11 / 2 + var5.top;

         for(int var3 = 0; var3 < var6.length; ++var3) {
            Component var2 = var6[var3];
            if (var2.isVisible()) {
               GridBagConstraints var4 = this.lookupConstraints(var2);
               var8.x = var14.startx;

               for(int var19 = 0; var19 < var4.tempX; ++var19) {
                  var8.x += var14.minWidth[var19];
               }

               var8.y = var14.starty;

               for(int var20 = 0; var20 < var4.tempY; ++var20) {
                  var8.y += var14.minHeight[var20];
               }

               var8.width = 0;

               for(int var21 = var4.tempX; var21 < var4.tempX + var4.tempWidth; ++var21) {
                  var8.width += var14.minWidth[var21];
               }

               var8.height = 0;

               for(int var22 = var4.tempY; var22 < var4.tempY + var4.tempHeight; ++var22) {
                  var8.height += var14.minHeight[var22];
               }

               this.AdjustForGravity(var4, var8);
               if (var8.width > 0 && var8.height > 0) {
                  if (var2.x != var8.x || var2.y != var8.y || var2.width != var8.width || var2.height != var8.height) {
                     var2.setBounds(var8.x, var8.y, var8.width, var8.height);
                  }
               } else {
                  var2.setBounds(0, 0, 0, 0);
               }
            }
         }

      }
   }
}
