package java.awt;

import java.awt.event.InputEvent;
import java.awt.event.KeyEvent;
import java.awt.peer.MenuBarPeer;
import java.io.IOException;
import java.io.ObjectInputStream;
import java.io.ObjectOutputStream;
import java.util.Enumeration;
import java.util.Vector;
import javax.accessibility.Accessible;
import javax.accessibility.AccessibleContext;

public class MenuBar extends MenuComponent implements MenuContainer, Accessible {
   Vector menus = new Vector();
   Menu helpMenu;
   private static final String base = "menubar";
   private static int nameCounter;
   private static final long serialVersionUID = -4930327919388951260L;
   private int menuBarSerializedDataVersion = 1;

   String constructComponentName() {
      Class var1 = this.getClass();
      synchronized(var1) {
         String var2 = "menubar" + nameCounter++;
         return var2;
      }
   }

   public void addNotify() {
      Object var1 = ((MenuComponent)this).getTreeLock();
      synchronized(var1) {
         if (super.peer == null) {
            super.peer = Toolkit.getDefaultToolkit().createMenuBar(this);
         }

         int var2 = this.getMenuCount();

         for(int var3 = 0; var3 < var2; ++var3) {
            this.getMenu(var3).addNotify();
         }

      }
   }

   public void removeNotify() {
      Object var1 = ((MenuComponent)this).getTreeLock();
      synchronized(var1) {
         int var2 = this.getMenuCount();

         for(int var3 = 0; var3 < var2; ++var3) {
            this.getMenu(var3).removeNotify();
         }

         super.removeNotify();
      }
   }

   public Menu getHelpMenu() {
      return this.helpMenu;
   }

   public void setHelpMenu(Menu var1) {
      Object var2 = ((MenuComponent)this).getTreeLock();
      synchronized(var2) {
         if (this.helpMenu != var1) {
            if (this.helpMenu != null) {
               this.remove(this.helpMenu);
            }

            if (var1.parent != this) {
               this.add(var1);
            }

            this.helpMenu = var1;
            if (var1 != null) {
               var1.isHelpMenu = true;
               var1.parent = this;
               MenuBarPeer var3 = (MenuBarPeer)super.peer;
               if (var3 != null) {
                  if (var1.peer == null) {
                     var1.addNotify();
                  }

                  var3.addHelpMenu(var1);
               }
            }

         }
      }
   }

   public Menu add(Menu var1) {
      Object var2 = ((MenuComponent)this).getTreeLock();
      synchronized(var2) {
         if (var1.parent != null) {
            var1.parent.remove(var1);
         }

         this.menus.addElement(var1);
         var1.parent = this;
         MenuBarPeer var3 = (MenuBarPeer)super.peer;
         if (var3 != null) {
            if (var1.peer == null) {
               var1.addNotify();
            }

            var3.addMenu(var1);
         }

         return var1;
      }
   }

   public void remove(int var1) {
      Object var2 = ((MenuComponent)this).getTreeLock();
      synchronized(var2) {
         Menu var3 = this.getMenu(var1);
         this.menus.removeElementAt(var1);
         MenuBarPeer var4 = (MenuBarPeer)super.peer;
         if (var4 != null) {
            var3.removeNotify();
            var3.parent = null;
            var4.delMenu(var1);
         }

      }
   }

   public void remove(MenuComponent var1) {
      Object var2 = ((MenuComponent)this).getTreeLock();
      synchronized(var2) {
         int var3 = this.menus.indexOf(var1);
         if (var3 >= 0) {
            this.remove(var3);
         }

      }
   }

   public int getMenuCount() {
      return this.countMenus();
   }

   public int countMenus() {
      return this.getMenuCountImpl();
   }

   final int getMenuCountImpl() {
      return this.menus.size();
   }

   public Menu getMenu(int var1) {
      return this.getMenuImpl(var1);
   }

   final Menu getMenuImpl(int var1) {
      return (Menu)this.menus.elementAt(var1);
   }

   public synchronized Enumeration shortcuts() {
      Vector var1 = new Vector();
      int var2 = this.getMenuCount();

      for(int var3 = 0; var3 < var2; ++var3) {
         Enumeration var4 = this.getMenu(var3).shortcuts();

         while(var4.hasMoreElements()) {
            var1.addElement(var4.nextElement());
         }
      }

      return var1.elements();
   }

   public MenuItem getShortcutMenuItem(MenuShortcut var1) {
      int var2 = this.getMenuCount();

      for(int var3 = 0; var3 < var2; ++var3) {
         MenuItem var4 = this.getMenu(var3).getShortcutMenuItem(var1);
         if (var4 != null) {
            return var4;
         }
      }

      return null;
   }

   boolean handleShortcut(KeyEvent var1) {
      int var2 = ((AWTEvent)var1).getID();
      if (var2 != 401 && var2 != 402) {
         return false;
      } else {
         int var3 = Toolkit.getDefaultToolkit().getMenuShortcutKeyMask();
         if ((((InputEvent)var1).getModifiers() & var3) == 0) {
            return false;
         } else {
            int var4 = this.getMenuCount();

            for(int var5 = 0; var5 < var4; ++var5) {
               Menu var6 = this.getMenu(var5);
               if (var6.handleShortcut(var1)) {
                  return true;
               }
            }

            return false;
         }
      }
   }

   public void deleteShortcut(MenuShortcut var1) {
      int var2 = this.getMenuCount();

      for(int var3 = 0; var3 < var2; ++var3) {
         this.getMenu(var3).deleteShortcut(var1);
      }

   }

   private void writeObject(ObjectOutputStream var1) throws ClassNotFoundException, IOException {
      var1.defaultWriteObject();
   }

   private void readObject(ObjectInputStream var1) throws ClassNotFoundException, IOException {
      var1.defaultReadObject();

      for(int var2 = 0; var2 < this.menus.size(); ++var2) {
         Menu var3 = (Menu)this.menus.elementAt(var2);
         var3.parent = this;
      }

   }

   private static native void initIDs();

   public AccessibleContext getAccessibleContext() {
      if (super.accessibleContext == null) {
         super.accessibleContext = new AccessibleAWTMenuBar(this);
      }

      return super.accessibleContext;
   }

   static {
      Toolkit.loadLibraries();
      initIDs();
      nameCounter = 0;
   }
}
