package java.awt;

import java.awt.event.ActionEvent;
import java.awt.peer.MenuComponentPeer;
import java.io.IOException;
import java.io.ObjectInputStream;
import java.io.Serializable;
import javax.accessibility.AccessibleContext;
import javax.accessibility.AccessibleStateSet;
import sun.awt.AppContext;
import sun.awt.SunToolkit;

public abstract class MenuComponent implements Serializable {
   transient MenuComponentPeer peer;
   transient MenuContainer parent;
   transient AppContext appContext = AppContext.getAppContext();
   Font font;
   private String name;
   private boolean nameExplicitlySet = false;
   boolean newEventsOnly = false;
   static final String actionListenerK = "actionL";
   static final String itemListenerK = "itemL";
   private static final long serialVersionUID = -4536902356223894379L;
   private transient Object privateKey = new Object();
   AccessibleContext accessibleContext = null;

   public MenuComponent() {
      SunToolkit.insertTargetMapping(this, this.appContext);
   }

   String constructComponentName() {
      return null;
   }

   public String getName() {
      if (this.name == null && !this.nameExplicitlySet) {
         synchronized(this) {
            if (this.name == null && !this.nameExplicitlySet) {
               this.name = this.constructComponentName();
            }
         }
      }

      return this.name;
   }

   public void setName(String var1) {
      synchronized(this) {
         this.name = var1;
         this.nameExplicitlySet = true;
      }
   }

   public MenuContainer getParent() {
      return this.getParent_NoClientCode();
   }

   final MenuContainer getParent_NoClientCode() {
      return this.parent;
   }

   public MenuComponentPeer getPeer() {
      return this.peer;
   }

   public Font getFont() {
      Font var1 = this.font;
      if (var1 != null) {
         return var1;
      } else {
         MenuContainer var2 = this.parent;
         return var2 != null ? var2.getFont() : null;
      }
   }

   final Font getFont_NoClientCode() {
      Font var1 = this.font;
      if (var1 != null) {
         return var1;
      } else {
         MenuContainer var2 = this.parent;
         if (var2 != null) {
            if (var2 instanceof Component) {
               var1 = ((Component)var2).getFont_NoClientCode();
            } else if (var2 instanceof MenuComponent) {
               var1 = ((MenuComponent)var2).getFont_NoClientCode();
            }
         }

         return var1;
      }
   }

   public void setFont(Font var1) {
      this.font = var1;
   }

   public void removeNotify() {
      Object var1 = this.getTreeLock();
      synchronized(var1) {
         MenuComponentPeer var2 = this.peer;
         if (var2 != null) {
            Toolkit.getEventQueue().removeSourceEvents(this);
            this.peer = null;
            var2.dispose();
         }

      }
   }

   public boolean postEvent(Event var1) {
      MenuContainer var2 = this.parent;
      if (var2 != null) {
         var2.postEvent(var1);
      }

      return false;
   }

   public final void dispatchEvent(AWTEvent var1) {
      this.dispatchEventImpl(var1);
   }

   void dispatchEventImpl(AWTEvent var1) {
      Toolkit.getDefaultToolkit().notifyAWTEventListeners(var1);
      if (this.newEventsOnly || this.parent != null && this.parent instanceof MenuComponent && ((MenuComponent)this.parent).newEventsOnly) {
         if (this.eventEnabled(var1)) {
            this.processEvent(var1);
         } else if (var1 instanceof ActionEvent && this.parent != null) {
            ((MenuComponent)this.parent).dispatchEvent(new ActionEvent(this.parent, var1.getID(), ((ActionEvent)var1).getActionCommand()));
         }
      } else {
         Event var2 = var1.convertToOld();
         if (var2 != null) {
            this.postEvent(var2);
         }
      }

   }

   boolean eventEnabled(AWTEvent var1) {
      return false;
   }

   protected void processEvent(AWTEvent var1) {
   }

   protected String paramString() {
      String var1 = this.getName();
      return var1 != null ? var1 : "";
   }

   public String toString() {
      return this.getClass().getName() + "[" + this.paramString() + "]";
   }

   protected final Object getTreeLock() {
      return Component.LOCK;
   }

   private void readObject(ObjectInputStream var1) throws ClassNotFoundException, IOException {
      var1.defaultReadObject();
      this.privateKey = new Object();
      this.appContext = AppContext.getAppContext();
      SunToolkit.insertTargetMapping(this, this.appContext);
   }

   private static native void initIDs();

   public AccessibleContext getAccessibleContext() {
      return this.accessibleContext;
   }

   int getAccessibleIndexInParent() {
      return -1;
   }

   AccessibleStateSet getAccessibleStateSet() {
      AccessibleStateSet var1 = new AccessibleStateSet();
      return var1;
   }

   static {
      Toolkit.loadLibraries();
      initIDs();
   }
}
