package java.awt;

import java.awt.peer.TextAreaPeer;
import java.io.IOException;
import java.io.ObjectInputStream;
import javax.accessibility.AccessibleContext;

public class TextArea extends TextComponent {
   int rows;
   int columns;
   private static final String base = "text";
   private static int nameCounter = 0;
   public static final int SCROLLBARS_BOTH = 0;
   public static final int SCROLLBARS_VERTICAL_ONLY = 1;
   public static final int SCROLLBARS_HORIZONTAL_ONLY = 2;
   public static final int SCROLLBARS_NONE = 3;
   private int scrollbarVisibility;
   private static final long serialVersionUID = 3692302836626095722L;
   private int textAreaSerializedDataVersion;

   private static native void initIDs();

   public TextArea() {
      this("", 0, 0, 0);
   }

   public TextArea(String var1) {
      this(var1, 0, 0, 0);
   }

   public TextArea(int var1, int var2) {
      this("", var1, var2, 0);
   }

   public TextArea(String var1, int var2, int var3) {
      this(var1, var2, var3, 0);
   }

   public TextArea(String var1, int var2, int var3, int var4) {
      super(var1);
      this.textAreaSerializedDataVersion = 1;
      this.rows = var2 >= 0 ? var2 : 0;
      this.columns = var3 >= 0 ? var3 : 0;
      if (var4 >= 0 && var4 <= 3) {
         this.scrollbarVisibility = var4;
      } else {
         this.scrollbarVisibility = 0;
      }

   }

   String constructComponentName() {
      Class var1 = this.getClass();
      synchronized(var1) {
         String var2 = "text" + nameCounter++;
         return var2;
      }
   }

   public void addNotify() {
      Object var1 = ((Component)this).getTreeLock();
      synchronized(var1) {
         if (super.peer == null) {
            super.peer = ((Component)this).getToolkit().createTextArea(this);
         }

         super.addNotify();
      }
   }

   public void insert(String var1, int var2) {
      this.insertText(var1, var2);
   }

   public synchronized void insertText(String var1, int var2) {
      TextAreaPeer var3 = (TextAreaPeer)super.peer;
      if (var3 != null) {
         var3.insertText(var1, var2);
      } else {
         super.text = super.text.substring(0, var2) + var1 + super.text.substring(var2);
      }

   }

   public void append(String var1) {
      this.appendText(var1);
   }

   public synchronized void appendText(String var1) {
      if (super.peer != null) {
         this.insertText(var1, ((TextComponent)this).getText().length());
      } else {
         super.text = super.text + var1;
      }

   }

   public void replaceRange(String var1, int var2, int var3) {
      this.replaceText(var1, var2, var3);
   }

   public synchronized void replaceText(String var1, int var2, int var3) {
      TextAreaPeer var4 = (TextAreaPeer)super.peer;
      if (var4 != null) {
         var4.replaceText(var1, var2, var3);
      } else {
         super.text = super.text.substring(0, var2) + var1 + super.text.substring(var3);
      }

   }

   public int getRows() {
      return this.rows;
   }

   public void setRows(int var1) {
      int var2 = this.rows;
      if (var1 < 0) {
         throw new IllegalArgumentException("rows less than zero.");
      } else {
         if (var1 != var2) {
            this.rows = var1;
            ((Component)this).invalidate();
         }

      }
   }

   public int getColumns() {
      return this.columns;
   }

   public void setColumns(int var1) {
      int var2 = this.columns;
      if (var1 < 0) {
         throw new IllegalArgumentException("columns less than zero.");
      } else {
         if (var1 != var2) {
            this.columns = var1;
            ((Component)this).invalidate();
         }

      }
   }

   public int getScrollbarVisibility() {
      return this.scrollbarVisibility;
   }

   public Dimension getPreferredSize(int var1, int var2) {
      return this.preferredSize(var1, var2);
   }

   public Dimension preferredSize(int var1, int var2) {
      Object var3 = ((Component)this).getTreeLock();
      synchronized(var3) {
         TextAreaPeer var4 = (TextAreaPeer)super.peer;
         Dimension var5 = var4 != null ? var4.preferredSize(var1, var2) : super.preferredSize();
         return var5;
      }
   }

   public Dimension getPreferredSize() {
      return this.preferredSize();
   }

   public Dimension preferredSize() {
      Object var1 = ((Component)this).getTreeLock();
      synchronized(var1) {
         Dimension var2 = this.rows > 0 && this.columns > 0 ? this.preferredSize(this.rows, this.columns) : super.preferredSize();
         return var2;
      }
   }

   public Dimension getMinimumSize(int var1, int var2) {
      return this.minimumSize(var1, var2);
   }

   public Dimension minimumSize(int var1, int var2) {
      Object var3 = ((Component)this).getTreeLock();
      synchronized(var3) {
         TextAreaPeer var4 = (TextAreaPeer)super.peer;
         Dimension var5 = var4 != null ? var4.minimumSize(var1, var2) : super.minimumSize();
         return var5;
      }
   }

   public Dimension getMinimumSize() {
      return this.minimumSize();
   }

   public Dimension minimumSize() {
      Object var1 = ((Component)this).getTreeLock();
      synchronized(var1) {
         Dimension var2 = this.rows > 0 && this.columns > 0 ? this.minimumSize(this.rows, this.columns) : super.minimumSize();
         return var2;
      }
   }

   protected String paramString() {
      String var1;
      switch (this.scrollbarVisibility) {
         case 0:
            var1 = "both";
            break;
         case 1:
            var1 = "vertical-only";
            break;
         case 2:
            var1 = "horizontal-only";
            break;
         case 3:
            var1 = "none";
            break;
         default:
            var1 = "invalid display policy";
      }

      return super.paramString() + ",rows=" + this.rows + ",columns=" + this.columns + ", scrollbarVisibility=" + var1;
   }

   private void readObject(ObjectInputStream var1) throws ClassNotFoundException, IOException {
      var1.defaultReadObject();
      if (this.columns < 0) {
         this.columns = 0;
      }

      if (this.rows < 0) {
         this.rows = 0;
      }

      if (this.scrollbarVisibility < 0 || this.scrollbarVisibility > 3) {
         this.scrollbarVisibility = 0;
      }

   }

   public AccessibleContext getAccessibleContext() {
      if (super.accessibleContext == null) {
         super.accessibleContext = new AccessibleAWTTextArea(this);
      }

      return super.accessibleContext;
   }

   static {
      Toolkit.loadLibraries();
      initIDs();
   }
}
