package java.awt;

import java.awt.geom.AffineTransform;
import java.awt.geom.NoninvertibleTransformException;
import java.awt.image.BufferedImage;
import java.awt.image.ColorModel;
import java.awt.image.DirectColorModel;
import java.awt.image.IndexColorModel;
import java.awt.image.Raster;
import java.awt.image.WritableRaster;
import sun.awt.image.ByteInterleavedRaster;
import sun.awt.image.IntegerInterleavedRaster;

abstract class TexturePaintContext implements PaintContext {
   ColorModel colorModel;
   int bWidth;
   int bHeight;
   int maxWidth;
   WritableRaster outRas;
   double xOrg;
   double yOrg;
   double incXAcross;
   double incYAcross;
   double incXDown;
   double incYDown;
   int colincx;
   int colincy;
   int colincxerr;
   int colincyerr;
   int rowincx;
   int rowincy;
   int rowincxerr;
   int rowincyerr;

   public static PaintContext getContext(BufferedImage var0, AffineTransform var1, RenderingHints var2, Rectangle var3) {
      WritableRaster var4 = var0.getRaster();
      ColorModel var5 = var0.getColorModel();
      int var6 = var3.width;
      Object var7 = var2.get(RenderingHints.KEY_INTERPOLATION);
      boolean var8 = var7 == null ? var2.get(RenderingHints.KEY_RENDERING) == RenderingHints.VALUE_RENDER_QUALITY : var7 != RenderingHints.VALUE_INTERPOLATION_NEAREST_NEIGHBOR;
      if (var4 instanceof IntegerInterleavedRaster && (!var8 || isFilterableDCM(var5))) {
         IntegerInterleavedRaster var10 = (IntegerInterleavedRaster)var4;
         if (((Raster)var10).getNumDataElements() == 1 && var10.getPixelStride() == 1) {
            return new Int(var10, var5, var1, var6, var8);
         }
      } else if (var4 instanceof ByteInterleavedRaster) {
         ByteInterleavedRaster var9 = (ByteInterleavedRaster)var4;
         if (((Raster)var9).getNumDataElements() == 1 && var9.getPixelStride() == 1) {
            if (!var8) {
               return new Byte(var9, var5, var1, var6);
            }

            if (isFilterableICM(var5)) {
               return new ByteFilter(var9, var5, var1, var6);
            }
         }
      }

      return new Any(var4, var5, var1, var6, var8);
   }

   public static boolean isFilterableICM(ColorModel var0) {
      if (var0 instanceof IndexColorModel) {
         IndexColorModel var1 = (IndexColorModel)var0;
         if (var1.getMapSize() <= 256) {
            return true;
         }
      }

      return false;
   }

   public static boolean isFilterableDCM(ColorModel var0) {
      if (!(var0 instanceof DirectColorModel)) {
         return false;
      } else {
         DirectColorModel var1 = (DirectColorModel)var0;
         return isMaskOK(var1.getAlphaMask(), true) && isMaskOK(var1.getRedMask(), false) && isMaskOK(var1.getGreenMask(), false) && isMaskOK(var1.getBlueMask(), false);
      }
   }

   public static boolean isMaskOK(int var0, boolean var1) {
      if (var1 && var0 == 0) {
         return true;
      } else {
         return var0 == 255 || var0 == 65280 || var0 == 16711680 || var0 == -16777216;
      }
   }

   TexturePaintContext(ColorModel var1, AffineTransform var2, int var3, int var4, int var5) {
      this.colorModel = var1;
      this.bWidth = var3;
      this.bHeight = var4;
      this.maxWidth = var5;

      try {
         var2 = var2.createInverse();
      } catch (NoninvertibleTransformException var7) {
         var2.setToScale((double)0.0F, (double)0.0F);
      }

      this.incXAcross = mod(var2.getScaleX(), (double)var3);
      this.incYAcross = mod(var2.getShearY(), (double)var4);
      this.incXDown = mod(var2.getShearX(), (double)var3);
      this.incYDown = mod(var2.getScaleY(), (double)var4);
      this.xOrg = var2.getTranslateX();
      this.yOrg = var2.getTranslateY();
      this.colincx = (int)this.incXAcross;
      this.colincy = (int)this.incYAcross;
      this.colincxerr = fractAsInt(this.incXAcross);
      this.colincyerr = fractAsInt(this.incYAcross);
      this.rowincx = (int)this.incXDown;
      this.rowincy = (int)this.incYDown;
      this.rowincxerr = fractAsInt(this.incXDown);
      this.rowincyerr = fractAsInt(this.incYDown);
   }

   static int fractAsInt(double var0) {
      return (int)(var0 % (double)1.0F * (double)Integer.MAX_VALUE);
   }

   static double mod(double var0, double var2) {
      var0 %= var2;
      if (var0 < (double)0.0F) {
         var0 += var2;
         if (var0 >= var2) {
            var0 = (double)0.0F;
         }
      }

      return var0;
   }

   public void dispose() {
   }

   public ColorModel getColorModel() {
      return this.colorModel;
   }

   public Raster getRaster(int var1, int var2, int var3, int var4) {
      if (this.outRas == null || this.outRas.getWidth() < var3 || this.outRas.getHeight() < var4) {
         this.outRas = this.makeRaster(var4 == 1 ? Math.max(var3, this.maxWidth) : var3, var4);
      }

      double var5 = mod(this.xOrg + (double)var1 * this.incXAcross + (double)var2 * this.incXDown, (double)this.bWidth);
      double var7 = mod(this.yOrg + (double)var1 * this.incYAcross + (double)var2 * this.incYDown, (double)this.bHeight);
      this.setRaster((int)var5, (int)var7, fractAsInt(var5), fractAsInt(var7), var3, var4, this.bWidth, this.bHeight, this.colincx, this.colincxerr, this.colincy, this.colincyerr, this.rowincx, this.rowincxerr, this.rowincy, this.rowincyerr);
      return this.outRas;
   }

   public abstract WritableRaster makeRaster(int var1, int var2);

   public abstract void setRaster(int var1, int var2, int var3, int var4, int var5, int var6, int var7, int var8, int var9, int var10, int var11, int var12, int var13, int var14, int var15, int var16);

   public static int blend(int[] var0, int var1, int var2) {
      var1 >>>= 19;
      var2 >>>= 19;
      int var6 = 0;
      int var5 = 0;
      int var4 = 0;
      int var3 = 0;

      for(int var7 = 0; var7 < 4; ++var7) {
         int var8 = var0[var7];
         var1 = 4096 - var1;
         if ((var7 & 1) == 0) {
            var2 = 4096 - var2;
         }

         int var9 = var1 * var2;
         if (var9 != 0) {
            var3 += (var8 >>> 24) * var9;
            var4 += (var8 >>> 16 & 255) * var9;
            var5 += (var8 >>> 8 & 255) * var9;
            var6 += (var8 & 255) * var9;
         }
      }

      return var3 + 8388608 >>> 24 << 24 | var4 + 8388608 >>> 24 << 16 | var5 + 8388608 >>> 24 << 8 | var6 + 8388608 >>> 24;
   }
}
