package java.awt;

import java.awt.datatransfer.Clipboard;
import java.awt.dnd.DragGestureEvent;
import java.awt.dnd.DragGestureListener;
import java.awt.dnd.DragGestureRecognizer;
import java.awt.dnd.DragSource;
import java.awt.dnd.InvalidDnDOperationException;
import java.awt.dnd.peer.DragSourceContextPeer;
import java.awt.event.AWTEventListener;
import java.awt.im.InputMethodHighlight;
import java.awt.image.ColorModel;
import java.awt.image.ImageObserver;
import java.awt.image.ImageProducer;
import java.awt.peer.ButtonPeer;
import java.awt.peer.CanvasPeer;
import java.awt.peer.CheckboxMenuItemPeer;
import java.awt.peer.CheckboxPeer;
import java.awt.peer.ChoicePeer;
import java.awt.peer.DialogPeer;
import java.awt.peer.FileDialogPeer;
import java.awt.peer.FontPeer;
import java.awt.peer.FramePeer;
import java.awt.peer.LabelPeer;
import java.awt.peer.ListPeer;
import java.awt.peer.MenuBarPeer;
import java.awt.peer.MenuItemPeer;
import java.awt.peer.MenuPeer;
import java.awt.peer.PanelPeer;
import java.awt.peer.PopupMenuPeer;
import java.awt.peer.ScrollPanePeer;
import java.awt.peer.ScrollbarPeer;
import java.awt.peer.TextAreaPeer;
import java.awt.peer.TextFieldPeer;
import java.awt.peer.WindowPeer;
import java.beans.PropertyChangeListener;
import java.beans.PropertyChangeSupport;
import java.io.File;
import java.net.URL;
import java.security.AccessController;
import java.util.HashMap;
import java.util.Map;
import java.util.MissingResourceException;
import java.util.Properties;
import java.util.ResourceBundle;
import java.util.StringTokenizer;
import java.util.WeakHashMap;
import sun.security.action.LoadLibraryAction;

public abstract class Toolkit {
   private static LightweightPeer lightweightMarker;
   private static Toolkit toolkit;
   private static ResourceBundle resources;
   private static boolean loaded = false;
   protected final Map desktopProperties = new HashMap();
   protected final PropertyChangeSupport desktopPropsSupport = new PropertyChangeSupport(this);
   private AWTEventListener eventListener = null;
   private WeakHashMap listener2SelectiveListener = new WeakHashMap();
   private AWTPermission listenToAllAWTEventsPermission = null;

   protected abstract ButtonPeer createButton(Button var1);

   protected abstract TextFieldPeer createTextField(TextField var1);

   protected abstract LabelPeer createLabel(Label var1);

   protected abstract ListPeer createList(List var1);

   protected abstract CheckboxPeer createCheckbox(Checkbox var1);

   protected abstract ScrollbarPeer createScrollbar(Scrollbar var1);

   protected abstract ScrollPanePeer createScrollPane(ScrollPane var1);

   protected abstract TextAreaPeer createTextArea(TextArea var1);

   protected abstract ChoicePeer createChoice(Choice var1);

   protected abstract FramePeer createFrame(Frame var1);

   protected abstract CanvasPeer createCanvas(Canvas var1);

   protected abstract PanelPeer createPanel(Panel var1);

   protected abstract WindowPeer createWindow(Window var1);

   protected abstract DialogPeer createDialog(Dialog var1);

   protected abstract MenuBarPeer createMenuBar(MenuBar var1);

   protected abstract MenuPeer createMenu(Menu var1);

   protected abstract PopupMenuPeer createPopupMenu(PopupMenu var1);

   protected abstract MenuItemPeer createMenuItem(MenuItem var1);

   protected abstract FileDialogPeer createFileDialog(FileDialog var1);

   protected abstract CheckboxMenuItemPeer createCheckboxMenuItem(CheckboxMenuItem var1);

   protected java.awt.peer.LightweightPeer createComponent(Component var1) {
      if (lightweightMarker == null) {
         lightweightMarker = new LightweightPeer(var1);
      }

      return lightweightMarker;
   }

   protected abstract FontPeer getFontPeer(String var1, int var2);

   protected void loadSystemColors(int[] var1) {
   }

   public abstract Dimension getScreenSize();

   public abstract int getScreenResolution();

   public abstract ColorModel getColorModel();

   public abstract String[] getFontList();

   public abstract FontMetrics getFontMetrics(Font var1);

   public abstract void sync();

   private static void loadAssistiveTechnologies() {
      String var0 = File.separator;
      Properties var1 = new Properties();
      AccessController.doPrivileged(new 1(var0, var1));
      String var2 = var1.getProperty("assistive_technologies", (String)null);
      ClassLoader var3 = ClassLoader.getSystemClassLoader();
      if (var2 != null) {
         StringTokenizer var4 = new StringTokenizer(var2, " ,");

         while(var4.hasMoreTokens()) {
            String var5 = var4.nextToken();

            try {
               Class var6;
               if (var3 != null) {
                  var6 = var3.loadClass(var5);
               } else {
                  var6 = Class.forName(var5);
               }

               var6.newInstance();
            } catch (ClassNotFoundException var10) {
               throw new AWTError("Assistive Technology not found: " + var5);
            } catch (InstantiationException var11) {
               throw new AWTError("Could not instantiate Assistive Technology: " + var5);
            } catch (IllegalAccessException var12) {
               throw new AWTError("Could not access Assistive Technology: " + var5);
            } catch (Exception var13) {
               throw new AWTError("Error trying to install Assistive Technology: " + var5 + " " + var13);
            }
         }
      }

   }

   public static synchronized Toolkit getDefaultToolkit() {
      if (toolkit == null) {
         try {
            Compiler.disable();
            AccessController.doPrivileged(new 2());
            loadAssistiveTechnologies();
         } finally {
            Compiler.enable();
         }
      }

      return toolkit;
   }

   public abstract Image getImage(String var1);

   public abstract Image getImage(URL var1);

   public abstract Image createImage(String var1);

   public abstract Image createImage(URL var1);

   public abstract boolean prepareImage(Image var1, int var2, int var3, ImageObserver var4);

   public abstract int checkImage(Image var1, int var2, int var3, ImageObserver var4);

   public abstract Image createImage(ImageProducer var1);

   public Image createImage(byte[] var1) {
      return this.createImage(var1, 0, var1.length);
   }

   public abstract Image createImage(byte[] var1, int var2, int var3);

   public abstract PrintJob getPrintJob(Frame var1, String var2, Properties var3);

   public PrintJob getPrintJob(Frame var1, String var2, JobAttributes var3, PageAttributes var4) {
      return this != getDefaultToolkit() ? getDefaultToolkit().getPrintJob(var1, var2, var3, var4) : this.getPrintJob(var1, var2, (Properties)null);
   }

   public abstract void beep();

   public abstract Clipboard getSystemClipboard();

   public int getMenuShortcutKeyMask() {
      return 2;
   }

   public boolean getLockingKeyState(int var1) {
      if (var1 != 20 && var1 != 144 && var1 != 145 && var1 != 262) {
         throw new IllegalArgumentException("invalid key for Toolkit.getLockingKeyState");
      } else {
         throw new UnsupportedOperationException("Toolkit.getLockingKeyState");
      }
   }

   public void setLockingKeyState(int var1, boolean var2) {
      if (var1 != 20 && var1 != 144 && var1 != 145 && var1 != 262) {
         throw new IllegalArgumentException("invalid key for Toolkit.setLockingKeyState");
      } else {
         throw new UnsupportedOperationException("Toolkit.setLockingKeyState");
      }
   }

   protected static Container getNativeContainer(Component var0) {
      return var0.getNativeContainer();
   }

   public Cursor createCustomCursor(Image var1, Point var2, String var3) throws IndexOutOfBoundsException {
      return this != getDefaultToolkit() ? getDefaultToolkit().createCustomCursor(var1, var2, var3) : new Cursor(0);
   }

   public Dimension getBestCursorSize(int var1, int var2) {
      return this != getDefaultToolkit() ? getDefaultToolkit().getBestCursorSize(var1, var2) : new Dimension(0, 0);
   }

   public int getMaximumCursorColors() {
      return this != getDefaultToolkit() ? getDefaultToolkit().getMaximumCursorColors() : 0;
   }

   private static native void initIDs();

   static void loadLibraries() {
      if (!loaded) {
         AccessController.doPrivileged(new LoadLibraryAction("awt"));
         loaded = true;
      }

   }

   public static String getProperty(String var0, String var1) {
      if (resources != null) {
         try {
            return resources.getString(var0);
         } catch (MissingResourceException var3) {
         }
      }

      return var1;
   }

   public final EventQueue getSystemEventQueue() {
      SecurityManager var1 = System.getSecurityManager();
      if (var1 != null) {
         var1.checkAwtEventQueueAccess();
      }

      return this.getSystemEventQueueImpl();
   }

   protected abstract EventQueue getSystemEventQueueImpl();

   static EventQueue getEventQueue() {
      return getDefaultToolkit().getSystemEventQueueImpl();
   }

   public abstract DragSourceContextPeer createDragSourceContextPeer(DragGestureEvent var1) throws InvalidDnDOperationException;

   public DragGestureRecognizer createDragGestureRecognizer(Class var1, DragSource var2, Component var3, int var4, DragGestureListener var5) {
      return null;
   }

   public final synchronized Object getDesktopProperty(String var1) {
      if (this.desktopProperties.isEmpty()) {
         this.initializeDesktopProperties();
      }

      Object var2 = this.desktopProperties.get(var1);
      if (var2 == null) {
         var2 = this.lazilyLoadDesktopProperty(var1);
         if (var2 != null) {
            this.setDesktopProperty(var1, var2);
         }
      }

      return var2;
   }

   protected final void setDesktopProperty(String var1, Object var2) {
      Object var3;
      synchronized(this) {
         var3 = this.desktopProperties.get(var1);
         this.desktopProperties.put(var1, var2);
      }

      this.desktopPropsSupport.firePropertyChange(var1, var3, var2);
   }

   protected Object lazilyLoadDesktopProperty(String var1) {
      return null;
   }

   protected void initializeDesktopProperties() {
   }

   public synchronized void addPropertyChangeListener(String var1, PropertyChangeListener var2) {
      if (var2 != null) {
         this.desktopPropsSupport.addPropertyChangeListener(var1, var2);
      }
   }

   public synchronized void removePropertyChangeListener(String var1, PropertyChangeListener var2) {
      if (var2 != null) {
         this.desktopPropsSupport.removePropertyChangeListener(var1, var2);
      }
   }

   public void addAWTEventListener(AWTEventListener var1, long var2) {
      if (var1 != null) {
         SecurityManager var4 = System.getSecurityManager();
         if (var4 != null) {
            if (this.listenToAllAWTEventsPermission == null) {
               this.listenToAllAWTEventsPermission = new AWTPermission("listenToAllAWTEvents");
            }

            var4.checkPermission(this.listenToAllAWTEventsPermission);
         }

         synchronized(this) {
            SelectiveAWTEventListener var6 = (SelectiveAWTEventListener)this.listener2SelectiveListener.get(var1);
            if (var6 == null) {
               var6 = new SelectiveAWTEventListener(this, var1, var2);
               this.listener2SelectiveListener.put(var1, var6);
               this.eventListener = java.awt.Toolkit.ToolkitEventMulticaster.add(this.eventListener, var6);
            }

            var6.orEventMasks(var2);
         }
      }
   }

   public void removeAWTEventListener(AWTEventListener var1) {
      if (var1 != null) {
         SecurityManager var2 = System.getSecurityManager();
         if (var2 != null) {
            if (this.listenToAllAWTEventsPermission == null) {
               this.listenToAllAWTEventsPermission = new AWTPermission("listenToAllAWTEvents");
            }

            var2.checkPermission(this.listenToAllAWTEventsPermission);
         }

         synchronized(this) {
            SelectiveAWTEventListener var4 = (SelectiveAWTEventListener)this.listener2SelectiveListener.get(var1);
            if (var4 != null) {
               this.listener2SelectiveListener.remove(var1);
            }

            this.eventListener = java.awt.Toolkit.ToolkitEventMulticaster.remove(this.eventListener, (AWTEventListener)(var4 == null ? var1 : var4));
         }
      }
   }

   void notifyAWTEventListeners(AWTEvent var1) {
      if (this.eventListener != null) {
         synchronized(this) {
            if (this.eventListener != null) {
               this.eventListener.eventDispatched(var1);
            }
         }
      }

   }

   public abstract Map mapInputMethodHighlight(InputMethodHighlight var1);

   // $FF: synthetic method
   static Toolkit access$002(Toolkit var0) {
      toolkit = var0;
      return var0;
   }

   // $FF: synthetic method
   static ResourceBundle access$102(ResourceBundle var0) {
      resources = var0;
      return var0;
   }

   static {
      AccessController.doPrivileged(new 3());
      loadLibraries();
      initIDs();
   }
}
