package java.awt.color;

import java.io.Serializable;

public abstract class ColorSpace implements Serializable {
   private int type;
   private int numComponents;
   private static ColorSpace sRGBspace;
   private static ColorSpace XYZspace;
   private static ColorSpace PYCCspace;
   private static ColorSpace GRAYspace;
   private static ColorSpace LINEAR_RGBspace;
   public static final int TYPE_XYZ = 0;
   public static final int TYPE_Lab = 1;
   public static final int TYPE_Luv = 2;
   public static final int TYPE_YCbCr = 3;
   public static final int TYPE_Yxy = 4;
   public static final int TYPE_RGB = 5;
   public static final int TYPE_GRAY = 6;
   public static final int TYPE_HSV = 7;
   public static final int TYPE_HLS = 8;
   public static final int TYPE_CMYK = 9;
   public static final int TYPE_CMY = 11;
   public static final int TYPE_2CLR = 12;
   public static final int TYPE_3CLR = 13;
   public static final int TYPE_4CLR = 14;
   public static final int TYPE_5CLR = 15;
   public static final int TYPE_6CLR = 16;
   public static final int TYPE_7CLR = 17;
   public static final int TYPE_8CLR = 18;
   public static final int TYPE_9CLR = 19;
   public static final int TYPE_ACLR = 20;
   public static final int TYPE_BCLR = 21;
   public static final int TYPE_CCLR = 22;
   public static final int TYPE_DCLR = 23;
   public static final int TYPE_ECLR = 24;
   public static final int TYPE_FCLR = 25;
   public static final int CS_sRGB = 1000;
   public static final int CS_LINEAR_RGB = 1004;
   public static final int CS_CIEXYZ = 1001;
   public static final int CS_PYCC = 1002;
   public static final int CS_GRAY = 1003;

   protected ColorSpace(int var1, int var2) {
      this.type = var1;
      this.numComponents = var2;
   }

   public static ColorSpace getInstance(int var0) {
      ColorSpace var1;
      switch (var0) {
         case 1000:
            if (sRGBspace == null) {
               ICC_Profile var6 = ICC_Profile.getInstance(1000);
               sRGBspace = new ICC_ColorSpace(var6);
            }

            var1 = sRGBspace;
            break;
         case 1001:
            if (XYZspace == null) {
               ICC_Profile var5 = ICC_Profile.getInstance(1001);
               XYZspace = new ICC_ColorSpace(var5);
            }

            var1 = XYZspace;
            break;
         case 1002:
            if (PYCCspace == null) {
               ICC_Profile var4 = ICC_Profile.getInstance(1002);
               PYCCspace = new ICC_ColorSpace(var4);
            }

            var1 = PYCCspace;
            break;
         case 1003:
            if (GRAYspace == null) {
               ICC_Profile var3 = ICC_Profile.getInstance(1003);
               GRAYspace = new ICC_ColorSpace(var3);
            }

            var1 = GRAYspace;
            break;
         case 1004:
            if (LINEAR_RGBspace == null) {
               ICC_Profile var2 = ICC_Profile.getInstance(1004);
               LINEAR_RGBspace = new ICC_ColorSpace(var2);
            }

            var1 = LINEAR_RGBspace;
            break;
         default:
            throw new IllegalArgumentException("Unknown color space");
      }

      return var1;
   }

   public boolean isCS_sRGB() {
      return this == sRGBspace;
   }

   public abstract float[] toRGB(float[] var1);

   public abstract float[] fromRGB(float[] var1);

   public abstract float[] toCIEXYZ(float[] var1);

   public abstract float[] fromCIEXYZ(float[] var1);

   public int getType() {
      return this.type;
   }

   public int getNumComponents() {
      return this.numComponents;
   }

   public String getName(int var1) {
      return new String("Unnamed color component(" + var1 + ")");
   }

   static boolean isCS_CIEXYZ(ColorSpace var0) {
      return var0 == XYZspace;
   }
}
