package java.awt.color;

import sun.awt.color.ICC_Transform;

public class ICC_ColorSpace extends ColorSpace {
   private ICC_Profile thisProfile;
   private transient ICC_Transform this2srgb;
   private transient ICC_Transform srgb2this;
   private transient ICC_Transform this2xyz;
   private transient ICC_Transform xyz2this;

   public ICC_ColorSpace(ICC_Profile var1) {
      super(var1.getColorSpaceType(), var1.getNumComponents());
      int var2 = var1.getProfileClass();
      if (var2 != 0 && var2 != 1 && var2 != 2 && var2 != 4 && var2 != 6) {
         throw new IllegalArgumentException("Invalid profile type");
      } else {
         this.thisProfile = var1;
      }
   }

   public ICC_Profile getProfile() {
      return this.thisProfile;
   }

   public float[] toRGB(float[] var1) {
      if (this.this2srgb == null) {
         ICC_Transform[] var2 = new ICC_Transform[2];
         ICC_ColorSpace var4 = (ICC_ColorSpace)ColorSpace.getInstance(1000);
         var2[0] = new ICC_Transform(this.thisProfile, -1, 1);
         var2[1] = new ICC_Transform(var4.getProfile(), -1, 2);
         this.this2srgb = new ICC_Transform(var2);
      }

      float[] var5;
      if (ColorSpace.isCS_CIEXYZ(this)) {
         var5 = new float[3];
         float var6 = 0.5000076F;
         var5[0] = var1[0] * var6;
         var5[1] = var1[1] * var6;
         var5[2] = var1[2] * var6;
      } else {
         var5 = var1;
      }

      float[] var3 = new float[3];
      this.this2srgb.colorConvert(1, var5, var3);
      return var3;
   }

   public float[] fromRGB(float[] var1) {
      if (this.srgb2this == null) {
         ICC_Transform[] var2 = new ICC_Transform[2];
         ICC_ColorSpace var4 = (ICC_ColorSpace)ColorSpace.getInstance(1000);
         var2[0] = new ICC_Transform(var4.getProfile(), -1, 1);
         var2[1] = new ICC_Transform(this.thisProfile, -1, 2);
         this.srgb2this = new ICC_Transform(var2);
      }

      float[] var3 = new float[((ColorSpace)this).getNumComponents()];
      this.srgb2this.colorConvert(1, var1, var3);
      if (ColorSpace.isCS_CIEXYZ(this)) {
         float var5 = 1.9999695F;
         var3[0] *= var5;
         var3[1] *= var5;
         var3[2] *= var5;
      }

      return var3;
   }

   public float[] toCIEXYZ(float[] var1) {
      if (this.this2xyz == null) {
         ICC_Transform[] var2 = new ICC_Transform[2];
         ICC_ColorSpace var4 = (ICC_ColorSpace)ColorSpace.getInstance(1001);

         try {
            var2[0] = new ICC_Transform(this.thisProfile, 1, 1);
         } catch (CMMException var6) {
            var2[0] = new ICC_Transform(this.thisProfile, -1, 1);
         }

         var2[1] = new ICC_Transform(var4.getProfile(), -1, 2);
         this.this2xyz = new ICC_Transform(var2);
      }

      float[] var3 = new float[3];
      this.this2xyz.colorConvert(1, var1, var3);
      float var5 = 1.9999695F;
      var3[0] *= var5;
      var3[1] *= var5;
      var3[2] *= var5;
      return var3;
   }

   public float[] fromCIEXYZ(float[] var1) {
      if (this.xyz2this == null) {
         ICC_Transform[] var2 = new ICC_Transform[2];
         ICC_ColorSpace var4 = (ICC_ColorSpace)ColorSpace.getInstance(1001);
         var2[0] = new ICC_Transform(var4.getProfile(), -1, 1);

         try {
            var2[1] = new ICC_Transform(this.thisProfile, 1, 2);
         } catch (CMMException var7) {
            var2[1] = new ICC_Transform(this.thisProfile, -1, 2);
         }

         this.xyz2this = new ICC_Transform(var2);
      }

      float[] var5 = new float[3];
      float var6 = 0.5000076F;
      var5[0] = var1[0] * var6;
      var5[1] = var1[1] * var6;
      var5[2] = var1[2] * var6;
      float[] var3 = new float[((ColorSpace)this).getNumComponents()];
      this.xyz2this.colorConvert(1, var5, var3);
      return var3;
   }
}
