package java.awt.datatransfer;

import java.io.Externalizable;
import java.io.IOException;
import java.io.ObjectInput;
import java.io.ObjectOutput;

class MimeType implements Externalizable, Cloneable {
   static final long serialVersionUID = -6568722458793895906L;
   private String primaryType;
   private String subType;
   private MimeTypeParameterList parameters;
   private static final String TSPECIALS = "()<>@,;:\\\"/[]?=";

   public MimeType() {
   }

   public MimeType(String var1) throws MimeTypeParseException {
      this.parse(var1);
   }

   public MimeType(String var1, String var2) throws MimeTypeParseException {
      this(var1, var2, new MimeTypeParameterList());
   }

   public MimeType(String var1, String var2, MimeTypeParameterList var3) throws MimeTypeParseException {
      if (this.isValidToken(var1)) {
         this.primaryType = var1.toLowerCase();
         if (this.isValidToken(var2)) {
            this.subType = var2.toLowerCase();

            try {
               var3 = (MimeTypeParameterList)var3.clone();
            } catch (CloneNotSupportedException var6) {
               throw new RuntimeException("failed to clone parameter list");
            }

            try {
               this.parameters = (MimeTypeParameterList)var3.clone();
            } catch (CloneNotSupportedException var5) {
               throw new RuntimeException("cannot clone parameter list");
            }
         } else {
            throw new MimeTypeParseException("Sub type is invalid.");
         }
      } else {
         throw new MimeTypeParseException("Primary type is invalid.");
      }
   }

   public int hashCode() {
      int var1 = 0;
      var1 += this.primaryType.hashCode();
      var1 += this.subType.hashCode();
      var1 += this.parameters.hashCode();
      return var1;
   }

   public boolean equals(Object var1) {
      if (!(var1 instanceof MimeType)) {
         return false;
      } else {
         MimeType var2 = (MimeType)var1;
         boolean var3 = this.primaryType.equals(var2.primaryType) && this.subType.equals(var2.subType) && this.parameters.equals(var2.parameters);
         return var3;
      }
   }

   private void parse(String var1) throws MimeTypeParseException {
      int var2 = var1.indexOf(47);
      int var3 = var1.indexOf(59);
      if (var2 < 0 && var3 < 0) {
         throw new MimeTypeParseException("Unable to find a sub type.");
      } else if (var2 < 0 && var3 >= 0) {
         throw new MimeTypeParseException("Unable to find a sub type.");
      } else {
         if (var2 >= 0 && var3 < 0) {
            this.primaryType = var1.substring(0, var2).trim().toLowerCase();
            this.subType = var1.substring(var2 + 1).trim().toLowerCase();
            this.parameters = new MimeTypeParameterList();
         } else {
            if (var2 >= var3) {
               throw new MimeTypeParseException("Unable to find a sub type.");
            }

            this.primaryType = var1.substring(0, var2).trim().toLowerCase();
            this.subType = var1.substring(var2 + 1, var3).trim().toLowerCase();
            this.parameters = new MimeTypeParameterList(var1.substring(var3));
         }

         if (!this.isValidToken(this.primaryType)) {
            throw new MimeTypeParseException("Primary type is invalid.");
         } else if (!this.isValidToken(this.subType)) {
            throw new MimeTypeParseException("Sub type is invalid.");
         }
      }
   }

   public String getPrimaryType() {
      return this.primaryType;
   }

   public String getSubType() {
      return this.subType;
   }

   public MimeTypeParameterList getParameters() {
      try {
         return (MimeTypeParameterList)this.parameters.clone();
      } catch (CloneNotSupportedException var2) {
         throw new RuntimeException("cannot clone parameter list");
      }
   }

   public String getParameter(String var1) {
      return this.parameters.get(var1);
   }

   public void setParameter(String var1, String var2) {
      this.parameters.set(var1, var2);
   }

   public void removeParameter(String var1) {
      this.parameters.remove(var1);
   }

   public String toString() {
      return this.getBaseType() + this.parameters.toString();
   }

   public String getBaseType() {
      return this.primaryType + "/" + this.subType;
   }

   public boolean match(MimeType var1) {
      if (var1 == null) {
         return false;
      } else {
         return this.primaryType.equals(var1.getPrimaryType()) && (this.subType.equals("*") || var1.getSubType().equals("*") || this.subType.equals(var1.getSubType()));
      }
   }

   public boolean match(String var1) throws MimeTypeParseException {
      return var1 == null ? false : this.match(new MimeType(var1));
   }

   public void writeExternal(ObjectOutput var1) throws IOException {
      var1.writeUTF(this.toString());
   }

   public void readExternal(ObjectInput var1) throws IOException, ClassNotFoundException {
      try {
         this.parse(var1.readUTF());
      } catch (MimeTypeParseException var3) {
         throw new IOException(((Throwable)var3).toString());
      }
   }

   public Object clone() throws CloneNotSupportedException {
      try {
         return new MimeType(this.primaryType, this.subType, this.parameters);
      } catch (MimeTypeParseException var2) {
         throw new CloneNotSupportedException();
      }
   }

   private static boolean isTokenChar(char var0) {
      return var0 > ' ' && var0 < 127 && "()<>@,;:\\\"/[]?=".indexOf(var0) < 0;
   }

   private boolean isValidToken(String var1) {
      int var2 = var1.length();
      if (var2 <= 0) {
         return false;
      } else {
         for(int var3 = 0; var3 < var2; ++var3) {
            char var4 = var1.charAt(var3);
            if (!isTokenChar(var4)) {
               return false;
            }
         }

         return true;
      }
   }
}
