package java.awt.dnd;

import java.awt.Component;
import java.awt.datatransfer.DataFlavor;
import java.awt.datatransfer.Transferable;
import java.awt.dnd.peer.DropTargetContextPeer;
import java.util.Arrays;
import java.util.List;

public class DropTargetContext {
   private DropTarget dropTarget;
   private DropTargetContextPeer dropTargetContextPeer;
   private Transferable transferable;

   DropTargetContext(DropTarget var1) {
      this.dropTarget = var1;
   }

   public DropTarget getDropTarget() {
      return this.dropTarget;
   }

   public Component getComponent() {
      return this.dropTarget.getComponent();
   }

   public synchronized void addNotify(DropTargetContextPeer var1) {
      this.dropTargetContextPeer = var1;
   }

   public synchronized void removeNotify() {
      this.dropTargetContextPeer = null;
      this.transferable = null;
   }

   protected void setTargetActions(int var1) {
      if (this.dropTargetContextPeer != null) {
         this.dropTargetContextPeer.setTargetActions(var1);
      }

   }

   protected int getTargetActions() {
      return this.dropTargetContextPeer != null ? this.dropTargetContextPeer.getTargetActions() : this.dropTarget.getDefaultActions();
   }

   public void dropComplete(boolean var1) throws InvalidDnDOperationException {
      if (this.dropTargetContextPeer != null) {
         this.dropTargetContextPeer.dropComplete(var1);
      }

   }

   protected void acceptDrag(int var1) {
      if (this.dropTargetContextPeer != null) {
         this.dropTargetContextPeer.acceptDrag(var1);
      }

   }

   protected void rejectDrag() {
      if (this.dropTargetContextPeer != null) {
         this.dropTargetContextPeer.rejectDrag();
      }

   }

   protected void acceptDrop(int var1) {
      if (this.dropTargetContextPeer != null) {
         this.dropTargetContextPeer.acceptDrop(var1);
      }

   }

   protected void rejectDrop() {
      if (this.dropTargetContextPeer != null) {
         this.dropTargetContextPeer.rejectDrop();
      }

   }

   protected DataFlavor[] getCurrentDataFlavors() {
      return this.dropTargetContextPeer != null ? this.dropTargetContextPeer.getTransferDataFlavors() : new DataFlavor[0];
   }

   protected List getCurrentDataFlavorsAsList() {
      return Arrays.asList(this.getCurrentDataFlavors());
   }

   protected boolean isDataFlavorSupported(DataFlavor var1) {
      return this.getCurrentDataFlavorsAsList().contains(var1);
   }

   protected synchronized Transferable getTransferable() throws InvalidDnDOperationException {
      if (this.dropTargetContextPeer == null) {
         throw new InvalidDnDOperationException();
      } else {
         if (this.transferable == null) {
            this.transferable = this.createTransferableProxy(this.dropTargetContextPeer.getTransferable(), this.dropTargetContextPeer.isTransferableJVMLocal());
         }

         return this.transferable;
      }
   }

   DropTargetContextPeer getDropTargetContextPeer() {
      return this.dropTargetContextPeer;
   }

   protected Transferable createTransferableProxy(Transferable var1, boolean var2) {
      return new TransferableProxy(this, var1, var2);
   }
}
