package java.awt.geom;

import java.awt.Rectangle;
import java.awt.Shape;

public abstract class Line2D implements Shape, Cloneable {
   protected Line2D() {
   }

   public abstract double getX1();

   public abstract double getY1();

   public abstract Point2D getP1();

   public abstract double getX2();

   public abstract double getY2();

   public abstract Point2D getP2();

   public abstract void setLine(double var1, double var3, double var5, double var7);

   public void setLine(Point2D var1, Point2D var2) {
      this.setLine(var1.getX(), var1.getY(), var2.getX(), var2.getY());
   }

   public void setLine(Line2D var1) {
      this.setLine(var1.getX1(), var1.getY1(), var1.getX2(), var1.getY2());
   }

   public static int relativeCCW(double var0, double var2, double var4, double var6, double var8, double var10) {
      var4 -= var0;
      var6 -= var2;
      var8 -= var0;
      var10 -= var2;
      double var12 = var8 * var6 - var10 * var4;
      if (var12 == (double)0.0F) {
         var12 = var8 * var4 + var10 * var6;
         if (var12 > (double)0.0F) {
            var8 -= var4;
            var10 -= var6;
            var12 = var8 * var4 + var10 * var6;
            if (var12 < (double)0.0F) {
               var12 = (double)0.0F;
            }
         }
      }

      return var12 < (double)0.0F ? -1 : (var12 > (double)0.0F ? 1 : 0);
   }

   public int relativeCCW(double var1, double var3) {
      return relativeCCW(this.getX1(), this.getY1(), this.getX2(), this.getY2(), var1, var3);
   }

   public int relativeCCW(Point2D var1) {
      return relativeCCW(this.getX1(), this.getY1(), this.getX2(), this.getY2(), var1.getX(), var1.getY());
   }

   public static boolean linesIntersect(double var0, double var2, double var4, double var6, double var8, double var10, double var12, double var14) {
      return relativeCCW(var0, var2, var4, var6, var8, var10) * relativeCCW(var0, var2, var4, var6, var12, var14) <= 0 && relativeCCW(var8, var10, var12, var14, var0, var2) * relativeCCW(var8, var10, var12, var14, var4, var6) <= 0;
   }

   public boolean intersectsLine(double var1, double var3, double var5, double var7) {
      return linesIntersect(var1, var3, var5, var7, this.getX1(), this.getY1(), this.getX2(), this.getY2());
   }

   public boolean intersectsLine(Line2D var1) {
      return linesIntersect(var1.getX1(), var1.getY1(), var1.getX2(), var1.getY2(), this.getX1(), this.getY1(), this.getX2(), this.getY2());
   }

   public static double ptSegDistSq(double var0, double var2, double var4, double var6, double var8, double var10) {
      var4 -= var0;
      var6 -= var2;
      var8 -= var0;
      var10 -= var2;
      double var12 = var8 * var4 + var10 * var6;
      double var14;
      if (var12 <= (double)0.0F) {
         var14 = (double)0.0F;
      } else {
         var8 = var4 - var8;
         var10 = var6 - var10;
         var12 = var8 * var4 + var10 * var6;
         if (var12 <= (double)0.0F) {
            var14 = (double)0.0F;
         } else {
            var14 = var12 * var12 / (var4 * var4 + var6 * var6);
         }
      }

      return var8 * var8 + var10 * var10 - var14;
   }

   public static double ptSegDist(double var0, double var2, double var4, double var6, double var8, double var10) {
      return Math.sqrt(ptSegDistSq(var0, var2, var4, var6, var8, var10));
   }

   public double ptSegDistSq(double var1, double var3) {
      return ptSegDistSq(this.getX1(), this.getY1(), this.getX2(), this.getY2(), var1, var3);
   }

   public double ptSegDistSq(Point2D var1) {
      return ptSegDistSq(this.getX1(), this.getY1(), this.getX2(), this.getY2(), var1.getX(), var1.getY());
   }

   public double ptSegDist(double var1, double var3) {
      return ptSegDist(this.getX1(), this.getY1(), this.getX2(), this.getY2(), var1, var3);
   }

   public double ptSegDist(Point2D var1) {
      return ptSegDist(this.getX1(), this.getY1(), this.getX2(), this.getY2(), var1.getX(), var1.getY());
   }

   public static double ptLineDistSq(double var0, double var2, double var4, double var6, double var8, double var10) {
      var4 -= var0;
      var6 -= var2;
      var8 -= var0;
      var10 -= var2;
      double var12 = var8 * var4 + var10 * var6;
      double var14 = var12 * var12 / (var4 * var4 + var6 * var6);
      return var8 * var8 + var10 * var10 - var14;
   }

   public static double ptLineDist(double var0, double var2, double var4, double var6, double var8, double var10) {
      return Math.sqrt(ptLineDistSq(var0, var2, var4, var6, var8, var10));
   }

   public double ptLineDistSq(double var1, double var3) {
      return ptLineDistSq(this.getX1(), this.getY1(), this.getX2(), this.getY2(), var1, var3);
   }

   public double ptLineDistSq(Point2D var1) {
      return ptLineDistSq(this.getX1(), this.getY1(), this.getX2(), this.getY2(), var1.getX(), var1.getY());
   }

   public double ptLineDist(double var1, double var3) {
      return ptLineDist(this.getX1(), this.getY1(), this.getX2(), this.getY2(), var1, var3);
   }

   public double ptLineDist(Point2D var1) {
      return ptLineDist(this.getX1(), this.getY1(), this.getX2(), this.getY2(), var1.getX(), var1.getY());
   }

   public boolean contains(double var1, double var3) {
      return false;
   }

   public boolean contains(Point2D var1) {
      return false;
   }

   public boolean intersects(double var1, double var3, double var5, double var7) {
      return this.intersects(new Rectangle2D.Double(var1, var3, var5, var7));
   }

   public boolean intersects(Rectangle2D var1) {
      return var1.intersectsLine(this.getX1(), this.getY1(), this.getX2(), this.getY2());
   }

   public boolean contains(double var1, double var3, double var5, double var7) {
      return false;
   }

   public boolean contains(Rectangle2D var1) {
      return false;
   }

   public Rectangle getBounds() {
      return this.getBounds2D().getBounds();
   }

   public PathIterator getPathIterator(AffineTransform var1) {
      return new LineIterator(this, var1);
   }

   public PathIterator getPathIterator(AffineTransform var1, double var2) {
      return new LineIterator(this, var1);
   }

   public Object clone() {
      try {
         return super.clone();
      } catch (CloneNotSupportedException var2) {
         throw new InternalError();
      }
   }

   public abstract Rectangle2D getBounds2D();
}
