package java.awt.image;

import java.awt.Graphics;
import java.awt.Graphics2D;
import java.awt.Point;
import java.awt.RenderingHints;
import java.awt.color.ColorSpace;
import java.awt.color.ICC_ColorSpace;
import java.awt.color.ICC_Profile;
import java.awt.geom.Point2D;
import java.awt.geom.Rectangle2D;
import java.util.Hashtable;
import sun.awt.color.ICC_Transform;
import sun.awt.color.ProfileDeferralMgr;

public class ColorConvertOp implements BufferedImageOp, RasterOp {
   ICC_Profile[] profileList;
   ColorSpace[] CSList;
   ICC_Transform thisTransform;
   ICC_Transform thisRasterTransform;
   ICC_Profile thisSrcProfile;
   ICC_Profile thisDestProfile;
   RenderingHints hints;
   boolean gotProfiles;

   public ColorConvertOp(RenderingHints var1) {
      this.profileList = new ICC_Profile[0];
      this.hints = var1;
   }

   public ColorConvertOp(ColorSpace var1, RenderingHints var2) {
      if (var1 instanceof ICC_ColorSpace) {
         this.profileList = new ICC_Profile[1];
         this.profileList[0] = ((ICC_ColorSpace)var1).getProfile();
      } else {
         this.CSList = new ColorSpace[1];
         this.CSList[0] = var1;
      }

      this.hints = var2;
   }

   public ColorConvertOp(ColorSpace var1, ColorSpace var2, RenderingHints var3) {
      if (var1 instanceof ICC_ColorSpace && var2 instanceof ICC_ColorSpace) {
         this.profileList = new ICC_Profile[2];
         this.profileList[0] = ((ICC_ColorSpace)var1).getProfile();
         this.profileList[1] = ((ICC_ColorSpace)var2).getProfile();
      } else {
         this.CSList = new ColorSpace[2];
         this.CSList[0] = var1;
         this.CSList[1] = var2;
      }

      this.hints = var3;
   }

   public ColorConvertOp(ICC_Profile[] var1, RenderingHints var2) {
      this.gotProfiles = true;
      this.profileList = new ICC_Profile[var1.length];

      for(int var3 = 0; var3 < var1.length; ++var3) {
         this.profileList[var3] = var1[var3];
      }

      this.hints = var2;
   }

   public final ICC_Profile[] getICC_Profiles() {
      if (!this.gotProfiles) {
         return null;
      } else {
         ICC_Profile[] var1 = new ICC_Profile[this.profileList.length];

         for(int var2 = 0; var2 < this.profileList.length; ++var2) {
            var1[var2] = this.profileList[var2];
         }

         return var1;
      }
   }

   public final BufferedImage filter(BufferedImage var1, BufferedImage var2) {
      BufferedImage var5 = null;
      if (var1.getColorModel() instanceof IndexColorModel) {
         IndexColorModel var6 = (IndexColorModel)var1.getColorModel();
         var1 = var6.convertToIntDiscrete(var1.getRaster(), true);
      }

      ColorSpace var3 = var1.getColorModel().getColorSpace();
      ColorSpace var4;
      if (var2 != null) {
         if (var2.getColorModel() instanceof IndexColorModel) {
            var5 = var2;
            var2 = null;
            var4 = null;
         } else {
            var4 = var2.getColorModel().getColorSpace();
         }
      } else {
         var4 = null;
      }

      if (this.CSList == null && var3 instanceof ICC_ColorSpace && (var2 == null || var4 instanceof ICC_ColorSpace)) {
         var2 = this.ICCBIFilter(var1, var3, var2, var4);
      } else {
         var2 = this.nonICCBIFilter(var1, var3, var2, var4);
      }

      if (var5 != null) {
         Graphics2D var12 = var5.createGraphics();

         try {
            ((Graphics)var12).drawImage(var2, 0, 0, (ImageObserver)null);
         } finally {
            ((Graphics)var12).dispose();
         }

         return var5;
      } else {
         return var2;
      }
   }

   private final BufferedImage ICCBIFilter(BufferedImage var1, ColorSpace var2, BufferedImage var3, ColorSpace var4) {
      int var6 = this.profileList.length;
      Object var12 = null;
      Object var13 = null;
      ICC_Profile var15 = ((ICC_ColorSpace)var2).getProfile();
      int var8;
      ICC_Profile var16;
      if (var3 == null) {
         if (var6 == 0) {
            throw new IllegalArgumentException("Destination ColorSpace is undefined");
         }

         var8 = var6 + 1;
         var16 = this.profileList[var6 - 1];
         var3 = this.createCompatibleDestImage(var1, (ColorModel)null);
      } else {
         if (var1.getHeight() != var3.getHeight() || var1.getWidth() != var3.getWidth()) {
            throw new IllegalArgumentException("Width or height of BufferedImages do not match");
         }

         var8 = var6 + 2;
         var16 = ((ICC_ColorSpace)var4).getProfile();
      }

      if (this.thisTransform == null || this.thisSrcProfile != var15 || this.thisDestProfile != var16) {
         ICC_Profile[] var5 = new ICC_Profile[var8];
         var5[0] = var15;

         for(int var7 = 1; var7 < var8 - 1; ++var7) {
            var5[var7] = this.profileList[var7 - 1];
         }

         var5[var8 - 1] = var16;
         ICC_Transform[] var11 = new ICC_Transform[var8];
         int var10;
         if (var5[0].getProfileClass() == 2) {
            var10 = 1;
         } else {
            var10 = 0;
         }

         byte var9 = 1;

         for(int var14 = 0; var14 < var8; ++var14) {
            if (var14 == var8 - 1) {
               var9 = 2;
            } else if (var9 == 4 && var5[var14].getProfileClass() == 5) {
               var10 = 0;
               var9 = 1;
            }

            var11[var14] = new ICC_Transform(var5[var14], var10, var9);
            var10 = this.getRenderingIntent(var5[var14]);
            var9 = 4;
         }

         this.thisTransform = new ICC_Transform(var11);
         this.thisSrcProfile = var15;
         this.thisDestProfile = var16;
      }

      this.thisTransform.colorConvert(var1, var3);
      return var3;
   }

   public final WritableRaster filter(Raster var1, WritableRaster var2) {
      if (this.CSList != null) {
         return this.nonICCRasterFilter(var1, var2);
      } else {
         int var3 = this.profileList.length;
         if (var3 < 2) {
            throw new IllegalArgumentException("Source or Destination ColorSpace is undefined");
         } else if (var1.getNumBands() != this.profileList[0].getNumComponents()) {
            throw new IllegalArgumentException("Numbers of source Raster bands and source color space components do not match");
         } else {
            if (var2 == null) {
               var2 = this.createCompatibleDestRaster(var1);
            } else {
               if (var1.getHeight() != ((Raster)var2).getHeight() || var1.getWidth() != ((Raster)var2).getWidth()) {
                  throw new IllegalArgumentException("Width or height of Rasters do not match");
               }

               if (((Raster)var2).getNumBands() != this.profileList[var3 - 1].getNumComponents()) {
                  throw new IllegalArgumentException("Numbers of destination Raster bands and destination color space components do not match");
               }
            }

            if (this.thisRasterTransform == null) {
               ICC_Transform[] var7 = new ICC_Transform[var3];
               int var6;
               if (this.profileList[0].getProfileClass() == 2) {
                  var6 = 1;
               } else {
                  var6 = 0;
               }

               byte var5 = 1;

               for(int var4 = 0; var4 < var3; ++var4) {
                  if (var4 == var3 - 1) {
                     var5 = 2;
                  } else if (var5 == 4 && this.profileList[var4].getProfileClass() == 5) {
                     var6 = 0;
                     var5 = 1;
                  }

                  var7[var4] = new ICC_Transform(this.profileList[var4], var6, var5);
                  var6 = this.getRenderingIntent(this.profileList[var4]);
                  var5 = 4;
               }

               this.thisRasterTransform = new ICC_Transform(var7);
            }

            this.thisRasterTransform.colorConvert(var1, var2);
            return var2;
         }
      }
   }

   public final Rectangle2D getBounds2D(BufferedImage var1) {
      return this.getBounds2D((Raster)var1.getRaster());
   }

   public final Rectangle2D getBounds2D(Raster var1) {
      return var1.getBounds();
   }

   public BufferedImage createCompatibleDestImage(BufferedImage var1, ColorModel var2) {
      Object var3 = null;
      if (var2 == null) {
         if (this.CSList == null) {
            int var4 = this.profileList.length;
            if (var4 == 0) {
               throw new IllegalArgumentException("Destination ColorSpace is undefined");
            }

            ICC_Profile var5 = this.profileList[var4 - 1];
            var3 = new ICC_ColorSpace(var5);
         } else {
            int var6 = this.CSList.length;
            var3 = this.CSList[var6 - 1];
         }
      }

      return this.createCompatibleDestImage(var1, var2, (ColorSpace)var3);
   }

   private BufferedImage createCompatibleDestImage(BufferedImage var1, ColorModel var2, ColorSpace var3) {
      if (var2 == null) {
         ColorModel var5 = var1.getColorModel();
         int var6 = var3.getNumComponents();
         boolean var7 = var5.hasAlpha();
         if (var7) {
            ++var6;
         }

         int[] var8 = new int[var6];

         for(int var9 = 0; var9 < var6; ++var9) {
            var8[var9] = 8;
         }

         var2 = new ComponentColorModel(var3, var8, var7, var5.isAlphaPremultiplied(), var5.getTransparency(), 0);
      }

      int var10 = var1.getWidth();
      int var11 = var1.getHeight();
      BufferedImage var4 = new BufferedImage((ColorModel)var2, ((ColorModel)var2).createCompatibleWritableRaster(var10, var11), ((ColorModel)var2).isAlphaPremultiplied(), (Hashtable)null);
      return var4;
   }

   public WritableRaster createCompatibleDestRaster(Raster var1) {
      int var2;
      if (this.CSList != null) {
         if (this.CSList.length != 2) {
            throw new IllegalArgumentException("Destination ColorSpace is undefined");
         }

         var2 = this.CSList[1].getNumComponents();
      } else {
         int var3 = this.profileList.length;
         if (var3 < 2) {
            throw new IllegalArgumentException("Destination ColorSpace is undefined");
         }

         var2 = this.profileList[var3 - 1].getNumComponents();
      }

      WritableRaster var4 = Raster.createInterleavedRaster(0, var1.getWidth(), var1.getHeight(), var2, new Point(var1.getMinX(), var1.getMinY()));
      return var4;
   }

   public final Point2D getPoint2D(Point2D var1, Point2D var2) {
      if (var2 == null) {
         var2 = new Point2D.Float();
      }

      ((Point2D)var2).setLocation(var1.getX(), var1.getY());
      return (Point2D)var2;
   }

   private int getRenderingIntent(ICC_Profile var1) {
      byte[] var2 = var1.getData(1751474532);
      byte var3 = 64;
      return (var2[var3] & 255) << 24 | (var2[var3 + 1] & 255) << 16 | (var2[var3 + 2] & 255) << 8 | var2[var3 + 3] & 255;
   }

   public final RenderingHints getRenderingHints() {
      return this.hints;
   }

   private final BufferedImage nonICCBIFilter(BufferedImage var1, ColorSpace var2, BufferedImage var3, ColorSpace var4) {
      int var5 = var1.getWidth();
      int var6 = var1.getHeight();
      ColorModel var7 = var1.getColorModel();
      boolean var8 = var7.hasAlpha();
      boolean var9 = false;
      ColorModel var10 = null;
      BufferedImage var11 = var1;
      ColorSpace var12 = ColorSpace.getInstance(1001);
      if (var8 && var7.isAlphaPremultiplied()) {
         var9 = true;
         var10 = var7.coerceData(var1.getRaster(), false);
         var11 = new BufferedImage(var10, var1.getRaster(), false, (Hashtable)null);
      }

      if (var3 == null) {
         var3 = this.createCompatibleDestImage(var1, (ColorModel)null);
         var4 = var3.getColorModel().getColorSpace();
      } else if (var6 != var3.getHeight() || var5 != var3.getWidth()) {
         throw new IllegalArgumentException("Width or height of BufferedImages do not match");
      }

      ColorModel var13 = var3.getColorModel();
      boolean var14 = var13.hasAlpha();
      boolean var15 = false;
      ColorModel var16 = null;
      BufferedImage var17 = var3;
      if (var14 && var13.isAlphaPremultiplied()) {
         var15 = true;
         if (var1 != var3) {
            var16 = var13.coerceData(var3.getRaster(), false);
         } else {
            var16 = var10;
         }

         var17 = new BufferedImage(var16, var3.getRaster(), false, (Hashtable)null);
      }

      if (this.CSList == null && this.profileList.length != 0) {
         BufferedImage var22;
         if (!(var2 instanceof ICC_ColorSpace)) {
            var22 = this.createCompatibleDestImage(var11, (ColorModel)null, var12);
            this.convertBItoCIEXYZ(var11, var22);
         } else {
            var22 = var11;
         }

         if (!(var4 instanceof ICC_ColorSpace)) {
            BufferedImage var23;
            if (var22 != var11) {
               var23 = var22;
            } else {
               var23 = this.createCompatibleDestImage(var11, (ColorModel)null, var12);
            }

            var23 = this.ICCBIFilter(var22, var22.getColorModel().getColorSpace(), var23, var12);
            this.convertBIfromCIEXYZ(var23, var17);
         } else {
            this.ICCBIFilter(var22, var22.getColorModel().getColorSpace(), var17, var4);
         }
      } else {
         ColorSpace[] var20;
         if (this.CSList == null) {
            var20 = new ColorSpace[]{var2, var4};
         } else {
            var20 = new ColorSpace[this.CSList.length + 2];
            var20[0] = var2;

            for(int var21 = 0; var21 < this.CSList.length; ++var21) {
               var20[var21 + 1] = this.CSList[var21];
            }

            var20[var20.length - 1] = var4;
         }

         BufferedImage var18 = var11;

         for(int var25 = 1; var25 < var20.length; ++var25) {
            BufferedImage var19 = this.createCompatibleDestImage(var18, (ColorModel)null, var20[var25]);
            this.convertBItoBI(var18, var19);
            var18 = var19;
         }
      }

      if (var8 && var9) {
         var10.coerceData(var1.getRaster(), true);
      }

      if (var14) {
         this.fixDestAlpha(var1, var3, var8, var15, var16);
      }

      return var3;
   }

   private void fixDestAlpha(BufferedImage var1, BufferedImage var2, boolean var3, boolean var4, ColorModel var5) {
      if (var3 && var1 != var2) {
         WritableRaster var23 = var1.getRaster();
         WritableRaster var24 = var2.getRaster();
         int var25 = ((Raster)var23).getNumBands() - 1;
         int var26 = ((Raster)var24).getNumBands() - 1;
         int var31 = ((Raster)var24).getMinX();
         int var32 = ((Raster)var24).getMinY();
         int var33 = ((Raster)var23).getMinX();
         int var15 = ((Raster)var23).getMinY();
         int var16 = var33 + ((Raster)var23).getWidth();
         int var17 = var15 + ((Raster)var23).getHeight();
         int var19 = var1.getColorModel().getComponentSize(var25);
         int var20 = var2.getColorModel().getComponentSize(var26);
         int var21 = var20 - var19;
         int var22 = -var21;

         for(int var30 = var15; var30 < var17; ++var32) {
            if (var21 > 0) {
               for(int var29 = var33; var29 < var16; ++var31) {
                  int var36 = ((Raster)var23).getSample(var29, var30, var25);
                  var36 <<= var21;
                  var24.setSample(var31, var32, var26, var36);
                  ++var29;
               }
            } else if (var21 == 0) {
               for(int var28 = var33; var28 < var16; ++var31) {
                  int var35 = ((Raster)var23).getSample(var28, var30, var25);
                  var24.setSample(var31, var32, var26, var35);
                  ++var28;
               }
            } else {
               for(int var27 = var33; var27 < var16; ++var31) {
                  int var18 = ((Raster)var23).getSample(var27, var30, var25);
                  var18 >>>= var22;
                  var24.setSample(var31, var32, var26, var18);
                  ++var27;
               }
            }

            ++var30;
         }

         if (var4) {
            var5.coerceData(var24, true);
         }
      } else if (!var3) {
         WritableRaster var6 = var2.getRaster();
         int var7 = ((Raster)var6).getNumBands() - 1;
         int var10 = ((Raster)var6).getMinX();
         int var11 = ((Raster)var6).getMinY();
         int var12 = var10 + ((Raster)var6).getWidth();
         int var13 = var11 + ((Raster)var6).getHeight();
         int var14 = (1 << var2.getColorModel().getComponentSize(var7)) - 1;

         for(int var9 = var11; var9 < var13; ++var9) {
            for(int var8 = var10; var8 < var12; ++var8) {
               var6.setSample(var8, var9, var7, var14);
            }
         }
      }

   }

   private void convertBItoCIEXYZ(BufferedImage var1, BufferedImage var2) {
      WritableRaster var3 = var1.getRaster();
      WritableRaster var4 = var2.getRaster();
      int var5 = var1.getColorModel().getNumColorComponents();
      int var6 = var2.getColorModel().getNumColorComponents();
      int[] var7 = null;
      int[] var8 = new int[var6];
      float[] var9 = new float[var5];
      Object var10 = null;
      int[] var11 = var1.getColorModel().getComponentSize();
      int[] var12 = var2.getColorModel().getComponentSize();
      float[] var13 = new float[var5];
      float[] var14 = new float[var6];
      ColorSpace var15 = var1.getColorModel().getColorSpace();
      int var16 = ((Raster)var3).getHeight();
      int var17 = ((Raster)var3).getWidth();

      for(int var22 = 0; var22 < var5; ++var22) {
         var13[var22] = (float)((1 << var11[var22]) - 1);
      }

      for(int var23 = 0; var23 < var6; ++var23) {
         var14[var23] = (float)((1 << var12[var23]) - 1);
      }

      int var19 = ((Raster)var3).getMinY();
      int var21 = ((Raster)var4).getMinY();

      for(int var24 = 0; var24 < var16; ++var21) {
         int var18 = ((Raster)var3).getMinX();
         int var20 = ((Raster)var4).getMinX();

         for(int var25 = 0; var25 < var17; ++var20) {
            var7 = ((Raster)var3).getPixel(var18, var19, var7);

            for(int var26 = 0; var26 < var5; ++var26) {
               var9[var26] = (float)var7[var26] / var13[var26];
            }

            float[] var28 = var15.toCIEXYZ(var9);

            for(int var27 = 0; var27 < var6; ++var27) {
               var8[var27] = (int)(var28[var27] * var14[var27]);
            }

            var4.setPixel(var20, var21, var8);
            ++var25;
            ++var18;
         }

         ++var24;
         ++var19;
      }

   }

   private void convertBIfromCIEXYZ(BufferedImage var1, BufferedImage var2) {
      WritableRaster var3 = var1.getRaster();
      WritableRaster var4 = var2.getRaster();
      int var5 = var1.getColorModel().getNumColorComponents();
      int var6 = var2.getColorModel().getNumColorComponents();
      int[] var7 = null;
      int[] var8 = new int[var6];
      float[] var9 = new float[var5];
      Object var10 = null;
      int[] var11 = var1.getColorModel().getComponentSize();
      int[] var12 = var2.getColorModel().getComponentSize();
      float[] var13 = new float[var5];
      float[] var14 = new float[var6];
      ColorSpace var15 = var2.getColorModel().getColorSpace();
      int var16 = ((Raster)var3).getHeight();
      int var17 = ((Raster)var3).getWidth();

      for(int var22 = 0; var22 < var5; ++var22) {
         var13[var22] = (float)((1 << var11[var22]) - 1);
      }

      for(int var23 = 0; var23 < var6; ++var23) {
         var14[var23] = (float)((1 << var12[var23]) - 1);
      }

      int var19 = ((Raster)var3).getMinY();
      int var21 = ((Raster)var4).getMinY();

      for(int var24 = 0; var24 < var16; ++var21) {
         int var18 = ((Raster)var3).getMinX();
         int var20 = ((Raster)var4).getMinX();

         for(int var25 = 0; var25 < var17; ++var20) {
            var7 = ((Raster)var3).getPixel(var18, var19, var7);

            for(int var26 = 0; var26 < var5; ++var26) {
               var9[var26] = (float)var7[var26] / var13[var26];
            }

            float[] var28 = var15.fromCIEXYZ(var9);

            for(int var27 = 0; var27 < var6; ++var27) {
               var8[var27] = (int)(var28[var27] * var14[var27]);
            }

            var4.setPixel(var20, var21, var8);
            ++var25;
            ++var18;
         }

         ++var24;
         ++var19;
      }

   }

   private void convertBItoBI(BufferedImage var1, BufferedImage var2) {
      WritableRaster var3 = var1.getRaster();
      WritableRaster var4 = var2.getRaster();
      int var5 = var1.getColorModel().getNumColorComponents();
      int var6 = var2.getColorModel().getNumColorComponents();
      int[] var7 = null;
      int[] var8 = new int[var6];
      float[] var9 = new float[var5];
      Object var10 = null;
      Object var11 = null;
      int[] var12 = var1.getColorModel().getComponentSize();
      int[] var13 = var2.getColorModel().getComponentSize();
      float[] var14 = new float[var5];
      float[] var15 = new float[var6];
      ColorSpace var16 = var1.getColorModel().getColorSpace();
      ColorSpace var17 = var2.getColorModel().getColorSpace();
      int var18 = ((Raster)var3).getHeight();
      int var19 = ((Raster)var3).getWidth();

      for(int var24 = 0; var24 < var5; ++var24) {
         var14[var24] = (float)((1 << var12[var24]) - 1);
      }

      for(int var25 = 0; var25 < var6; ++var25) {
         var15[var25] = (float)((1 << var13[var25]) - 1);
      }

      int var21 = ((Raster)var3).getMinY();
      int var23 = ((Raster)var4).getMinY();

      for(int var26 = 0; var26 < var18; ++var23) {
         int var20 = ((Raster)var3).getMinX();
         int var22 = ((Raster)var4).getMinX();

         for(int var27 = 0; var27 < var19; ++var22) {
            var7 = ((Raster)var3).getPixel(var20, var21, var7);

            for(int var28 = 0; var28 < var5; ++var28) {
               var9[var28] = (float)var7[var28] / var14[var28];
            }

            float[] var31 = var16.toCIEXYZ(var9);
            float[] var30 = var17.fromCIEXYZ(var31);

            for(int var29 = 0; var29 < var6; ++var29) {
               var8[var29] = (int)(var30[var29] * var15[var29]);
            }

            var4.setPixel(var22, var23, var8);
            ++var27;
            ++var20;
         }

         ++var26;
         ++var21;
      }

   }

   private final WritableRaster nonICCRasterFilter(Raster var1, WritableRaster var2) {
      if (this.CSList.length != 2) {
         throw new IllegalArgumentException("Destination ColorSpace is undefined");
      } else if (var1.getNumBands() != this.CSList[0].getNumComponents()) {
         throw new IllegalArgumentException("Numbers of source Raster bands and source color space components do not match");
      } else {
         if (var2 == null) {
            var2 = this.createCompatibleDestRaster(var1);
         } else {
            if (var1.getHeight() != ((Raster)var2).getHeight() || var1.getWidth() != ((Raster)var2).getWidth()) {
               throw new IllegalArgumentException("Width or height of Rasters do not match");
            }

            if (((Raster)var2).getNumBands() != this.CSList[1].getNumComponents()) {
               throw new IllegalArgumentException("Numbers of destination Raster bands and destination color space components do not match");
            }
         }

         int var3 = var1.getNumBands();
         int var4 = ((Raster)var2).getNumBands();
         int[] var5 = null;
         int[] var6 = new int[var4];
         float[] var7 = new float[var3];
         Object var8 = null;
         Object var9 = null;
         int[] var10 = var1.getSampleModel().getSampleSize();
         int[] var11 = ((Raster)var2).getSampleModel().getSampleSize();
         float[] var12 = new float[var3];
         float[] var13 = new float[var4];
         int var14 = var1.getHeight();
         int var15 = var1.getWidth();

         for(int var20 = 0; var20 < var3; ++var20) {
            var12[var20] = (float)((1 << var10[var20]) - 1);
         }

         for(int var21 = 0; var21 < var4; ++var21) {
            var13[var21] = (float)((1 << var11[var21]) - 1);
         }

         int var17 = var1.getMinY();
         int var19 = ((Raster)var2).getMinY();

         for(int var22 = 0; var22 < var14; ++var19) {
            int var16 = var1.getMinX();
            int var18 = ((Raster)var2).getMinX();

            for(int var23 = 0; var23 < var15; ++var18) {
               var5 = var1.getPixel(var16, var17, var5);

               for(int var24 = 0; var24 < var3; ++var24) {
                  var7[var24] = (float)var5[var24] / var12[var24];
               }

               float[] var27 = this.CSList[0].toCIEXYZ(var7);
               float[] var26 = this.CSList[1].fromCIEXYZ(var27);

               for(int var25 = 0; var25 < var4; ++var25) {
                  var6[var25] = (int)(var26[var25] * var13[var25]);
               }

               var2.setPixel(var18, var19, var6);
               ++var23;
               ++var16;
            }

            ++var22;
            ++var17;
         }

         return var2;
      }
   }

   static {
      if (ProfileDeferralMgr.deferring) {
         ProfileDeferralMgr.activateProfiles();
      }

   }
}
