package java.awt.image;

import java.awt.Transparency;
import java.awt.color.ColorSpace;
import java.security.AccessController;
import sun.security.action.LoadLibraryAction;

public abstract class ColorModel implements Transparency {
   private long pData;
   protected int pixel_bits;
   int[] nBits;
   int transparency = 3;
   boolean supportsAlpha = true;
   boolean isAlphaPremultiplied = false;
   int numComponents = -1;
   int numColorComponents = -1;
   ColorSpace colorSpace = ColorSpace.getInstance(1000);
   int colorSpaceType = 5;
   int maxBits;
   boolean is_sRGB = true;
   protected int transferType;
   private static boolean loaded = false;
   private static ColorModel RGBdefault;

   static void loadLibraries() {
      if (!loaded) {
         AccessController.doPrivileged(new LoadLibraryAction("awt"));
         loaded = true;
      }

   }

   private static native void initIDs();

   public static ColorModel getRGBdefault() {
      if (RGBdefault == null) {
         RGBdefault = new DirectColorModel(32, 16711680, 65280, 255, -16777216);
      }

      return RGBdefault;
   }

   public ColorModel(int var1) {
      this.pixel_bits = var1;
      if (var1 < 1) {
         throw new IllegalArgumentException("Number of bits must be > 0");
      } else {
         this.numComponents = 4;
         this.numColorComponents = 3;
         this.maxBits = var1;
         this.transferType = getDefaultTransferType(var1);
      }
   }

   protected ColorModel(int var1, int[] var2, ColorSpace var3, boolean var4, boolean var5, int var6, int var7) {
      this.colorSpace = var3;
      this.colorSpaceType = var3.getType();
      this.numColorComponents = var3.getNumComponents();
      this.numComponents = this.numColorComponents + (var4 ? 1 : 0);
      this.supportsAlpha = var4;
      if (var2.length < this.numComponents) {
         throw new IllegalArgumentException("Number of color/alpha components should be " + this.numComponents + " but length of bits array is " + var2.length);
      } else if (var6 >= 1 && var6 <= 3) {
         if (!this.supportsAlpha) {
            this.isAlphaPremultiplied = false;
            this.transparency = 1;
         } else {
            this.isAlphaPremultiplied = var5;
            this.transparency = var6;
         }

         this.nBits = (int[])var2.clone();
         this.pixel_bits = var1;
         if (var1 <= 0) {
            throw new IllegalArgumentException("Number of pixel bits must be > 0");
         } else {
            this.maxBits = 0;

            for(int var8 = 0; var8 < var2.length; ++var8) {
               if (var2[var8] <= 0) {
                  throw new IllegalArgumentException("Number of bits must be > 0");
               }

               if (this.maxBits < var2[var8]) {
                  this.maxBits = var2[var8];
               }
            }

            if (var3 != ColorSpace.getInstance(1000)) {
               this.is_sRGB = false;
            }

            this.transferType = var7;
         }
      } else {
         throw new IllegalArgumentException("Unknown transparency: " + var6);
      }
   }

   public final boolean hasAlpha() {
      return this.supportsAlpha;
   }

   public final boolean isAlphaPremultiplied() {
      return this.isAlphaPremultiplied;
   }

   public final int getTransferType() {
      return this.transferType;
   }

   public int getPixelSize() {
      return this.pixel_bits;
   }

   public int getComponentSize(int var1) {
      if (this.nBits == null) {
         throw new NullPointerException("Number of bits array is null.");
      } else {
         return this.nBits[var1];
      }
   }

   public int[] getComponentSize() {
      return this.nBits != null ? (int[])this.nBits.clone() : null;
   }

   public int getTransparency() {
      return this.transparency;
   }

   public int getNumComponents() {
      return this.numComponents;
   }

   public int getNumColorComponents() {
      return this.numColorComponents;
   }

   public abstract int getRed(int var1);

   public abstract int getGreen(int var1);

   public abstract int getBlue(int var1);

   public abstract int getAlpha(int var1);

   public int getRGB(int var1) {
      return this.getAlpha(var1) << 24 | this.getRed(var1) << 16 | this.getGreen(var1) << 8 | this.getBlue(var1) << 0;
   }

   public int getRed(Object var1) {
      int var2 = 0;
      int var3 = 0;
      switch (this.transferType) {
         case 0:
            byte[] var4 = (byte[])var1;
            var2 = var4[0] & 255;
            var3 = var4.length;
            break;
         case 1:
            short[] var5 = (short[])var1;
            var2 = var5[0] & '\uffff';
            var3 = var5.length;
            break;
         case 2:
         default:
            throw new UnsupportedOperationException("This method has not been implemented for transferType " + this.transferType);
         case 3:
            int[] var6 = (int[])var1;
            var2 = var6[0];
            var3 = var6.length;
      }

      if (var3 == 1) {
         return this.getRed(var2);
      } else {
         throw new UnsupportedOperationException("This method is not supported by this color model");
      }
   }

   public int getGreen(Object var1) {
      int var2 = 0;
      int var3 = 0;
      switch (this.transferType) {
         case 0:
            byte[] var4 = (byte[])var1;
            var2 = var4[0] & 255;
            var3 = var4.length;
            break;
         case 1:
            short[] var5 = (short[])var1;
            var2 = var5[0] & '\uffff';
            var3 = var5.length;
            break;
         case 2:
         default:
            throw new UnsupportedOperationException("This method has not been implemented for transferType " + this.transferType);
         case 3:
            int[] var6 = (int[])var1;
            var2 = var6[0];
            var3 = var6.length;
      }

      if (var3 == 1) {
         return this.getGreen(var2);
      } else {
         throw new UnsupportedOperationException("This method is not supported by this color model");
      }
   }

   public int getBlue(Object var1) {
      int var2 = 0;
      int var3 = 0;
      switch (this.transferType) {
         case 0:
            byte[] var4 = (byte[])var1;
            var2 = var4[0] & 255;
            var3 = var4.length;
            break;
         case 1:
            short[] var5 = (short[])var1;
            var2 = var5[0] & '\uffff';
            var3 = var5.length;
            break;
         case 2:
         default:
            throw new UnsupportedOperationException("This method has not been implemented for transferType " + this.transferType);
         case 3:
            int[] var6 = (int[])var1;
            var2 = var6[0];
            var3 = var6.length;
      }

      if (var3 == 1) {
         return this.getBlue(var2);
      } else {
         throw new UnsupportedOperationException("This method is not supported by this color model");
      }
   }

   public int getAlpha(Object var1) {
      int var2 = 0;
      int var3 = 0;
      switch (this.transferType) {
         case 0:
            byte[] var4 = (byte[])var1;
            var2 = var4[0] & 255;
            var3 = var4.length;
            break;
         case 1:
            short[] var5 = (short[])var1;
            var2 = var5[0] & '\uffff';
            var3 = var5.length;
            break;
         case 2:
         default:
            throw new UnsupportedOperationException("This method has not been implemented for transferType " + this.transferType);
         case 3:
            int[] var6 = (int[])var1;
            var2 = var6[0];
            var3 = var6.length;
      }

      if (var3 == 1) {
         return this.getAlpha(var2);
      } else {
         throw new UnsupportedOperationException("This method is not supported by this color model");
      }
   }

   public int getRGB(Object var1) {
      return this.getAlpha(var1) << 24 | this.getRed(var1) << 16 | this.getGreen(var1) << 8 | this.getBlue(var1) << 0;
   }

   public Object getDataElements(int var1, Object var2) {
      throw new UnsupportedOperationException("This method is not supported by this color model.");
   }

   public int[] getComponents(int var1, int[] var2, int var3) {
      throw new UnsupportedOperationException("This method is not supported by this color model.");
   }

   public int[] getComponents(Object var1, int[] var2, int var3) {
      throw new UnsupportedOperationException("This method is not supported by this color model.");
   }

   public int[] getUnnormalizedComponents(float[] var1, int var2, int[] var3, int var4) {
      if (this.colorSpace == null) {
         throw new UnsupportedOperationException("This method is not supported by this color model.");
      } else if (this.nBits == null) {
         throw new UnsupportedOperationException("This method is not supported.  Unable to determine #bits per component.");
      } else if (var1.length - var2 < this.numComponents) {
         throw new IllegalArgumentException("Incorrect number of components.  Expecting " + this.numComponents);
      } else {
         if (var3 == null) {
            var3 = new int[var4 + this.numComponents];
         }

         if (this.supportsAlpha && this.isAlphaPremultiplied) {
            float var7 = var1[var2 + this.numColorComponents];

            for(int var6 = 0; var6 < this.numColorComponents; ++var6) {
               var3[var4 + var6] = (int)((double)(var1[var2 + var6] * (float)((1 << this.nBits[var6]) - 1) * var7) + (double)0.5F);
            }

            var3[var4 + this.numColorComponents] = (int)((double)(var7 * (float)(1 << this.nBits[this.numColorComponents] - 1)) + (double)0.5F);
         } else {
            for(int var5 = 0; var5 < this.numComponents; ++var5) {
               var3[var4 + var5] = (int)(var1[var2 + var5] * (float)((1 << this.nBits[var5]) - 1));
            }
         }

         return var3;
      }
   }

   public float[] getNormalizedComponents(int[] var1, int var2, float[] var3, int var4) {
      if (this.colorSpace == null) {
         throw new UnsupportedOperationException("This method is not supported by this color model.");
      } else if (this.nBits == null) {
         throw new UnsupportedOperationException("This method is not supported.  Unable to determine #bits per component.");
      } else if (var1.length - var2 < this.numComponents) {
         throw new IllegalArgumentException("Incorrect number of components.  Expecting " + this.numComponents);
      } else {
         if (var3 == null) {
            var3 = new float[this.numComponents + var4];
         }

         if (this.supportsAlpha && this.isAlphaPremultiplied) {
            float var7 = (float)var1[var2 + this.numColorComponents];
            var7 /= (float)(1 << this.nBits[this.numColorComponents]) - 1.0F;

            for(int var6 = 0; var6 < this.numColorComponents; ++var6) {
               var3[var4 + var6] = (float)var1[var2 + var6] / (var7 * ((float)(1 << this.nBits[var6]) - 1.0F));
            }

            var3[var4 + this.numColorComponents] = var7;
         } else {
            for(int var5 = 0; var5 < this.numComponents; ++var5) {
               var3[var4 + var5] = (float)var1[var2 + var5] / ((float)(1 << this.nBits[var5]) - 1.0F);
            }
         }

         return var3;
      }
   }

   public int getDataElement(int[] var1, int var2) {
      throw new UnsupportedOperationException("This method is not supported by this color model.");
   }

   public Object getDataElements(int[] var1, int var2, Object var3) {
      throw new UnsupportedOperationException("This method has not been implemented for this color model.");
   }

   public boolean equals(Object var1) {
      if (!(var1 instanceof ColorModel)) {
         return false;
      } else {
         ColorModel var2 = (ColorModel)var1;
         if (this == var2) {
            return true;
         } else if (this.supportsAlpha == var2.hasAlpha() && this.isAlphaPremultiplied == var2.isAlphaPremultiplied() && this.pixel_bits == var2.getPixelSize() && this.transparency == var2.getTransparency() && this.numComponents == var2.getNumComponents()) {
            int[] var4 = var2.getComponentSize();

            for(int var3 = 0; var3 < this.numComponents; ++var3) {
               if (this.nBits[var3] != var4[var3]) {
                  return false;
               }
            }

            return true;
         } else {
            return false;
         }
      }
   }

   public int hashCode() {
      int var1 = 0;
      var1 = (this.supportsAlpha ? 2 : 3) + (this.isAlphaPremultiplied ? 4 : 5) + this.pixel_bits * 6 + this.transparency * 7 + this.numComponents * 8;

      for(int var2 = 0; var2 < this.numComponents; ++var2) {
         var1 += this.nBits[var2] * (var2 + 9);
      }

      return var1;
   }

   public final ColorSpace getColorSpace() {
      return this.colorSpace;
   }

   public ColorModel coerceData(WritableRaster var1, boolean var2) {
      throw new UnsupportedOperationException("This method is not supported by this color model");
   }

   public boolean isCompatibleRaster(Raster var1) {
      throw new UnsupportedOperationException("This method has not been implemented for this ColorModel.");
   }

   public WritableRaster createCompatibleWritableRaster(int var1, int var2) {
      throw new UnsupportedOperationException("This method is not supported by this color model");
   }

   public SampleModel createCompatibleSampleModel(int var1, int var2) {
      throw new UnsupportedOperationException("This method is not supported by this color model");
   }

   public boolean isCompatibleSampleModel(SampleModel var1) {
      throw new UnsupportedOperationException("This method is not supported by this color model");
   }

   public void finalize() {
   }

   public WritableRaster getAlphaRaster(WritableRaster var1) {
      return null;
   }

   public String toString() {
      return new String("ColorModel: #pixelBits = " + this.pixel_bits + " numComponents = " + this.numComponents + " color space = " + this.colorSpace + " transparency = " + this.transparency + " has alpha = " + this.supportsAlpha + " isAlphaPre = " + this.isAlphaPremultiplied);
   }

   static int getDefaultTransferType(int var0) {
      if (var0 <= 8) {
         return 0;
      } else if (var0 <= 16) {
         return 1;
      } else {
         return var0 <= 32 ? 3 : 32;
      }
   }

   static {
      loadLibraries();
      initIDs();
   }
}
