package java.awt.image;

import java.awt.Point;
import java.awt.color.ColorSpace;

public class ComponentColorModel extends ColorModel {
   public ComponentColorModel(ColorSpace var1, int[] var2, boolean var3, boolean var4, int var5, int var6) {
      super(DataBuffer.getDataTypeSize(var6) * var2.length, var2, var1, var3, var4, var5, var6);
   }

   public int getRed(int var1) {
      if (super.numComponents > 1) {
         throw new IllegalArgumentException("More than one component per pixel");
      } else {
         float[] var2 = new float[]{(float)var1 / (float)((1 << super.nBits[0]) - 1)};
         float[] var3 = super.colorSpace.toRGB(var2);
         return (int)(var3[0] * 255.0F);
      }
   }

   public int getGreen(int var1) {
      if (super.numComponents > 1) {
         throw new IllegalArgumentException("More than one component per pixel");
      } else {
         float[] var2 = new float[]{(float)var1 / (float)((1 << super.nBits[0]) - 1)};
         float[] var3 = super.colorSpace.toRGB(var2);
         return (int)(var3[1] * 255.0F);
      }
   }

   public int getBlue(int var1) {
      if (super.numComponents > 1) {
         throw new IllegalArgumentException("More than one component per pixel");
      } else {
         float[] var2 = new float[]{(float)var1 / (float)((1 << super.nBits[0]) - 1)};
         float[] var3 = super.colorSpace.toRGB(var2);
         return (int)(var3[2] * 255.0F);
      }
   }

   public int getAlpha(int var1) {
      if (!super.supportsAlpha) {
         return 255;
      } else if (super.numComponents > 1) {
         throw new IllegalArgumentException("More than one component per pixel");
      } else {
         return var1 / ((1 << super.nBits[0]) - 1) * 255;
      }
   }

   public int getRGB(int var1) {
      if (super.numComponents > 1) {
         throw new IllegalArgumentException("More than one component per pixel");
      } else {
         return this.getAlpha(var1) << 24 | this.getRed(var1) << 16 | this.getGreen(var1) << 8 | this.getBlue(var1) << 0;
      }
   }

   public int getRed(Object var1) {
      if (!super.is_sRGB) {
         int[] var9;
         if (var1 instanceof int[]) {
            var9 = (int[])var1;
         } else {
            var9 = DataBuffer.toIntArray(var1);
            if (var9 == null) {
               throw new UnsupportedOperationException("This method has not been implemented for transferType " + super.transferType);
            }
         }

         float[] var10 = ((ColorModel)this).getNormalizedComponents(var9, 0, (float[])null, 0);
         float[] var12 = super.colorSpace.toRGB(var10);
         return (int)(var12[0] * 255.0F);
      } else {
         boolean var2 = super.supportsAlpha && super.isAlphaPremultiplied;
         int var3 = 0;
         int var4 = 0;
         switch (super.transferType) {
            case 0:
               byte[] var5 = (byte[])var1;
               var4 = var5[0] & 255;
               if (var2) {
                  var3 = var5[super.numColorComponents] & 255;
               }
               break;
            case 1:
               short[] var6 = (short[])var1;
               var4 = var6[0] & '\uffff';
               if (var2) {
                  var3 = var6[super.numColorComponents] & '\uffff';
               }
               break;
            case 2:
            default:
               throw new UnsupportedOperationException("This method has not been implemented for transferType " + super.transferType);
            case 3:
               int[] var7 = (int[])var1;
               var4 = var7[0];
               if (var2) {
                  var3 = var7[super.numColorComponents];
               }
         }

         if (super.nBits[0] != 8) {
            int var8 = super.nBits[0] - 8;
            var4 = var8 > 0 ? var4 >> var8 : var4 << -var8;
         }

         if (var2) {
            return var3 != 0 ? (int)((float)var4 * ((float)(1 << super.nBits[super.numColorComponents]) - 1.0F) / (float)var3) : 0;
         } else {
            return var4;
         }
      }
   }

   public int getGreen(Object var1) {
      if (!super.is_sRGB) {
         int[] var9;
         if (var1 instanceof int[]) {
            var9 = (int[])var1;
         } else {
            var9 = DataBuffer.toIntArray(var1);
            if (var9 == null) {
               throw new UnsupportedOperationException("This method has not been implemented for transferType " + super.transferType);
            }
         }

         float[] var10 = ((ColorModel)this).getNormalizedComponents(var9, 0, (float[])null, 0);
         float[] var12 = super.colorSpace.toRGB(var10);
         return (int)(var12[1] * 255.0F);
      } else {
         boolean var2 = super.supportsAlpha && super.isAlphaPremultiplied;
         int var3 = 0;
         int var4 = 0;
         switch (super.transferType) {
            case 0:
               byte[] var5 = (byte[])var1;
               var4 = var5[1] & 255;
               if (var2) {
                  var3 = var5[super.numColorComponents] & 255;
               }
               break;
            case 1:
               short[] var6 = (short[])var1;
               var4 = var6[1] & '\uffff';
               if (var2) {
                  var3 = var6[super.numColorComponents] & '\uffff';
               }
               break;
            case 2:
            default:
               throw new UnsupportedOperationException("This method has not been implemented for transferType " + super.transferType);
            case 3:
               int[] var7 = (int[])var1;
               var4 = var7[1];
               if (var2) {
                  var3 = var7[super.numColorComponents];
               }
         }

         if (super.nBits[1] != 8) {
            int var8 = super.nBits[1] - 8;
            var4 = var8 > 0 ? var4 >> var8 : var4 << -var8;
         }

         if (var2) {
            return var3 != 0 ? (int)((float)var4 * ((float)(1 << super.nBits[super.numColorComponents]) - 1.0F) / (float)var3) : 0;
         } else {
            return var4;
         }
      }
   }

   public int getBlue(Object var1) {
      if (!super.is_sRGB) {
         int[] var9;
         if (var1 instanceof int[]) {
            var9 = (int[])var1;
         } else {
            var9 = DataBuffer.toIntArray(var1);
            if (var9 == null) {
               throw new UnsupportedOperationException("This method has not been implemented for transferType " + super.transferType);
            }
         }

         float[] var10 = ((ColorModel)this).getNormalizedComponents(var9, 0, (float[])null, 0);
         float[] var12 = super.colorSpace.toRGB(var10);
         return (int)(var12[2] * 255.0F);
      } else {
         boolean var2 = super.supportsAlpha && super.isAlphaPremultiplied;
         int var3 = 0;
         int var4 = 0;
         switch (super.transferType) {
            case 0:
               byte[] var5 = (byte[])var1;
               var4 = var5[2] & 255;
               if (var2) {
                  var3 = var5[super.numColorComponents] & 255;
               }
               break;
            case 1:
               short[] var6 = (short[])var1;
               var4 = var6[2] & '\uffff';
               if (var2) {
                  var3 = var6[super.numColorComponents] & '\uffff';
               }
               break;
            case 2:
            default:
               throw new UnsupportedOperationException("This method has not been implemented for transferType " + super.transferType);
            case 3:
               int[] var7 = (int[])var1;
               var4 = var7[2];
               if (var2) {
                  var3 = var7[super.numColorComponents];
               }
         }

         if (super.nBits[2] != 8) {
            int var8 = super.nBits[2] - 8;
            return var8 > 0 ? var4 >> var8 : var4 << -var8;
         } else if (var2) {
            return var3 != 0 ? (int)((float)var4 * ((float)(1 << super.nBits[super.numColorComponents]) - 1.0F) / (float)var3) : 0;
         } else {
            return var4;
         }
      }
   }

   public int getAlpha(Object var1) {
      if (!super.supportsAlpha) {
         return 255;
      } else {
         int var2 = 0;
         int var3 = super.numColorComponents;
         switch (super.transferType) {
            case 0:
               byte[] var4 = (byte[])var1;
               var2 = var4[var3] & 255;
               break;
            case 1:
               short[] var5 = (short[])var1;
               var2 = var5[var3] & '\uffff';
               break;
            case 2:
            default:
               throw new UnsupportedOperationException("This method has not been implemented for transferType " + super.transferType);
            case 3:
               int[] var6 = (int[])var1;
               var2 = var6[var3];
         }

         if (super.nBits[var3] == 8) {
            return var2;
         } else {
            int var7 = super.nBits[var3] - 8;
            return var7 > 0 ? var2 >> var7 : var2 << -var7;
         }
      }
   }

   private float getNormAlpha(int[] var1) {
      return (float)var1[super.numColorComponents] / ((float)(1 << super.nBits[super.numColorComponents]) - 1.0F);
   }

   public int getRGB(Object var1) {
      if (super.colorSpaceType == 6) {
         int var5 = this.getRed(var1);
         return this.getAlpha(var1) << 24 | var5 << 16 | var5 << 8 | var5;
      } else if (!super.is_sRGB) {
         int[] var2;
         if (var1 instanceof int[]) {
            var2 = (int[])var1;
         } else {
            var2 = DataBuffer.toIntArray(var1);
            if (var2 == null) {
               throw new UnsupportedOperationException("This method has not been implemented for transferType " + super.transferType);
            }
         }

         float[] var3 = ((ColorModel)this).getNormalizedComponents(var2, 0, (float[])null, 0);
         float[] var4 = super.colorSpace.toRGB(var3);
         return this.getAlpha(var1) << 24 | (int)(var4[0] * 255.0F) << 16 | (int)(var4[1] * 255.0F) << 8 | (int)(var4[2] * 255.0F) << 0;
      } else {
         return this.getAlpha(var1) << 24 | this.getRed(var1) << 16 | this.getGreen(var1) << 8 | this.getBlue(var1);
      }
   }

   public Object getDataElements(int var1, Object var2) {
      Object var3 = null;
      int[] var9;
      if (super.transferType == 3 && var2 != null) {
         var9 = (int[])var2;
      } else {
         var9 = new int[super.numComponents];
      }

      if (!super.is_sRGB) {
         float[] var4 = new float[]{(float)(var1 >> 16 & 255) / 255.0F, (float)(var1 >> 8 & 255) / 255.0F, (float)(var1 >> 0 & 255) / 255.0F};
         var4 = super.colorSpace.fromRGB(var4);
         if (super.supportsAlpha) {
            if (super.nBits[super.numColorComponents] == 8) {
               var9[super.numColorComponents] = var1 >> 24 & 255;
            } else {
               var9[super.numColorComponents] = (int)((float)(var1 >> 24 & 255) / 255.0F * (float)((1 << super.nBits[super.numColorComponents]) - 1));
            }

            if (super.isAlphaPremultiplied) {
               float var5 = (float)(var1 >> 24 & 255) / 255.0F;

               for(int var6 = 0; var6 < super.numColorComponents; ++var6) {
                  var4[var6] *= var5;
               }
            }
         }

         for(int var14 = 0; var14 < super.numColorComponents; ++var14) {
            var9[var14] = (int)(var4[var14] * (float)((1 << super.nBits[var14]) - 1));
         }
      } else {
         int var11 = var1 >> 24 & 255;
         int var15 = var1 >> 16 & 255;
         int var18 = var1 >> 8 & 255;
         int var7 = var1 & 255;
         if (super.isAlphaPremultiplied) {
            float var8 = (float)var11 / 255.0F;
            if (super.nBits[0] == 8) {
               var9[0] = (int)((float)var15 * var8);
            } else {
               var9[0] = (int)((float)var15 * var8 / 255.0F * (float)((1 << super.nBits[0]) - 1));
            }

            if (super.nBits[1] == 8) {
               var9[1] = (int)((float)var18 * var8);
            } else {
               var9[1] = (int)((float)var18 * var8 / 255.0F * (float)((1 << super.nBits[1]) - 1));
            }

            if (super.nBits[2] == 8) {
               var9[2] = (int)((float)var7 * var8);
            } else {
               var9[2] = (int)((float)var7 * var8 / 255.0F * (float)((1 << super.nBits[2]) - 1));
            }

            if (super.supportsAlpha) {
               if (super.nBits[3] == 8) {
                  var9[3] = var11;
               } else {
                  var9[3] = (int)(var8 * (float)((1 << super.nBits[3]) - 1));
               }
            }
         } else {
            if (super.nBits[0] == 8) {
               var9[0] = var15;
            } else {
               var9[0] = (int)((float)var15 / 255.0F * (float)((1 << super.nBits[0]) - 1));
            }

            if (super.nBits[1] == 8) {
               var9[1] = var18;
            } else {
               var9[1] = (int)((float)var18 / 255.0F * (float)((1 << super.nBits[1]) - 1));
            }

            if (super.nBits[2] == 8) {
               var9[2] = var7;
            } else {
               var9[2] = (int)((float)var7 / 255.0F * (float)((1 << super.nBits[2]) - 1));
            }

            if (super.supportsAlpha) {
               if (super.nBits[3] == 8) {
                  var9[3] = var11;
               } else {
                  var9[3] = (int)((float)var11 / 255.0F * (float)((1 << super.nBits[3]) - 1));
               }
            }
         }
      }

      switch (super.transferType) {
         case 0:
            byte[] var13;
            if (var2 == null) {
               var13 = new byte[super.numComponents];
            } else {
               var13 = (byte[])var2;
            }

            for(int var17 = 0; var17 < super.numComponents; ++var17) {
               var13[var17] = (byte)(255 & var9[var17]);
            }

            return var13;
         case 1:
            short[] var12;
            if (var2 == null) {
               var12 = new short[super.numComponents];
            } else {
               var12 = (short[])var2;
            }

            for(int var16 = 0; var16 < super.numComponents; ++var16) {
               var12[var16] = (short)(var9[var16] & '\uffff');
            }

            return var12;
         case 2:
         default:
            throw new IllegalArgumentException("This method has not been implemented for transferType " + super.transferType);
         case 3:
            return var9;
      }
   }

   public int[] getComponents(int var1, int[] var2, int var3) {
      if (super.numComponents > 1) {
         throw new IllegalArgumentException("More than one component per pixel");
      } else {
         if (var2 == null) {
            var2 = new int[var3 + 1];
         }

         var2[var3 + 0] = var1 & (1 << super.nBits[0]) - 1;
         return var2;
      }
   }

   public int[] getComponents(Object var1, int[] var2, int var3) {
      int[] var4;
      if (var1 instanceof int[]) {
         var4 = (int[])var1;
      } else {
         var4 = DataBuffer.toIntArray(var1);
         if (var4 == null) {
            throw new UnsupportedOperationException("This method has not been implemented for transferType " + super.transferType);
         }
      }

      if (var4.length < super.numComponents) {
         throw new IllegalArgumentException("Length of pixel array < number of components in model");
      } else {
         if (var2 == null) {
            var2 = new int[var3 + super.numComponents];
         } else if (var2.length - var3 < super.numComponents) {
            throw new IllegalArgumentException("Length of components array < number of components in model");
         }

         System.arraycopy(var4, 0, var2, var3, super.numComponents);
         return var2;
      }
   }

   public int getDataElement(int[] var1, int var2) {
      if (super.numComponents == 1) {
         return var1[var2 + 0];
      } else {
         throw new IllegalArgumentException("This model returns " + super.numComponents + " elements in the pixel array.");
      }
   }

   public Object getDataElements(int[] var1, int var2, Object var3) {
      if (var1.length - var2 < super.numComponents) {
         throw new IllegalArgumentException("Component array too small (should be " + super.numComponents);
      } else {
         switch (super.transferType) {
            case 0:
               byte[] var7;
               if (var3 == null) {
                  var7 = new byte[var1.length];
               } else {
                  var7 = (byte[])var3;
               }

               for(int var8 = 0; var8 < super.numComponents; ++var8) {
                  var7[var8] = (byte)(var1[var2 + var8] & 255);
               }

               return var7;
            case 1:
               short[] var6;
               if (var3 == null) {
                  var6 = new short[var1.length];
               } else {
                  var6 = (short[])var3;
               }

               for(int var5 = 0; var5 < super.numComponents; ++var5) {
                  var6[var5] = (short)(var1[var2 + var5] & '\uffff');
               }

               return var6;
            case 2:
            default:
               throw new UnsupportedOperationException("This method has not been implemented for transferType " + super.transferType);
            case 3:
               int[] var4;
               if (var3 == null) {
                  var4 = new int[var1.length];
               } else {
                  var4 = (int[])var3;
               }

               System.arraycopy(var1, var2, var4, 0, super.numComponents);
               return var4;
         }
      }
   }

   public ColorModel coerceData(WritableRaster var1, boolean var2) {
      if (super.supportsAlpha && super.isAlphaPremultiplied != var2) {
         int var3 = ((Raster)var1).getWidth();
         int var4 = ((Raster)var1).getHeight();
         int var5 = ((Raster)var1).getNumBands() - 1;
         int var7 = ((Raster)var1).getMinX();
         int var8 = ((Raster)var1).getMinY();
         if (var2) {
            switch (super.transferType) {
               case 0:
                  byte[] var25 = null;

                  for(int var30 = 0; var30 < var4; ++var8) {
                     int var20 = var7;

                     for(int var35 = 0; var35 < var3; ++var20) {
                        var25 = (byte[])((Raster)var1).getDataElements(var20, var8, var25);
                        int var15 = var25[var5] & 255;
                        if (var15 != 0) {
                           for(int var43 = 0; var43 < var5; ++var43) {
                              var25[var43] = (byte)((var25[var43] & 255) * var15);
                           }

                           var1.setDataElements(var20, var8, var25);
                        }

                        ++var35;
                     }

                     ++var30;
                  }
                  break;
               case 1:
                  short[] var24 = null;

                  for(int var29 = 0; var29 < var4; ++var8) {
                     int var19 = var7;

                     for(int var34 = 0; var34 < var3; ++var19) {
                        var24 = (short[])((Raster)var1).getDataElements(var19, var8, var24);
                        int var14 = var24[var5] & '\uffff';
                        if (var14 != 0) {
                           for(int var42 = 0; var42 < var5; ++var42) {
                              var24[var42] = (short)((var24[var42] & '\uffff') * var14);
                           }

                           var1.setDataElements(var19, var8, var24);
                        }

                        ++var34;
                     }

                     ++var29;
                  }
                  break;
               case 2:
               default:
                  throw new UnsupportedOperationException("This method has not been implemented for transferType " + super.transferType);
               case 3:
                  int[] var10 = null;

                  for(int var11 = 0; var11 < var4; ++var8) {
                     int var9 = var7;

                     for(int var12 = 0; var12 < var3; ++var9) {
                        var10 = (int[])((Raster)var1).getDataElements(var9, var8, var10);
                        int var6 = var10[var5];
                        if (var6 != 0) {
                           for(int var13 = 0; var13 < var5; ++var13) {
                              var10[var13] *= var6;
                           }

                           var1.setDataElements(var9, var8, var10);
                        }

                        ++var12;
                     }

                     ++var11;
                  }
            }
         } else {
            switch (super.transferType) {
               case 0:
                  for(int var28 = 0; var28 < var4; ++var8) {
                     int var23 = var7;

                     for(int var33 = 0; var33 < var3; ++var23) {
                        Object var40 = null;
                        byte[] var41 = (byte[])((Raster)var1).getDataElements(var23, var8, var40);
                        int var18 = var41[var5] & 255;

                        for(int var46 = 0; var46 < var5; ++var46) {
                           if (var18 != 0) {
                              var41[var46] = (byte)((var41[var46] & 255) / var18);
                           }
                        }

                        var1.setDataElements(var23, var8, var41);
                        ++var33;
                     }

                     ++var28;
                  }
                  break;
               case 1:
                  for(int var27 = 0; var27 < var4; ++var8) {
                     int var22 = var7;

                     for(int var32 = 0; var32 < var3; ++var22) {
                        Object var38 = null;
                        short[] var39 = (short[])((Raster)var1).getDataElements(var22, var8, var38);
                        int var17 = var39[var5] & '\uffff';

                        for(int var45 = 0; var45 < var5; ++var45) {
                           if (var17 != 0) {
                              var39[var45] = (short)((var39[var45] & '\uffff') / var17);
                           }
                        }

                        var1.setDataElements(var22, var8, var39);
                        ++var32;
                     }

                     ++var27;
                  }
                  break;
               case 2:
               default:
                  throw new UnsupportedOperationException("This method has not been implemented for transferType " + super.transferType);
               case 3:
                  for(int var26 = 0; var26 < var4; ++var8) {
                     int var21 = var7;

                     for(int var31 = 0; var31 < var3; ++var21) {
                        Object var36 = null;
                        int[] var37 = (int[])((Raster)var1).getDataElements(var21, var8, var36);
                        int var16 = var37[var5];

                        for(int var44 = 0; var44 < var5; ++var44) {
                           if (var16 != 0) {
                              var37[var44] /= var16;
                           }
                        }

                        var1.setDataElements(var21, var8, var37);
                        ++var31;
                     }

                     ++var26;
                  }
            }
         }

         return new ComponentColorModel(super.colorSpace, super.nBits, super.supportsAlpha, var2, super.transparency, super.transferType);
      } else {
         return this;
      }
   }

   public boolean isCompatibleRaster(Raster var1) {
      boolean var2 = true;
      SampleModel var3 = var1.getSampleModel();
      if (!(var3 instanceof ComponentSampleModel)) {
         return false;
      } else if (var3.getNumBands() != ((ColorModel)this).getNumComponents()) {
         return false;
      } else {
         for(int var4 = 0; var4 < super.nBits.length; ++var4) {
            if (var3.getSampleSize(var4) < super.nBits[var4]) {
               var2 = false;
            }
         }

         return var1.getTransferType() == super.transferType && var2;
      }
   }

   public WritableRaster createCompatibleWritableRaster(int var1, int var2) {
      int var3 = var1 * var2 * super.numComponents;
      Object var4 = null;
      WritableRaster var5 = Raster.createInterleavedRaster(super.transferType, var1, var2, super.numComponents, (Point)null);
      return var5;
   }

   public SampleModel createCompatibleSampleModel(int var1, int var2) {
      int[] var3 = new int[super.numComponents];

      for(int var4 = 0; var4 < super.numComponents; var3[var4] = var4++) {
      }

      return new PixelInterleavedSampleModel(super.transferType, var1, var2, super.numComponents, var1 * super.numComponents, var3);
   }

   public boolean isCompatibleSampleModel(SampleModel var1) {
      if (!(var1 instanceof ComponentSampleModel)) {
         return false;
      } else {
         return var1.getTransferType() == super.transferType;
      }
   }

   public WritableRaster getAlphaRaster(WritableRaster var1) {
      if (!((ColorModel)this).hasAlpha()) {
         return null;
      } else {
         int var2 = ((Raster)var1).getMinX();
         int var3 = ((Raster)var1).getMinY();
         int[] var4 = new int[]{((Raster)var1).getNumBands() - 1};
         return var1.createWritableChild(var2, var3, ((Raster)var1).getWidth(), ((Raster)var1).getHeight(), var2, var3, var4);
      }
   }

   public boolean equals(Object var1) {
      if (!super.equals(var1)) {
         return false;
      } else {
         return var1.getClass() == this.getClass();
      }
   }
}
