package java.awt.image;

public abstract class DataBuffer {
   public static final int TYPE_BYTE = 0;
   public static final int TYPE_USHORT = 1;
   public static final int TYPE_SHORT = 2;
   public static final int TYPE_INT = 3;
   public static final int TYPE_FLOAT = 4;
   public static final int TYPE_DOUBLE = 5;
   public static final int TYPE_UNDEFINED = 32;
   protected int dataType;
   protected int banks;
   protected int offset;
   protected int size;
   protected int[] offsets;
   private static final int[] dataTypeSize = new int[]{8, 16, 16, 32, 32, 64};

   public static int getDataTypeSize(int var0) {
      if (var0 >= 0 && var0 <= 5) {
         return dataTypeSize[var0];
      } else {
         throw new IllegalArgumentException("Unknown data type " + var0);
      }
   }

   protected DataBuffer(int var1, int var2) {
      this.dataType = var1;
      this.banks = 1;
      this.size = var2;
      this.offset = 0;
      this.offsets = new int[1];
   }

   protected DataBuffer(int var1, int var2, int var3) {
      this.dataType = var1;
      this.banks = var3;
      this.size = var2;
      this.offset = 0;
      this.offsets = new int[this.banks];
   }

   protected DataBuffer(int var1, int var2, int var3, int var4) {
      this.dataType = var1;
      this.banks = var3;
      this.size = var2;
      this.offset = var4;
      this.offsets = new int[var3];

      for(int var5 = 0; var5 < var3; ++var5) {
         this.offsets[var5] = var4;
      }

   }

   protected DataBuffer(int var1, int var2, int var3, int[] var4) {
      if (var3 != var4.length) {
         throw new ArrayIndexOutOfBoundsException("Number of banks does not match number of bank offsets");
      } else {
         this.dataType = var1;
         this.banks = var3;
         this.size = var2;
         this.offset = var4[0];
         this.offsets = (int[])var4.clone();
      }
   }

   public int getDataType() {
      return this.dataType;
   }

   public int getSize() {
      return this.size;
   }

   public int getOffset() {
      return this.offset;
   }

   public int[] getOffsets() {
      return (int[])this.offsets.clone();
   }

   public int getNumBanks() {
      return this.banks;
   }

   public int getElem(int var1) {
      return this.getElem(0, var1);
   }

   public abstract int getElem(int var1, int var2);

   public void setElem(int var1, int var2) {
      this.setElem(0, var1, var2);
   }

   public abstract void setElem(int var1, int var2, int var3);

   public float getElemFloat(int var1) {
      return (float)this.getElem(var1);
   }

   public float getElemFloat(int var1, int var2) {
      return (float)this.getElem(var1, var2);
   }

   public void setElemFloat(int var1, float var2) {
      this.setElem(var1, (int)var2);
   }

   public void setElemFloat(int var1, int var2, float var3) {
      this.setElem(var1, var2, (int)var3);
   }

   public double getElemDouble(int var1) {
      return (double)this.getElem(var1);
   }

   public double getElemDouble(int var1, int var2) {
      return (double)this.getElem(var1, var2);
   }

   public void setElemDouble(int var1, double var2) {
      this.setElem(var1, (int)var2);
   }

   public void setElemDouble(int var1, int var2, double var3) {
      this.setElem(var1, var2, (int)var3);
   }

   static int[] toIntArray(Object var0) {
      if (var0 instanceof int[]) {
         return (int[])var0;
      } else if (var0 == null) {
         return null;
      } else if (var0 instanceof short[]) {
         short[] var4 = (short[])var0;
         int[] var5 = new int[var4.length];

         for(int var6 = 0; var6 < var4.length; ++var6) {
            var5[var6] = var4[var6] & '\uffff';
         }

         return var5;
      } else if (!(var0 instanceof byte[])) {
         return null;
      } else {
         byte[] var1 = (byte[])var0;
         int[] var2 = new int[var1.length];

         for(int var3 = 0; var3 < var1.length; ++var3) {
            var2[var3] = 255 & var1[var3];
         }

         return var2;
      }
   }
}
