package java.awt.image;

import java.awt.Point;
import java.awt.color.ColorSpace;

public class DirectColorModel extends PackedColorModel {
   private int red_mask;
   private int green_mask;
   private int blue_mask;
   private int alpha_mask;
   private int red_offset;
   private int green_offset;
   private int blue_offset;
   private int alpha_offset;
   private int red_scale;
   private int green_scale;
   private int blue_scale;
   private int alpha_scale;

   public DirectColorModel(int var1, int var2, int var3, int var4) {
      this(var1, var2, var3, var4, 0);
   }

   public DirectColorModel(int var1, int var2, int var3, int var4, int var5) {
      super(ColorSpace.getInstance(1000), var1, var2, var3, var4, var5, false, var5 == 0 ? 1 : 3, ColorModel.getDefaultTransferType(var1));
      this.setFields();
   }

   public DirectColorModel(ColorSpace var1, int var2, int var3, int var4, int var5, int var6, boolean var7, int var8) {
      super(var1, var2, var3, var4, var5, var6, var7, var6 == 0 ? 1 : 3, var8);
      this.setFields();
   }

   public final int getRedMask() {
      return super.maskArray[0];
   }

   public final int getGreenMask() {
      return super.maskArray[1];
   }

   public final int getBlueMask() {
      return super.maskArray[2];
   }

   public final int getAlphaMask() {
      return super.supportsAlpha ? super.maskArray[3] : 0;
   }

   private float[] getDefaultRGBComponents(int var1) {
      int[] var2 = this.getComponents(var1, (int[])null, 0);
      float[] var3 = ((ColorModel)this).getNormalizedComponents(var2, 0, (float[])null, 0);
      return super.colorSpace.toRGB(var3);
   }

   public final int getRed(int var1) {
      if (!super.is_sRGB) {
         float[] var4 = this.getDefaultRGBComponents(var1);
         return (int)(var4[0] * 255.0F);
      } else {
         int var2 = (var1 & super.maskArray[0]) >>> super.maskOffsets[0];
         if (super.scaleFactors[0] != (double)1.0F) {
            var2 = (int)((double)var2 * super.scaleFactors[0]);
         }

         if (super.isAlphaPremultiplied) {
            int var3 = this.getAlpha(var1);
            var2 = var3 == 0 ? 0 : var2 * 255 / var3;
            if (var2 > 255) {
               var2 = 255;
            }
         }

         return var2;
      }
   }

   public final int getGreen(int var1) {
      if (!super.is_sRGB) {
         float[] var4 = this.getDefaultRGBComponents(var1);
         return (int)(var4[1] * 255.0F);
      } else {
         int var2 = (var1 & super.maskArray[1]) >>> super.maskOffsets[1];
         if (super.scaleFactors[1] != (double)1.0F) {
            var2 = (int)((double)var2 * super.scaleFactors[1]);
         }

         if (super.isAlphaPremultiplied) {
            int var3 = this.getAlpha(var1);
            var2 = var3 == 0 ? 0 : var2 * 255 / var3;
            if (var2 > 255) {
               var2 = 255;
            }
         }

         return var2;
      }
   }

   public final int getBlue(int var1) {
      if (!super.is_sRGB) {
         float[] var4 = this.getDefaultRGBComponents(var1);
         return (int)(var4[2] * 255.0F);
      } else {
         int var2 = (var1 & super.maskArray[2]) >>> super.maskOffsets[2];
         if (super.scaleFactors[2] != (double)1.0F) {
            var2 = (int)((double)var2 * super.scaleFactors[2]);
         }

         if (super.isAlphaPremultiplied) {
            int var3 = this.getAlpha(var1);
            var2 = var3 == 0 ? 0 : var2 * 255 / var3;
            if (var2 > 255) {
               var2 = 255;
            }
         }

         return var2;
      }
   }

   public final int getAlpha(int var1) {
      if (!super.supportsAlpha) {
         return 255;
      } else {
         int var2 = (var1 & super.maskArray[3]) >>> super.maskOffsets[3];
         if (super.scaleFactors[3] != (double)1.0F) {
            var2 = (int)((double)var2 * super.scaleFactors[3]);
         }

         return var2;
      }
   }

   public final int getRGB(int var1) {
      if (!super.is_sRGB) {
         float[] var2 = this.getDefaultRGBComponents(var1);
         return this.getAlpha(var1) << 24 | (int)(var2[0] * 255.0F) << 16 | (int)(var2[1] * 255.0F) << 8 | (int)(var2[2] * 255.0F) << 0;
      } else {
         return this.getAlpha(var1) << 24 | this.getRed(var1) << 16 | this.getGreen(var1) << 8 | this.getBlue(var1) << 0;
      }
   }

   public int getRed(Object var1) {
      int var2 = 0;
      switch (super.transferType) {
         case 0:
            byte[] var3 = (byte[])var1;
            var2 = var3[0] & 255;
            break;
         case 1:
            short[] var4 = (short[])var1;
            var2 = var4[0] & '\uffff';
            break;
         case 2:
         default:
            throw new UnsupportedOperationException("This method has not been implemented for transferType " + super.transferType);
         case 3:
            int[] var5 = (int[])var1;
            var2 = var5[0];
      }

      return this.getRed(var2);
   }

   public int getGreen(Object var1) {
      int var2 = 0;
      switch (super.transferType) {
         case 0:
            byte[] var3 = (byte[])var1;
            var2 = var3[0] & 255;
            break;
         case 1:
            short[] var4 = (short[])var1;
            var2 = var4[0] & '\uffff';
            break;
         case 2:
         default:
            throw new UnsupportedOperationException("This method has not been implemented for transferType " + super.transferType);
         case 3:
            int[] var5 = (int[])var1;
            var2 = var5[0];
      }

      return this.getGreen(var2);
   }

   public int getBlue(Object var1) {
      int var2 = 0;
      switch (super.transferType) {
         case 0:
            byte[] var3 = (byte[])var1;
            var2 = var3[0] & 255;
            break;
         case 1:
            short[] var4 = (short[])var1;
            var2 = var4[0] & '\uffff';
            break;
         case 2:
         default:
            throw new UnsupportedOperationException("This method has not been implemented for transferType " + super.transferType);
         case 3:
            int[] var5 = (int[])var1;
            var2 = var5[0];
      }

      return this.getBlue(var2);
   }

   public int getAlpha(Object var1) {
      int var2 = 0;
      switch (super.transferType) {
         case 0:
            byte[] var3 = (byte[])var1;
            var2 = var3[0] & 255;
            break;
         case 1:
            short[] var4 = (short[])var1;
            var2 = var4[0] & '\uffff';
            break;
         case 2:
         default:
            throw new UnsupportedOperationException("This method has not been implemented for transferType " + super.transferType);
         case 3:
            int[] var5 = (int[])var1;
            var2 = var5[0];
      }

      return this.getAlpha(var2);
   }

   public int getRGB(Object var1) {
      int var2 = 0;
      switch (super.transferType) {
         case 0:
            byte[] var3 = (byte[])var1;
            var2 = var3[0] & 255;
            break;
         case 1:
            short[] var4 = (short[])var1;
            var2 = var4[0] & '\uffff';
            break;
         case 2:
         default:
            throw new UnsupportedOperationException("This method has not been implemented for transferType " + super.transferType);
         case 3:
            int[] var5 = (int[])var1;
            var2 = var5[0];
      }

      return this.getRGB(var2);
   }

   public Object getDataElements(int var1, Object var2) {
      Object var4 = null;
      int[] var13;
      if (super.transferType == 3 && var2 != null) {
         var13 = (int[])var2;
      } else {
         var13 = new int[1];
      }

      ColorModel var5 = ColorModel.getRGBdefault();
      if (this != var5 && !((PackedColorModel)this).equals(var5)) {
         if (super.is_sRGB) {
            double var6 = (double)1.0F;
            if (super.supportsAlpha && super.isAlphaPremultiplied) {
               var6 = (double)(var1 >> 24 & 255) / (double)255.0F;
            }

            int[] var9 = new int[]{16, 8, 0, 24};
            var13[0] = 0;

            for(int var3 = 0; var3 < 3; ++var3) {
               int var8 = (int)((double)(var1 >> var9[var3] & 255) * var6 / super.scaleFactors[var3]);
               var13[0] |= var8 << super.maskOffsets[var3] & super.maskArray[var3];
            }

            if (super.supportsAlpha) {
               int var17 = (int)((double)(var1 >> var9[3] & 255) / super.scaleFactors[3]);
               var13[0] |= var17 << super.maskOffsets[3] & super.maskArray[3];
            }
         } else {
            int[] var14 = var5.getComponents(var1, (int[])null, 0);
            float[] var7 = var5.getNormalizedComponents(var14, 0, (float[])null, 0);
            float[] var18 = super.colorSpace.fromRGB(var7);
            double var19 = (double)1.0F;
            if (super.supportsAlpha && super.isAlphaPremultiplied) {
               var19 = (double)(var1 >> 24 & 255) / (double)255.0F;
            }

            var13[0] = 0;

            for(int var12 = 0; var12 < 3; ++var12) {
               int var11 = (int)((double)var18[var12] * (double)255.0F * var19 / super.scaleFactors[var12]);
               var13[0] |= var11 << super.maskOffsets[var12] & super.maskArray[var12];
            }

            if (super.supportsAlpha) {
               int var20 = (int)((double)(var1 >> 24 & 255) / super.scaleFactors[3]);
               var13[0] |= var20 << super.maskOffsets[3] & super.maskArray[3];
            }
         }
      } else {
         var13[0] = var1;
      }

      switch (super.transferType) {
         case 0:
            byte[] var16;
            if (var2 == null) {
               var16 = new byte[1];
            } else {
               var16 = (byte[])var2;
            }

            var16[0] = (byte)(255 & var13[0]);
            return var16;
         case 1:
            short[] var15;
            if (var2 == null) {
               var15 = new short[1];
            } else {
               var15 = (short[])var2;
            }

            var15[0] = (short)(var13[0] & '\uffff');
            return var15;
         case 2:
         default:
            throw new UnsupportedOperationException("This method has not been implemented for transferType " + super.transferType);
         case 3:
            return var13;
      }
   }

   public final int[] getComponents(int var1, int[] var2, int var3) {
      if (var2 == null) {
         var2 = new int[var3 + super.numComponents];
      }

      for(int var4 = 0; var4 < super.numComponents; ++var4) {
         var2[var3 + var4] = (var1 & super.maskArray[var4]) >>> super.maskOffsets[var4];
      }

      return var2;
   }

   public final int[] getComponents(Object var1, int[] var2, int var3) {
      int var4 = 0;
      switch (super.transferType) {
         case 0:
            byte[] var5 = (byte[])var1;
            var4 = var5[0] & 255;
            break;
         case 1:
            short[] var6 = (short[])var1;
            var4 = var6[0] & '\uffff';
            break;
         case 2:
         default:
            throw new UnsupportedOperationException("This method has not been implemented for transferType " + super.transferType);
         case 3:
            int[] var7 = (int[])var1;
            var4 = var7[0];
      }

      return this.getComponents(var4, var2, var3);
   }

   public final WritableRaster createCompatibleWritableRaster(int var1, int var2) {
      int[] var3;
      if (super.supportsAlpha) {
         var3 = new int[4];
         var3[3] = this.alpha_mask;
      } else {
         var3 = new int[3];
      }

      var3[0] = this.red_mask;
      var3[1] = this.green_mask;
      var3[2] = this.blue_mask;
      if (super.pixel_bits > 16) {
         return Raster.createPackedRaster(3, var1, var2, var3, (Point)null);
      } else {
         return super.pixel_bits > 8 ? Raster.createPackedRaster(1, var1, var2, var3, (Point)null) : Raster.createPackedRaster(0, var1, var2, var3, (Point)null);
      }
   }

   public int getDataElement(int[] var1, int var2) {
      int var3 = 0;

      for(int var4 = 0; var4 < super.numComponents; ++var4) {
         var3 |= var1[var2 + var4] << super.maskOffsets[var4] & super.maskArray[var4];
      }

      return var3;
   }

   public Object getDataElements(int[] var1, int var2, Object var3) {
      int var4 = 0;

      for(int var5 = 0; var5 < super.numComponents; ++var5) {
         var4 |= var1[var2 + var5] << super.maskOffsets[var5] & super.maskArray[var5];
      }

      switch (super.transferType) {
         case 0:
            if (var3 instanceof byte[]) {
               byte[] var11 = (byte[])var3;
               var11[0] = (byte)(var4 & 255);
               return var11;
            }

            byte[] var10 = new byte[]{(byte)(var4 & 255)};
            return var10;
         case 1:
            if (var3 instanceof short[]) {
               short[] var9 = (short[])var3;
               var9[0] = (short)(var4 & '\uffff');
               return var9;
            }

            short[] var8 = new short[]{(short)(var4 & '\uffff')};
            return var8;
         case 2:
         default:
            throw new ClassCastException("This method has not been implemented for transferType " + super.transferType);
         case 3:
            if (var3 instanceof int[]) {
               int[] var7 = (int[])var3;
               var7[0] = var4;
               return var7;
            } else {
               int[] var6 = new int[]{var4};
               return var6;
            }
      }
   }

   public final ColorModel coerceData(WritableRaster var1, boolean var2) {
      if (super.supportsAlpha && ((ColorModel)this).isAlphaPremultiplied() != var2) {
         int var3 = ((Raster)var1).getWidth();
         int var4 = ((Raster)var1).getHeight();
         int var5 = super.numColorComponents;
         int var7 = (1 << super.nBits[var5]) - 1;
         int var8 = ((Raster)var1).getMinX();
         int var9 = ((Raster)var1).getMinY();
         int[] var11 = null;
         if (var2) {
            switch (super.transferType) {
               case 0:
                  for(int var26 = 0; var26 < var4; ++var9) {
                     int var21 = var8;

                     for(int var31 = 0; var31 < var3; ++var21) {
                        var11 = ((Raster)var1).getPixel(var21, var9, var11);
                        float var16 = (float)(var11[var5] / var7);
                        if (var16 != 0.0F) {
                           for(int var36 = 0; var36 < var5; ++var36) {
                              var11[var36] = (int)((float)var11[var36] * var16);
                           }

                           var1.setPixel(var21, var9, var11);
                        }

                        ++var31;
                     }

                     ++var26;
                  }
                  break;
               case 1:
                  for(int var25 = 0; var25 < var4; ++var9) {
                     int var20 = var8;

                     for(int var30 = 0; var30 < var3; ++var20) {
                        var11 = ((Raster)var1).getPixel(var20, var9, var11);
                        float var15 = (float)(var11[var5] / var7);
                        if (var15 != 0.0F) {
                           for(int var35 = 0; var35 < var5; ++var35) {
                              var11[var35] = (int)((float)var11[var35] * var15);
                           }

                           var1.setPixel(var20, var9, var11);
                        }

                        ++var30;
                     }

                     ++var25;
                  }
                  break;
               case 2:
               default:
                  throw new UnsupportedOperationException("This method has not been implemented for transferType " + super.transferType);
               case 3:
                  for(int var12 = 0; var12 < var4; ++var9) {
                     int var10 = var8;

                     for(int var13 = 0; var13 < var3; ++var10) {
                        var11 = ((Raster)var1).getPixel(var10, var9, var11);
                        float var6 = (float)(var11[var5] / var7);
                        if (var6 != 0.0F) {
                           for(int var14 = 0; var14 < var5; ++var14) {
                              var11[var14] = (int)((float)var11[var14] * var6);
                           }

                           var1.setPixel(var10, var9, var11);
                        }

                        ++var13;
                     }

                     ++var12;
                  }
            }
         } else {
            switch (super.transferType) {
               case 0:
                  for(int var29 = 0; var29 < var4; ++var9) {
                     int var24 = var8;

                     for(int var34 = 0; var34 < var3; ++var24) {
                        var11 = ((Raster)var1).getPixel(var24, var9, var11);
                        float var19 = (float)(var11[var5] / var7);
                        if (var19 != 0.0F) {
                           for(int var39 = 0; var39 < var5; ++var39) {
                              var11[var39] = (int)((float)var11[var39] / var19);
                           }
                        }

                        var1.setPixel(var24, var9, var11);
                        ++var34;
                     }

                     ++var29;
                  }
                  break;
               case 1:
                  for(int var28 = 0; var28 < var4; ++var9) {
                     int var23 = var8;

                     for(int var33 = 0; var33 < var3; ++var23) {
                        var11 = ((Raster)var1).getPixel(var23, var9, var11);
                        float var18 = (float)(var11[var5] / var7);
                        if (var18 != 0.0F) {
                           for(int var38 = 0; var38 < var5; ++var38) {
                              var11[var38] = (int)((float)var11[var38] / var18);
                           }
                        }

                        var1.setPixel(var23, var9, var11);
                        ++var33;
                     }

                     ++var28;
                  }
                  break;
               case 2:
               default:
                  throw new UnsupportedOperationException("This method has not been implemented for transferType " + super.transferType);
               case 3:
                  for(int var27 = 0; var27 < var4; ++var9) {
                     int var22 = var8;

                     for(int var32 = 0; var32 < var3; ++var22) {
                        var11 = ((Raster)var1).getPixel(var22, var9, var11);
                        float var17 = (float)(var11[var5] / var7);
                        if (var17 != 0.0F) {
                           for(int var37 = 0; var37 < var5; ++var37) {
                              var11[var37] = (int)((float)var11[var37] / var17);
                           }
                        }

                        var1.setPixel(var22, var9, var11);
                        ++var32;
                     }

                     ++var27;
                  }
            }
         }

         return new DirectColorModel(super.colorSpace, super.pixel_bits, super.maskArray[0], super.maskArray[1], super.maskArray[2], super.maskArray[3], var2, super.transferType);
      } else {
         return this;
      }
   }

   public boolean isCompatibleRaster(Raster var1) {
      SampleModel var2 = var1.getSampleModel();
      if (!(var2 instanceof SinglePixelPackedSampleModel)) {
         return false;
      } else {
         SinglePixelPackedSampleModel var3 = (SinglePixelPackedSampleModel)var2;
         if (((SampleModel)var3).getNumBands() != ((ColorModel)this).getNumComponents()) {
            return false;
         } else {
            int[] var4 = var3.getBitMasks();

            for(int var5 = 0; var5 < super.numComponents; ++var5) {
               if (var4[var5] != super.maskArray[var5]) {
                  return false;
               }
            }

            return var1.getTransferType() == super.transferType;
         }
      }
   }

   private void setFields() {
      this.red_mask = super.maskArray[0];
      this.red_offset = super.maskOffsets[0];
      this.green_mask = super.maskArray[1];
      this.green_offset = super.maskOffsets[1];
      this.blue_mask = super.maskArray[2];
      this.blue_offset = super.maskOffsets[2];
      if (super.nBits[0] < 8) {
         this.red_scale = (1 << super.nBits[0]) - 1;
      }

      if (super.nBits[1] < 8) {
         this.green_scale = (1 << super.nBits[1]) - 1;
      }

      if (super.nBits[2] < 8) {
         this.blue_scale = (1 << super.nBits[2]) - 1;
      }

      if (super.supportsAlpha) {
         this.alpha_mask = super.maskArray[3];
         this.alpha_offset = super.maskOffsets[3];
         if (super.nBits[3] < 8) {
            this.alpha_scale = (1 << super.nBits[3]) - 1;
         }
      }

   }

   public String toString() {
      return new String("DirectColorModel: rmask=" + Integer.toHexString(this.red_mask) + " gmask=" + Integer.toHexString(this.green_mask) + " bmask=" + Integer.toHexString(this.blue_mask) + " amask=" + Integer.toHexString(this.alpha_mask));
   }
}
