package java.awt.image;

import java.awt.Point;
import java.awt.color.ColorSpace;
import java.math.BigInteger;
import java.util.Arrays;
import java.util.Hashtable;
import sun.java2d.loops.ImageData;

public class IndexColorModel extends ColorModel {
   private int[] rgb;
   private int map_size;
   private int transparent_index;
   private boolean allgrayopaque;
   private BigInteger validBits;
   private static final int CACHESIZE = 40;
   private int[] lookupcache;

   private static native void initIDs();

   public IndexColorModel(int var1, int var2, byte[] var3, byte[] var4, byte[] var5) {
      super(var1, setBits(var1, false), ColorSpace.getInstance(1000), false, false, 1, ColorModel.getDefaultTransferType(var1));
      this.transparent_index = -1;
      this.lookupcache = new int[40];
      if (var1 >= 1 && var1 <= 16) {
         this.setRGBs(var2, var3, var4, var5, (byte[])null);
         this.checkAllGrayOpaque();
      } else {
         throw new IllegalArgumentException("Number of bits must be between 1 and 16.");
      }
   }

   public IndexColorModel(int var1, int var2, byte[] var3, byte[] var4, byte[] var5, int var6) {
      super(var1, setBits(var1, var6 >= 0), ColorSpace.getInstance(1000), var6 > -1, false, 2, ColorModel.getDefaultTransferType(var1));
      this.transparent_index = -1;
      this.lookupcache = new int[40];
      if (var1 >= 1 && var1 <= 16) {
         this.setRGBs(var2, var3, var4, var5, (byte[])null);
         if (var6 > -1) {
            super.transparency = 2;
            this.setTransparentPixel(var6);
         }

         this.checkAllGrayOpaque();
      } else {
         throw new IllegalArgumentException("Number of bits must be between 1 and 16.");
      }
   }

   public IndexColorModel(int var1, int var2, byte[] var3, byte[] var4, byte[] var5, byte[] var6) {
      super(var1, setBits(var1, true), ColorSpace.getInstance(1000), true, false, 3, ColorModel.getDefaultTransferType(var1));
      this.transparent_index = -1;
      this.lookupcache = new int[40];
      if (var1 >= 1 && var1 <= 16) {
         this.setRGBs(var2, var3, var4, var5, var6);
         this.setTransparentPixel(-1);
         this.checkAllGrayOpaque();
      } else {
         throw new IllegalArgumentException("Number of bits must be between 1 and 16.");
      }
   }

   public IndexColorModel(int var1, int var2, byte[] var3, int var4, boolean var5) {
      this(var1, var2, var3, var4, var5, -1);
      if (var1 < 1 || var1 > 16) {
         throw new IllegalArgumentException("Number of bits must be between 1 and 16.");
      }
   }

   public IndexColorModel(int var1, int var2, byte[] var3, int var4, boolean var5, int var6) {
      super(var1, setBits(var1, var5 || var6 > -1), ColorSpace.getInstance(1000), var5 || var6 > -1, false, var5 ? 3 : (var6 >= 0 ? 2 : 1), ColorModel.getDefaultTransferType(var1));
      this.transparent_index = -1;
      this.lookupcache = new int[40];
      if (var1 >= 1 && var1 <= 16) {
         if (var2 < 1) {
            throw new IllegalArgumentException("Map size (" + var2 + ") must be >= 1");
         } else {
            this.map_size = var2;
            this.rgb = new int[Math.max(var2, 256)];
            int var7 = var4;
            short var8 = 255;
            super.transparency = 1;

            for(int var9 = 0; var9 < var2; ++var9) {
               this.rgb[var9] = (var3[var7++] & 255) << 16 | (var3[var7++] & 255) << 8 | var3[var7++] & 255;
               if (var5) {
                  var8 = var3[var7++];
                  if (var8 != 255 && super.transparency != 3) {
                     super.transparency = var8 == 0 ? 2 : 3;
                  }
               }

               int[] var10000 = this.rgb;
               var10000[var9] |= var8 << 24;
            }

            this.setTransparentPixel(var6);
            if (this.transparent_index >= 0) {
               if (super.transparency == 1) {
                  super.transparency = 2;
               }
            } else if (super.transparency == 1) {
               super.supportsAlpha = false;
               super.numComponents = 3;
            }

            if (super.supportsAlpha) {
               super.nBits = new int[4];
               super.nBits[0] = super.nBits[1] = super.nBits[2] = super.nBits[3] = 8;
            } else {
               if (this.transparent_index > -1) {
                  super.nBits = new int[4];
                  super.nBits[3] = 1;
               } else {
                  super.nBits = new int[3];
               }

               super.nBits[0] = super.nBits[1] = super.nBits[2] = 8;
            }

            this.checkAllGrayOpaque();
         }
      } else {
         throw new IllegalArgumentException("Number of bits must be between 1 and 16.");
      }
   }

   public IndexColorModel(int var1, int var2, int[] var3, int var4, boolean var5, int var6, int var7) {
      super(var1, setBits(var1, var5), ColorSpace.getInstance(1000), var5 ? true : var6 >= 0, false, var5 ? 3 : (var6 >= 0 ? 2 : 1), var7);
      this.transparent_index = -1;
      this.lookupcache = new int[40];
      if (var1 >= 1 && var1 <= 16) {
         if (var2 < 1) {
            throw new IllegalArgumentException("Map size (" + var2 + ") must be >= 1");
         } else {
            this.map_size = var2;
            this.rgb = new int[Math.max(var2, 256)];
            int var8 = var4;
            int var9 = -16777216;
            super.transparency = 1;
            if (!var5) {
               for(int var10 = 0; var10 < var2; ++var8) {
                  this.rgb[var10] = var3[var8] | -16777216;
                  ++var10;
               }
            } else {
               for(int var12 = 0; var12 < var2; ++var8) {
                  this.rgb[var12] = var3[var8];
                  var9 = var3[var8] & -16777216;
                  if (var9 != -16777216 && super.transparency != 3) {
                     super.transparency = var9 == 0 ? 2 : 3;
                  }

                  ++var12;
               }
            }

            this.setTransparentPixel(var6);
            if (this.transparent_index >= 0 && super.transparency == 1) {
               super.transparency = 2;
            }

            this.checkAllGrayOpaque();
         }
      } else {
         throw new IllegalArgumentException("Number of bits must be between 1 and 16.");
      }
   }

   public IndexColorModel(int var1, int var2, int[] var3, int var4, int var5, BigInteger var6) {
      super(var1, setBits(var1, true), ColorSpace.getInstance(1000), true, false, 3, var5);
      this.transparent_index = -1;
      this.lookupcache = new int[40];
      if (var1 >= 1 && var1 <= 32) {
         if (var2 < 1) {
            throw new IllegalArgumentException("Map size (" + var2 + ") must be >= 1");
         } else {
            this.map_size = var2;
            if (var6 != null) {
               for(int var7 = 0; var7 < var2; ++var7) {
                  if (!var6.testBit(var7)) {
                     this.validBits = var6;
                     break;
                  }
               }
            }

            this.rgb = new int[Math.max(var2, 256)];
            int var10 = var4;
            super.transparency = 1;

            for(int var9 = 0; var9 < var2; ++var10) {
               this.rgb[var9] = var3[var10];
               int var8 = var3[var10] & -16777216;
               if (var8 != -16777216 && super.transparency != 3) {
                  super.transparency = var8 == 0 ? 2 : 3;
               }

               ++var9;
            }

            this.checkAllGrayOpaque();
         }
      } else {
         throw new IllegalArgumentException("Number of bits must be between 1 and 32.");
      }
   }

   private void setRGBs(int var1, byte[] var2, byte[] var3, byte[] var4, byte[] var5) {
      if (var1 < 1) {
         throw new IllegalArgumentException("Map size (" + var1 + ") must be >= 1");
      } else {
         this.map_size = var1;
         this.rgb = new int[Math.max(var1, 256)];
         int var6 = 255;
         super.transparency = 1;

         for(int var7 = 0; var7 < var1; ++var7) {
            if (var5 != null) {
               var6 = var5[var7] & 255;
               if (var6 != 255 && super.transparency != 3) {
                  super.transparency = var6 == 0 ? 2 : 3;
               }
            }

            this.rgb[var7] = var6 << 24 | (var2[var7] & 255) << 16 | (var3[var7] & 255) << 8 | var4[var7] & 255;
         }

         super.nBits = new int[4];
         super.nBits[0] = super.nBits[1] = super.nBits[2] = super.nBits[3] = 8;
         super.maxBits = 8;
      }
   }

   private BigInteger getAllValid() {
      int var2 = (this.map_size + 7) / 8;
      byte[] var3 = new byte[var2];
      Arrays.fill(var3, (byte)-1);
      var3[0] = (byte)(255 >>> var2 * 8 - this.map_size);
      return new BigInteger(1, var3);
   }

   private void checkAllGrayOpaque() {
      this.allgrayopaque = false;
      if (this.transparent_index < 0 && super.transparency != 3) {
         for(int var2 = 0; var2 < this.map_size; ++var2) {
            int var1 = this.rgb[var2];
            if (var1 != 0) {
               if ((var1 & -16777216) != -16777216) {
                  return;
               }

               if ((var1 >> 16 & 255) != (var1 >> 8 & 255) || (var1 >> 8 & 255) != (var1 & 255)) {
                  return;
               }
            }
         }

         this.allgrayopaque = true;
         super.transparency = 1;
      }
   }

   public int getTransparency() {
      return super.transparency;
   }

   public int[] getComponentSize() {
      if (super.nBits == null) {
         if (super.supportsAlpha) {
            super.nBits = new int[4];
            super.nBits[3] = 8;
         } else {
            super.nBits = new int[3];
         }

         super.nBits[0] = super.nBits[1] = super.nBits[2] = 8;
      }

      return super.nBits;
   }

   public final int getMapSize() {
      return this.map_size;
   }

   public final int getTransparentPixel() {
      return this.transparent_index;
   }

   public final void getReds(byte[] var1) {
      for(int var2 = 0; var2 < this.map_size; ++var2) {
         var1[var2] = (byte)(this.rgb[var2] >> 16);
      }

   }

   public final void getGreens(byte[] var1) {
      for(int var2 = 0; var2 < this.map_size; ++var2) {
         var1[var2] = (byte)(this.rgb[var2] >> 8);
      }

   }

   public final void getBlues(byte[] var1) {
      for(int var2 = 0; var2 < this.map_size; ++var2) {
         var1[var2] = (byte)this.rgb[var2];
      }

   }

   public final void getAlphas(byte[] var1) {
      for(int var2 = 0; var2 < this.map_size; ++var2) {
         var1[var2] = (byte)(this.rgb[var2] >> 24);
      }

   }

   public final void getRGBs(int[] var1) {
      System.arraycopy(this.rgb, 0, var1, 0, this.map_size);
   }

   private void setTransparentPixel(int var1) {
      if (var1 < this.map_size && var1 >= 0) {
         int[] var10000 = this.rgb;
         var10000[var1] &= 16777215;
      } else {
         var1 = -1;
      }

      this.transparent_index = var1;
   }

   public final int getRed(int var1) {
      return this.rgb[var1] >> 16 & 255;
   }

   public final int getGreen(int var1) {
      return this.rgb[var1] >> 8 & 255;
   }

   public final int getBlue(int var1) {
      return this.rgb[var1] & 255;
   }

   public final int getAlpha(int var1) {
      return this.rgb[var1] >> 24 & 255;
   }

   public final int getRGB(int var1) {
      return this.rgb[var1];
   }

   public synchronized Object getDataElements(int var1, Object var2) {
      int var3 = var1 >> 16 & 255;
      int var4 = var1 >> 8 & 255;
      int var5 = var1 & 255;
      int var6 = var1 >>> 24;
      int var7 = 0;

      for(int var8 = 38; var8 >= 0 && (var7 = this.lookupcache[var8]) != 0; var8 -= 2) {
         if (var1 == this.lookupcache[var8 + 1]) {
            return this.installpixel(var2, ~var7);
         }
      }

      if (var6 == 0) {
         if (this.transparent_index > -1) {
            var7 = this.transparent_index;
         } else {
            for(int var9 = 0; var9 < this.map_size; ++var9) {
               if (this.rgb[var9] < 16777216) {
                  this.transparent_index = var9;
                  var7 = var9;
                  break;
               }
            }
         }
      } else {
         int var15 = 16581375;
         int var10 = 255;

         for(int var11 = 0; var11 < this.map_size; ++var11) {
            int var12 = this.rgb[var11];
            if (var12 == var1) {
               var7 = var11;
               break;
            }

            int var13 = (var12 >>> 24) - var6;
            if (var13 < 0) {
               var13 = -var13;
            }

            if (var13 <= var10) {
               var10 = var13;
               var13 = (var12 >> 16 & 255) - var3;
               int var14 = var13 * var13;
               if (var14 < var15) {
                  var13 = (var12 >> 8 & 255) - var4;
                  var14 += var13 * var13;
                  if (var14 < var15) {
                     var13 = (var12 & 255) - var5;
                     var14 += var13 * var13;
                     if (var14 < var15) {
                        var7 = var11;
                        var15 = var14;
                     }
                  }
               }
            }
         }
      }

      System.arraycopy(this.lookupcache, 2, this.lookupcache, 0, 38);
      this.lookupcache[39] = var1;
      this.lookupcache[38] = ~var7;
      return this.installpixel(var2, var7);
   }

   private Object installpixel(Object var1, int var2) {
      switch (super.transferType) {
         case 0:
            byte[] var4;
            if (var1 == null) {
               var1 = var4 = new byte[1];
            } else {
               var4 = (byte[])var1;
            }

            var4[0] = (byte)var2;
            break;
         case 1:
            short[] var5;
            if (var1 == null) {
               var1 = var5 = new short[1];
            } else {
               var5 = (short[])var1;
            }

            var5[0] = (short)var2;
            break;
         case 2:
         default:
            throw new UnsupportedOperationException("This method has not been implemented for transferType " + super.transferType);
         case 3:
            int[] var3;
            if (var1 == null) {
               var1 = var3 = new int[1];
            } else {
               var3 = (int[])var1;
            }

            var3[0] = var2;
      }

      return var1;
   }

   public int[] getComponents(int var1, int[] var2, int var3) {
      if (var2 == null) {
         var2 = new int[var3 + super.numComponents];
      }

      var2[var3 + 0] = this.getRed(var1);
      var2[var3 + 1] = this.getGreen(var1);
      var2[var3 + 2] = this.getBlue(var1);
      if (super.supportsAlpha && var2.length - var3 > 3) {
         var2[var3 + 3] = this.getAlpha(var1);
      }

      return var2;
   }

   public int[] getComponents(Object var1, int[] var2, int var3) {
      int var4;
      switch (super.transferType) {
         case 0:
            byte[] var5 = (byte[])var1;
            var4 = var5[0] & 255;
            break;
         case 1:
            short[] var6 = (short[])var1;
            var4 = var6[0] & '\uffff';
            break;
         case 2:
         default:
            throw new UnsupportedOperationException("This method has not been implemented for transferType " + super.transferType);
         case 3:
            int[] var7 = (int[])var1;
            var4 = var7[0];
      }

      return this.getComponents(var4, var2, var3);
   }

   public int getDataElement(int[] var1, int var2) {
      int var3 = var1[var2 + 0] << 16 | var1[var2 + 1] << 8 | var1[var2 + 2];
      if (super.supportsAlpha) {
         var3 |= var1[var2 + 3] << 24;
      } else {
         var3 |= -16777216;
      }

      Object var4 = this.getDataElements(var3, (Object)null);
      int var5;
      switch (super.transferType) {
         case 0:
            byte[] var6 = (byte[])var4;
            var5 = var6[0] & 255;
            break;
         case 1:
            short[] var7 = (short[])var4;
            var5 = var7[0];
            break;
         case 2:
         default:
            throw new UnsupportedOperationException("This method has not been implemented for transferType " + super.transferType);
         case 3:
            int[] var8 = (int[])var4;
            var5 = var8[0];
      }

      return var5;
   }

   public Object getDataElements(int[] var1, int var2, Object var3) {
      int var4 = var1[var2 + 0] << 16 | var1[var2 + 1] << 8 | var1[var2 + 2];
      if (super.supportsAlpha) {
         var4 |= var1[var2 + 3] << 24;
      } else {
         var4 &= -16777216;
      }

      return this.getDataElements(var4, var3);
   }

   public WritableRaster createCompatibleWritableRaster(int var1, int var2) {
      WritableRaster var3;
      if (super.pixel_bits != 1 && super.pixel_bits != 2 && super.pixel_bits != 4) {
         if (super.pixel_bits <= 8) {
            var3 = Raster.createInterleavedRaster(0, var1, var2, 1, (Point)null);
         } else {
            if (super.pixel_bits > 16) {
               throw new UnsupportedOperationException("This method is not supported  for pixel bits > 16.");
            }

            var3 = Raster.createInterleavedRaster(1, var1, var2, 1, (Point)null);
         }
      } else {
         var3 = Raster.createPackedRaster(0, var1, var2, 1, super.pixel_bits, (Point)null);
      }

      return var3;
   }

   public boolean isCompatibleRaster(Raster var1) {
      int var2 = var1.getSampleModel().getSampleSize(0);
      return var1.getTransferType() == super.transferType && var1.getNumBands() == 1 && 1 << var2 >= this.map_size;
   }

   public SampleModel createCompatibleSampleModel(int var1, int var2) {
      int[] var3 = new int[]{0};
      return (SampleModel)(super.pixel_bits != 1 && super.pixel_bits != 2 && super.pixel_bits != 4 ? new ComponentSampleModel(super.transferType, var1, var2, 1, var1, var3) : new MultiPixelPackedSampleModel(super.transferType, var1, var2, super.pixel_bits));
   }

   public boolean isCompatibleSampleModel(SampleModel var1) {
      if (!(var1 instanceof ComponentSampleModel) && !(var1 instanceof MultiPixelPackedSampleModel)) {
         return false;
      } else if (var1.getTransferType() != super.transferType) {
         return false;
      } else {
         return var1.getNumBands() == 1;
      }
   }

   public BufferedImage convertToIntDiscrete(Raster var1, boolean var2) {
      Object var3;
      if (!var2 && super.transparency != 3) {
         if (super.transparency == 2) {
            var3 = new DirectColorModel(25, 16711680, 65280, 255, 16777216);
         } else {
            var3 = new DirectColorModel(24, 16711680, 65280, 255);
         }
      } else {
         var3 = ColorModel.getRGBdefault();
      }

      int var4 = var1.getWidth();
      int var5 = var1.getHeight();
      WritableRaster var6 = ((ColorModel)var3).createCompatibleWritableRaster(var4, var5);
      Object var7 = null;
      Object var8 = null;
      int var9 = var1.getMinX();
      int var10 = var1.getMinY();

      for(int var11 = 0; var11 < var5; ++var10) {
         var7 = var1.getDataElements(var9, var10, var4, 1, var7);
         int[] var13;
         if (var7 instanceof int[]) {
            var13 = (int[])var7;
         } else {
            var13 = DataBuffer.toIntArray(var7);
         }

         for(int var12 = 0; var12 < var4; ++var12) {
            var13[var12] = this.rgb[var13[var12]];
         }

         var6.setDataElements(0, var11, var4, 1, var13);
         ++var11;
      }

      return new BufferedImage((ColorModel)var3, var6, false, (Hashtable)null);
   }

   public boolean isValid(int var1) {
      if (this.validBits == null) {
         return var1 >= 0 && var1 < this.map_size;
      } else {
         return var1 < this.map_size && this.validBits.testBit(var1);
      }
   }

   public boolean isValid() {
      return this.validBits == null;
   }

   public BigInteger getValidPixels() {
      return this.validBits == null ? this.getAllValid() : this.validBits;
   }

   private static int[] setBits(int var0, boolean var1) {
      int[] var2 = new int[3 + (var1 ? 1 : 0)];
      var2[0] = var2[1] = var2[2] = 8;
      if (var1) {
         var2[3] = 8;
      }

      return var2;
   }

   public void finalize() {
      ImageData.freeNativeICMData(this);
   }

   public String toString() {
      return new String("IndexColorModel: #pixelBits = " + super.pixel_bits + " numComponents = " + super.numComponents + " color space = " + super.colorSpace + " transparency = " + super.transparency + " transIndex   = " + this.transparent_index + " has alpha = " + super.supportsAlpha + " isAlphaPre = " + super.isAlphaPremultiplied);
   }

   static {
      ColorModel.loadLibraries();
      initIDs();
   }
}
