package java.awt.image;

import java.awt.Point;
import java.awt.Rectangle;

public class WritableRaster extends Raster {
   protected WritableRaster(SampleModel var1, Point var2) {
      this(var1, var1.createDataBuffer(), new Rectangle(var2.x, var2.y, var1.getWidth(), var1.getHeight()), var2, (WritableRaster)null);
   }

   protected WritableRaster(SampleModel var1, DataBuffer var2, Point var3) {
      this(var1, var2, new Rectangle(var3.x, var3.y, var1.getWidth(), var1.getHeight()), var3, (WritableRaster)null);
   }

   protected WritableRaster(SampleModel var1, DataBuffer var2, Rectangle var3, Point var4, WritableRaster var5) {
      super(var1, var2, var3, var4, var5);
   }

   public WritableRaster getWritableParent() {
      return (WritableRaster)super.parent;
   }

   public WritableRaster createWritableTranslatedChild(int var1, int var2) {
      return this.createWritableChild(super.minX, super.minY, super.width, super.height, var1, var2, (int[])null);
   }

   public WritableRaster createWritableChild(int var1, int var2, int var3, int var4, int var5, int var6, int[] var7) {
      if (var1 < super.minX) {
         throw new RasterFormatException("parentX lies outside raster");
      } else if (var2 < super.minY) {
         throw new RasterFormatException("parentY lies outside raster");
      } else if (var1 + var3 > super.width + super.minX) {
         throw new RasterFormatException("(parentX + width) is outside raster");
      } else if (var2 + var4 > super.height + super.minY) {
         throw new RasterFormatException("(parentY + height) is outside raster");
      } else {
         SampleModel var11;
         if (var7 != null) {
            var11 = super.sampleModel.createCompatibleSampleModel(super.sampleModel.width, super.sampleModel.height);
            var11 = var11.createSubsetSampleModel(var7);
         } else {
            var11 = super.sampleModel;
         }

         int var9 = var5 - var1;
         int var10 = var6 - var2;
         return new WritableRaster(var11, super.dataBuffer, new Rectangle(var5, var6, var3, var4), new Point(super.sampleModelTranslateX + var9, super.sampleModelTranslateY + var10), this);
      }
   }

   public void setDataElements(int var1, int var2, Object var3) {
      super.sampleModel.setDataElements(var1 - super.sampleModelTranslateX, var2 - super.sampleModelTranslateY, var3, super.dataBuffer);
   }

   public void setDataElements(int var1, int var2, Raster var3) {
      int var4 = var3.getWidth();
      int var5 = var3.getHeight();
      int var6 = var3.getMinX();
      int var7 = var3.getMinY();
      int var8 = var1 + var3.getMinX();
      int var9 = var2 + var3.getMinY();
      Object var10 = null;

      for(int var11 = 0; var11 < var5; ++var11) {
         var10 = var3.getDataElements(var6, var7 + var11, var4, 1, var10);
         this.setDataElements(var8, var9 + var11, var4, 1, var10);
      }

   }

   public void setDataElements(int var1, int var2, int var3, int var4, Object var5) {
      super.sampleModel.setDataElements(var1 - super.sampleModelTranslateX, var2 - super.sampleModelTranslateY, var3, var4, var5, super.dataBuffer);
   }

   public void setRect(Raster var1) {
      this.setRect(0, 0, var1);
   }

   public void setRect(int var1, int var2, Raster var3) {
      int var4 = var3.getWidth();
      int var5 = var3.getHeight();
      int var6 = var3.getMinX();
      int var7 = var3.getMinY();
      int var8 = var1 + var6;
      int var9 = var2 + var7;
      if (var8 + var4 > super.minX + super.width) {
         var4 = super.minX + super.width - var8;
      }

      if (var9 + var5 > super.minY + super.height) {
         var5 = super.minY + super.height - var9;
      }

      switch (var3.getSampleModel().getDataType()) {
         case 0:
         case 1:
         case 2:
         case 3:
            int[] var10 = null;

            for(int var11 = 0; var11 < var5; ++var11) {
               var10 = var3.getPixels(var6, var7 + var11, var4, 1, var10);
               this.setPixels(var8, var9 + var11, var4, 1, (int[])var10);
            }
            break;
         case 4:
            float[] var12 = null;

            for(int var13 = 0; var13 < var5; ++var13) {
               var12 = var3.getPixels(var6, var7 + var13, var4, 1, var12);
               this.setPixels(var8, var9 + var13, var4, 1, (float[])var12);
            }
            break;
         case 5:
            double[] var14 = null;

            for(int var15 = 0; var15 < var5; ++var15) {
               var14 = var3.getPixels(var6, var7 + var15, var4, 1, var14);
               this.setPixels(var8, var9 + var15, var4, 1, (double[])var14);
            }
      }

   }

   public void setPixel(int var1, int var2, int[] var3) {
      super.sampleModel.setPixel(var1 - super.sampleModelTranslateX, var2 - super.sampleModelTranslateY, var3, super.dataBuffer);
   }

   public void setPixel(int var1, int var2, float[] var3) {
      super.sampleModel.setPixel(var1 - super.sampleModelTranslateX, var2 - super.sampleModelTranslateY, var3, super.dataBuffer);
   }

   public void setPixel(int var1, int var2, double[] var3) {
      super.sampleModel.setPixel(var1 - super.sampleModelTranslateX, var2 - super.sampleModelTranslateY, var3, super.dataBuffer);
   }

   public void setPixels(int var1, int var2, int var3, int var4, int[] var5) {
      super.sampleModel.setPixels(var1 - super.sampleModelTranslateX, var2 - super.sampleModelTranslateY, var3, var4, var5, super.dataBuffer);
   }

   public void setPixels(int var1, int var2, int var3, int var4, float[] var5) {
      super.sampleModel.setPixels(var1 - super.sampleModelTranslateX, var2 - super.sampleModelTranslateY, var3, var4, var5, super.dataBuffer);
   }

   public void setPixels(int var1, int var2, int var3, int var4, double[] var5) {
      super.sampleModel.setPixels(var1 - super.sampleModelTranslateX, var2 - super.sampleModelTranslateY, var3, var4, var5, super.dataBuffer);
   }

   public void setSample(int var1, int var2, int var3, int var4) {
      super.sampleModel.setSample(var1 - super.sampleModelTranslateX, var2 - super.sampleModelTranslateY, var3, var4, super.dataBuffer);
   }

   public void setSample(int var1, int var2, int var3, float var4) {
      super.sampleModel.setSample(var1 - super.sampleModelTranslateX, var2 - super.sampleModelTranslateY, var3, var4, super.dataBuffer);
   }

   public void setSample(int var1, int var2, int var3, double var4) {
      super.sampleModel.setSample(var1 - super.sampleModelTranslateX, var2 - super.sampleModelTranslateY, var3, var4, super.dataBuffer);
   }

   public void setSamples(int var1, int var2, int var3, int var4, int var5, int[] var6) {
      super.sampleModel.setSamples(var1 - super.sampleModelTranslateX, var2 - super.sampleModelTranslateY, var3, var4, var5, var6, super.dataBuffer);
   }

   public void setSamples(int var1, int var2, int var3, int var4, int var5, float[] var6) {
      super.sampleModel.setSamples(var1 - super.sampleModelTranslateX, var2 - super.sampleModelTranslateY, var3, var4, var5, var6, super.dataBuffer);
   }

   public void setSamples(int var1, int var2, int var3, int var4, int var5, double[] var6) {
      super.sampleModel.setSamples(var1 - super.sampleModelTranslateX, var2 - super.sampleModelTranslateY, var3, var4, var5, var6, super.dataBuffer);
   }
}
