package java.awt;

import java.awt.event.ActionEvent;
import java.awt.event.AdjustmentEvent;
import java.awt.event.InputEvent;
import java.awt.event.ItemEvent;
import java.awt.event.KeyEvent;
import java.awt.event.MouseEvent;
import java.util.EventObject;

public abstract class AWTEvent extends EventObject {
   private transient long data;
   // $FF: renamed from: id int
   protected int field_0;
   protected boolean consumed;
   public static final long COMPONENT_EVENT_MASK = 1L;
   public static final long CONTAINER_EVENT_MASK = 2L;
   public static final long FOCUS_EVENT_MASK = 4L;
   public static final long KEY_EVENT_MASK = 8L;
   public static final long MOUSE_EVENT_MASK = 16L;
   public static final long MOUSE_MOTION_EVENT_MASK = 32L;
   public static final long WINDOW_EVENT_MASK = 64L;
   public static final long ACTION_EVENT_MASK = 128L;
   public static final long ADJUSTMENT_EVENT_MASK = 256L;
   public static final long ITEM_EVENT_MASK = 512L;
   public static final long TEXT_EVENT_MASK = 1024L;
   public static final long INPUT_METHOD_EVENT_MASK = 2048L;
   static final long INPUT_METHODS_ENABLED_MASK = 4096L;
   public static final long PAINT_EVENT_MASK = 8192L;
   public static final long INVOCATION_EVENT_MASK = 16384L;
   public static final long HIERARCHY_EVENT_MASK = 32768L;
   public static final long HIERARCHY_BOUNDS_EVENT_MASK = 65536L;
   public static final int RESERVED_ID_MAX = 1999;
   private static final long serialVersionUID = -1825314779160409405L;

   private static native void initIDs();

   public AWTEvent(Event var1) {
      this(var1.target, var1.id);
   }

   public AWTEvent(Object var1, int var2) {
      super(var1);
      this.consumed = false;
      this.field_0 = var2;
      switch (var2) {
         case 601:
         case 701:
         case 900:
         case 1001:
            this.consumed = true;
         default:
      }
   }

   public int getID() {
      return this.field_0;
   }

   public String toString() {
      String var1 = null;
      if (super.source instanceof Component) {
         var1 = ((Component)super.source).getName();
      } else if (super.source instanceof MenuComponent) {
         var1 = ((MenuComponent)super.source).getName();
      }

      return this.getClass().getName() + "[" + this.paramString() + "] on " + (var1 != null ? var1 : super.source);
   }

   public String paramString() {
      return "";
   }

   protected void consume() {
      switch (this.field_0) {
         case 401:
         case 402:
         case 501:
         case 502:
         case 503:
         case 504:
         case 505:
         case 506:
         case 1100:
         case 1101:
            this.consumed = true;
         default:
      }
   }

   protected boolean isConsumed() {
      return this.consumed;
   }

   Event convertToOld() {
      Object var1 = ((EventObject)this).getSource();
      int var2 = this.field_0;
      switch (this.field_0) {
         case 100:
            if (var1 instanceof Frame || var1 instanceof Dialog) {
               Point var14 = ((Component)var1).getLocation();
               return new Event(var1, 0L, 205, var14.x, var14.y, 0, 0);
            }
         default:
            return null;
         case 201:
         case 203:
         case 204:
            return new Event(var1, var2, (Object)null);
         case 401:
         case 402:
            KeyEvent var3 = (KeyEvent)this;
            if (var3.isActionKey()) {
               var2 = this.field_0 == 401 ? 403 : 404;
            }

            int var4 = var3.getKeyCode();
            if (var4 != 16 && var4 != 17 && var4 != 18) {
               return new Event(var1, ((InputEvent)var3).getWhen(), var2, 0, 0, Event.getOldEventKey(var3), ((InputEvent)var3).getModifiers() & -17);
            }

            return null;
         case 501:
         case 502:
         case 503:
         case 504:
         case 505:
         case 506:
            MouseEvent var5 = (MouseEvent)this;
            Event var6 = new Event(var1, ((InputEvent)var5).getWhen(), var2, var5.getX(), var5.getY(), 0, ((InputEvent)var5).getModifiers() & -17);
            var6.clickCount = var5.getClickCount();
            return var6;
         case 601:
            AdjustmentEvent var11 = (AdjustmentEvent)this;
            switch (var11.getAdjustmentType()) {
               case 1:
                  var2 = 602;
                  break;
               case 2:
                  var2 = 601;
                  break;
               case 3:
                  var2 = 603;
                  break;
               case 4:
                  var2 = 604;
                  break;
               case 5:
                  var2 = 605;
                  break;
               default:
                  return null;
            }

            return new Event(var1, var2, new Integer(var11.getValue()));
         case 701:
            ItemEvent var9 = (ItemEvent)this;
            Object var10;
            if (var1 instanceof List) {
               var2 = var9.getStateChange() == 1 ? 701 : 702;
               var10 = var9.getItem();
            } else {
               var2 = 1001;
               if (var1 instanceof Choice) {
                  var10 = var9.getItem();
               } else {
                  var10 = new Boolean(var9.getStateChange() == 1);
               }
            }

            return new Event(var1, var2, var10);
         case 1001:
            ActionEvent var7 = (ActionEvent)this;
            String var8;
            if (var1 instanceof Button) {
               var8 = ((Button)var1).getLabel();
            } else if (var1 instanceof MenuItem) {
               var8 = ((MenuItem)var1).getLabel();
            } else {
               var8 = var7.getActionCommand();
            }

            return new Event(var1, 0L, var2, 0, 0, 0, var7.getModifiers(), var8);
         case 1004:
            return new Event(var1, 1004, (Object)null);
         case 1005:
            return new Event(var1, 1005, (Object)null);
      }
   }

   void movePrivateDataInto(AWTEvent var1) {
      var1.data = this.data;
      this.data = 0L;
   }

   void copyPrivateDataInto(AWTEvent var1) {
      this.copyDataFieldInto(var1);
   }

   private native void copyDataFieldInto(AWTEvent var1);

   private native void freeNativeData();

   protected void finalize() throws Throwable {
      this.freeNativeData();
      super.finalize();
   }

   static {
      Toolkit.loadLibraries();
      initIDs();
   }
}
