package java.awt;

import java.awt.event.ItemEvent;
import java.awt.event.ItemListener;
import java.awt.peer.CheckboxPeer;
import java.io.IOException;
import java.io.ObjectInputStream;
import java.io.ObjectOutputStream;
import java.util.EventListener;
import javax.accessibility.Accessible;
import javax.accessibility.AccessibleContext;

public class Checkbox extends Component implements ItemSelectable, Accessible {
   String label;
   boolean state;
   CheckboxGroup group;
   transient ItemListener itemListener;
   private static final String base = "checkbox";
   private static int nameCounter;
   private static final long serialVersionUID = 7270714317450821763L;
   private int checkboxSerializedDataVersion;
   // $FF: synthetic field
   static Class class$java$awt$event$ItemListener;

   void setStateInternal(boolean var1) {
      this.state = var1;
      CheckboxPeer var2 = (CheckboxPeer)super.peer;
      if (var2 != null) {
         var2.setState(var1);
      }

   }

   public Checkbox() {
      this("", false, (CheckboxGroup)null);
   }

   public Checkbox(String var1) {
      this(var1, false, (CheckboxGroup)null);
   }

   public Checkbox(String var1, boolean var2) {
      this(var1, var2, (CheckboxGroup)null);
   }

   public Checkbox(String var1, boolean var2, CheckboxGroup var3) {
      this.checkboxSerializedDataVersion = 1;
      this.label = var1;
      this.state = var2;
      this.group = var3;
      if (var2 && var3 != null) {
         var3.setSelectedCheckbox(this);
      }

   }

   public Checkbox(String var1, CheckboxGroup var2, boolean var3) {
      this(var1, var3, var2);
   }

   String constructComponentName() {
      Class var1 = this.getClass();
      synchronized(var1) {
         String var2 = "checkbox" + nameCounter++;
         return var2;
      }
   }

   public void addNotify() {
      Object var1 = ((Component)this).getTreeLock();
      synchronized(var1) {
         if (super.peer == null) {
            super.peer = ((Component)this).getToolkit().createCheckbox(this);
         }

         super.addNotify();
      }
   }

   public String getLabel() {
      return this.label;
   }

   public void setLabel(String var1) {
      boolean var2 = false;
      synchronized(this) {
         if (var1 != this.label && (this.label == null || !this.label.equals(var1))) {
            this.label = var1;
            CheckboxPeer var4 = (CheckboxPeer)super.peer;
            if (var4 != null) {
               var4.setLabel(var1);
            }

            var2 = true;
         }
      }

      if (var2 && super.valid) {
         ((Component)this).invalidate();
      }

   }

   public boolean getState() {
      return this.state;
   }

   public void setState(boolean var1) {
      CheckboxGroup var2 = this.group;
      if (var2 != null) {
         if (var1) {
            var2.setSelectedCheckbox(this);
         } else if (var2.getSelectedCheckbox() == this) {
            var1 = true;
         }
      }

      this.setStateInternal(var1);
   }

   public Object[] getSelectedObjects() {
      if (this.state) {
         Object[] var1 = new Object[]{this.label};
         return var1;
      } else {
         return null;
      }
   }

   public CheckboxGroup getCheckboxGroup() {
      return this.group;
   }

   public void setCheckboxGroup(CheckboxGroup var1) {
      CheckboxGroup var2 = this.group;
      if (var2 != null) {
         var2.setSelectedCheckbox((Checkbox)null);
      }

      synchronized(this) {
         this.group = var1;
         CheckboxPeer var4 = (CheckboxPeer)super.peer;
         if (var4 != null) {
            var4.setCheckboxGroup(var1);
         }

      }
   }

   public synchronized void addItemListener(ItemListener var1) {
      if (var1 != null) {
         this.itemListener = AWTEventMulticaster.add(this.itemListener, var1);
         super.newEventsOnly = true;
      }
   }

   public synchronized void removeItemListener(ItemListener var1) {
      if (var1 != null) {
         this.itemListener = AWTEventMulticaster.remove(this.itemListener, var1);
      }
   }

   public EventListener[] getListeners(Class var1) {
      Object var2 = null;
      if (var1 == (class$java$awt$event$ItemListener == null ? (class$java$awt$event$ItemListener = class$("java.awt.event.ItemListener")) : class$java$awt$event$ItemListener)) {
         ItemListener var3 = this.itemListener;
         return AWTEventMulticaster.getListeners(var3, var1);
      } else {
         return super.getListeners(var1);
      }
   }

   boolean eventEnabled(AWTEvent var1) {
      if (var1.id == 701) {
         return (super.eventMask & 512L) != 0L || this.itemListener != null;
      } else {
         return super.eventEnabled(var1);
      }
   }

   protected void processEvent(AWTEvent var1) {
      if (var1 instanceof ItemEvent) {
         this.processItemEvent((ItemEvent)var1);
      } else {
         super.processEvent(var1);
      }
   }

   protected void processItemEvent(ItemEvent var1) {
      if (this.itemListener != null) {
         this.itemListener.itemStateChanged(var1);
      }

   }

   protected String paramString() {
      String var1 = super.paramString();
      String var2 = this.label;
      if (var2 != null) {
         var1 = var1 + ",label=" + var2;
      }

      return var1 + ",state=" + this.state;
   }

   private void writeObject(ObjectOutputStream var1) throws IOException {
      var1.defaultWriteObject();
      AWTEventMulticaster.save(var1, "itemL", this.itemListener);
      var1.writeObject((Object)null);
   }

   private void readObject(ObjectInputStream var1) throws ClassNotFoundException, IOException {
      var1.defaultReadObject();

      Object var2;
      while(null != (var2 = var1.readObject())) {
         String var3 = ((String)var2).intern();
         if ("itemL" == var3) {
            this.addItemListener((ItemListener)var1.readObject());
         } else {
            var1.readObject();
         }
      }

   }

   private static native void initIDs();

   public AccessibleContext getAccessibleContext() {
      if (super.accessibleContext == null) {
         super.accessibleContext = new AccessibleAWTCheckbox(this);
      }

      return super.accessibleContext;
   }

   // $FF: synthetic method
   static Class class$(String var0) {
      try {
         return Class.forName(var0);
      } catch (ClassNotFoundException var2) {
         throw new NoClassDefFoundError(((Throwable)var2).getMessage());
      }
   }

   static {
      Toolkit.loadLibraries();
      initIDs();
      nameCounter = 0;
   }
}
