package java.awt;

import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.event.InputEvent;
import java.awt.event.KeyEvent;
import java.awt.peer.MenuItemPeer;
import java.io.IOException;
import java.io.ObjectInputStream;
import java.io.ObjectOutputStream;
import java.util.EventListener;
import javax.accessibility.Accessible;
import javax.accessibility.AccessibleContext;

public class MenuItem extends MenuComponent implements Accessible {
   boolean enabled;
   String label;
   String actionCommand;
   long eventMask;
   transient ActionListener actionListener;
   private MenuShortcut shortcut;
   private static final String base = "menuitem";
   private static int nameCounter;
   private static final long serialVersionUID = -21757335363267194L;
   private int menuItemSerializedDataVersion;
   // $FF: synthetic field
   static Class class$java$awt$event$ActionListener;

   public MenuItem() {
      this("", (MenuShortcut)null);
   }

   public MenuItem(String var1) {
      this(var1, (MenuShortcut)null);
   }

   public MenuItem(String var1, MenuShortcut var2) {
      this.enabled = true;
      this.shortcut = null;
      this.menuItemSerializedDataVersion = 1;
      this.label = var1;
      this.shortcut = var2;
   }

   String constructComponentName() {
      Class var1 = this.getClass();
      synchronized(var1) {
         String var2 = "menuitem" + nameCounter++;
         return var2;
      }
   }

   public void addNotify() {
      Object var1 = ((MenuComponent)this).getTreeLock();
      synchronized(var1) {
         if (super.peer == null) {
            super.peer = Toolkit.getDefaultToolkit().createMenuItem(this);
         }

      }
   }

   public String getLabel() {
      return this.label;
   }

   public synchronized void setLabel(String var1) {
      this.label = var1;
      MenuItemPeer var2 = (MenuItemPeer)super.peer;
      if (var2 != null) {
         var2.setLabel(var1);
      }

   }

   public boolean isEnabled() {
      return this.enabled;
   }

   public synchronized void setEnabled(boolean var1) {
      this.enable(var1);
   }

   public synchronized void enable() {
      this.enabled = true;
      MenuItemPeer var1 = (MenuItemPeer)super.peer;
      if (var1 != null) {
         var1.enable();
      }

   }

   public void enable(boolean var1) {
      if (var1) {
         this.enable();
      } else {
         this.disable();
      }

   }

   public synchronized void disable() {
      this.enabled = false;
      MenuItemPeer var1 = (MenuItemPeer)super.peer;
      if (var1 != null) {
         var1.disable();
      }

   }

   public MenuShortcut getShortcut() {
      return this.shortcut;
   }

   public void setShortcut(MenuShortcut var1) {
      this.shortcut = var1;
      MenuItemPeer var2 = (MenuItemPeer)super.peer;
      if (var2 != null) {
         var2.setLabel(this.label);
      }

   }

   public void deleteShortcut() {
      this.shortcut = null;
      MenuItemPeer var1 = (MenuItemPeer)super.peer;
      if (var1 != null) {
         var1.setLabel(this.label);
      }

   }

   void deleteShortcut(MenuShortcut var1) {
      if (var1.equals(this.shortcut)) {
         this.shortcut = null;
         MenuItemPeer var2 = (MenuItemPeer)super.peer;
         if (var2 != null) {
            var2.setLabel(this.label);
         }
      }

   }

   void doMenuEvent() {
      Toolkit.getEventQueue().postEvent(new ActionEvent(this, 1001, this.getActionCommand()));
   }

   boolean handleShortcut(KeyEvent var1) {
      MenuShortcut var2 = new MenuShortcut(var1.getKeyCode(), (((InputEvent)var1).getModifiers() & 1) > 0);
      if (var2.equals(this.shortcut) && this.enabled) {
         if (((AWTEvent)var1).getID() == 401) {
            this.doMenuEvent();
         }

         return true;
      } else {
         return false;
      }
   }

   MenuItem getShortcutMenuItem(MenuShortcut var1) {
      return var1.equals(this.shortcut) ? this : null;
   }

   protected final void enableEvents(long var1) {
      this.eventMask |= var1;
      super.newEventsOnly = true;
   }

   protected final void disableEvents(long var1) {
      this.eventMask &= ~var1;
   }

   public void setActionCommand(String var1) {
      this.actionCommand = var1;
   }

   public String getActionCommand() {
      return this.actionCommand == null ? this.label : this.actionCommand;
   }

   public synchronized void addActionListener(ActionListener var1) {
      if (var1 != null) {
         this.actionListener = AWTEventMulticaster.add(this.actionListener, var1);
         super.newEventsOnly = true;
      }
   }

   public synchronized void removeActionListener(ActionListener var1) {
      if (var1 != null) {
         this.actionListener = AWTEventMulticaster.remove(this.actionListener, var1);
      }
   }

   public EventListener[] getListeners(Class var1) {
      ActionListener var2 = null;
      if (var1 == (class$java$awt$event$ActionListener == null ? (class$java$awt$event$ActionListener = class$("java.awt.event.ActionListener")) : class$java$awt$event$ActionListener)) {
         var2 = this.actionListener;
      }

      return AWTEventMulticaster.getListeners(var2, var1);
   }

   protected void processEvent(AWTEvent var1) {
      if (var1 instanceof ActionEvent) {
         this.processActionEvent((ActionEvent)var1);
      }

   }

   boolean eventEnabled(AWTEvent var1) {
      if (var1.id == 1001) {
         return (this.eventMask & 128L) != 0L || this.actionListener != null;
      } else {
         return super.eventEnabled(var1);
      }
   }

   protected void processActionEvent(ActionEvent var1) {
      if (this.actionListener != null) {
         this.actionListener.actionPerformed(var1);
      }

   }

   public String paramString() {
      String var1 = ",label=" + this.label;
      if (this.shortcut != null) {
         var1 = var1 + ",shortcut=" + this.shortcut;
      }

      return super.paramString() + var1;
   }

   private void writeObject(ObjectOutputStream var1) throws IOException {
      var1.defaultWriteObject();
      AWTEventMulticaster.save(var1, "actionL", this.actionListener);
      var1.writeObject((Object)null);
   }

   private void readObject(ObjectInputStream var1) throws ClassNotFoundException, IOException {
      var1.defaultReadObject();

      Object var2;
      while(null != (var2 = var1.readObject())) {
         String var3 = ((String)var2).intern();
         if ("actionL" == var3) {
            this.addActionListener((ActionListener)var1.readObject());
         } else {
            var1.readObject();
         }
      }

   }

   private static native void initIDs();

   public AccessibleContext getAccessibleContext() {
      if (super.accessibleContext == null) {
         super.accessibleContext = new AccessibleAWTMenuItem(this);
      }

      return super.accessibleContext;
   }

   // $FF: synthetic method
   static Class class$(String var0) {
      try {
         return Class.forName(var0);
      } catch (ClassNotFoundException var2) {
         throw new NoClassDefFoundError(((Throwable)var2).getMessage());
      }
   }

   static {
      Toolkit.loadLibraries();
      initIDs();
      nameCounter = 0;
   }
}
