package java.awt;

import java.awt.event.TextEvent;
import java.awt.event.TextListener;
import java.awt.peer.TextComponentPeer;
import java.io.IOException;
import java.io.ObjectInputStream;
import java.io.ObjectOutputStream;
import java.util.EventListener;
import javax.accessibility.Accessible;
import javax.accessibility.AccessibleContext;
import sun.awt.SunToolkit;

public class TextComponent extends Component implements Accessible {
   String text;
   boolean editable = true;
   int selectionStart;
   int selectionEnd;
   private transient boolean canAccessClipboard;
   protected transient TextListener textListener;
   private static final long serialVersionUID = -2214773872412987419L;
   private int textComponentSerializedDataVersion = 1;
   // $FF: synthetic field
   static Class class$java$awt$event$TextListener;

   TextComponent(String var1) {
      this.text = var1 != null ? var1 : "";
      ((Component)this).setCursor(Cursor.getPredefinedCursor(2));
      this.enableInputMethodsIfNecessary();
      this.checkSystemClipboardAccess();
   }

   private void enableInputMethodsIfNecessary() {
      try {
         Toolkit var1 = Toolkit.getDefaultToolkit();
         ((Component)this).enableInputMethods(((SunToolkit)var1).enableInputMethodsForTextComponent());
      } catch (Exception var2) {
      }

   }

   boolean areInputMethodsEnabled() {
      return (super.eventMask & 4096L) != 0L;
   }

   public void removeNotify() {
      Object var1 = ((Component)this).getTreeLock();
      synchronized(var1) {
         TextComponentPeer var2 = (TextComponentPeer)super.peer;
         if (var2 != null) {
            this.text = var2.getText();
            this.selectionStart = var2.getSelectionStart();
            this.selectionEnd = var2.getSelectionEnd();
         }

         super.removeNotify();
      }
   }

   public synchronized void setText(String var1) {
      this.text = var1 != null ? var1 : "";
      TextComponentPeer var2 = (TextComponentPeer)super.peer;
      if (var2 != null) {
         var2.setText(this.text);
      }

   }

   public synchronized String getText() {
      TextComponentPeer var1 = (TextComponentPeer)super.peer;
      if (var1 != null) {
         this.text = var1.getText();
      }

      return this.text;
   }

   public synchronized String getSelectedText() {
      return this.getText().substring(this.getSelectionStart(), this.getSelectionEnd());
   }

   public boolean isEditable() {
      return this.editable;
   }

   public synchronized void setEditable(boolean var1) {
      if (this.editable != var1) {
         this.editable = var1;
         TextComponentPeer var2 = (TextComponentPeer)super.peer;
         if (var2 != null) {
            var2.setEditable(var1);
         }

      }
   }

   public Color getBackground() {
      return (Color)(!this.editable ? SystemColor.control : super.getBackground());
   }

   public void setBackground(Color var1) {
      if (!this.editable) {
         super.background = var1;
      } else {
         super.setBackground(var1);
      }
   }

   public synchronized int getSelectionStart() {
      TextComponentPeer var1 = (TextComponentPeer)super.peer;
      if (var1 != null) {
         this.selectionStart = var1.getSelectionStart();
      }

      return this.selectionStart;
   }

   public synchronized void setSelectionStart(int var1) {
      this.select(var1, this.getSelectionEnd());
   }

   public synchronized int getSelectionEnd() {
      TextComponentPeer var1 = (TextComponentPeer)super.peer;
      if (var1 != null) {
         this.selectionEnd = var1.getSelectionEnd();
      }

      return this.selectionEnd;
   }

   public synchronized void setSelectionEnd(int var1) {
      this.select(this.getSelectionStart(), var1);
   }

   public synchronized void select(int var1, int var2) {
      String var3 = this.getText();
      if (var1 < 0) {
         var1 = 0;
      }

      if (var1 > var3.length()) {
         var1 = var3.length();
      }

      if (var2 > var3.length()) {
         var2 = var3.length();
      }

      if (var2 < var1) {
         var2 = var1;
      }

      this.selectionStart = var1;
      this.selectionEnd = var2;
      TextComponentPeer var4 = (TextComponentPeer)super.peer;
      if (var4 != null) {
         var4.select(var1, var2);
      }

   }

   public synchronized void selectAll() {
      String var1 = this.getText();
      this.selectionStart = 0;
      this.selectionEnd = this.getText().length();
      TextComponentPeer var2 = (TextComponentPeer)super.peer;
      if (var2 != null) {
         var2.select(this.selectionStart, this.selectionEnd);
      }

   }

   public synchronized void setCaretPosition(int var1) {
      if (var1 < 0) {
         throw new IllegalArgumentException("position less than zero.");
      } else {
         int var2 = this.getText().length();
         if (var1 > var2) {
            var1 = var2;
         }

         TextComponentPeer var3 = (TextComponentPeer)super.peer;
         if (var3 != null) {
            var3.setCaretPosition(var1);
         } else {
            throw new IllegalComponentStateException("Cannot set caret position until after the peer has been created");
         }
      }
   }

   public synchronized int getCaretPosition() {
      TextComponentPeer var1 = (TextComponentPeer)super.peer;
      int var2 = 0;
      if (var1 != null) {
         var2 = var1.getCaretPosition();
      }

      return var2;
   }

   public synchronized void addTextListener(TextListener var1) {
      if (var1 != null) {
         this.textListener = AWTEventMulticaster.add(this.textListener, var1);
         super.newEventsOnly = true;
      }
   }

   public synchronized void removeTextListener(TextListener var1) {
      if (var1 != null) {
         this.textListener = AWTEventMulticaster.remove(this.textListener, var1);
      }
   }

   public EventListener[] getListeners(Class var1) {
      Object var2 = null;
      if (var1 == (class$java$awt$event$TextListener == null ? (class$java$awt$event$TextListener = class$("java.awt.event.TextListener")) : class$java$awt$event$TextListener)) {
         TextListener var3 = this.textListener;
         return AWTEventMulticaster.getListeners(var3, var1);
      } else {
         return super.getListeners(var1);
      }
   }

   boolean eventEnabled(AWTEvent var1) {
      if (var1.id == 900) {
         return (super.eventMask & 1024L) != 0L || this.textListener != null;
      } else {
         return super.eventEnabled(var1);
      }
   }

   protected void processEvent(AWTEvent var1) {
      if (var1 instanceof TextEvent) {
         this.processTextEvent((TextEvent)var1);
      } else {
         super.processEvent(var1);
      }
   }

   protected void processTextEvent(TextEvent var1) {
      if (this.textListener != null) {
         int var2 = ((AWTEvent)var1).getID();
         switch (var2) {
            case 900:
               this.textListener.textValueChanged(var1);
         }
      }

   }

   protected String paramString() {
      String var1 = super.paramString() + ",text=" + this.getText();
      if (this.editable) {
         var1 = var1 + ",editable";
      }

      return var1 + ",selection=" + this.getSelectionStart() + "-" + this.getSelectionEnd();
   }

   private void checkSystemClipboardAccess() {
      this.canAccessClipboard = true;
      SecurityManager var1 = System.getSecurityManager();
      if (var1 != null) {
         try {
            var1.checkSystemClipboardAccess();
         } catch (SecurityException var3) {
            this.canAccessClipboard = false;
         }
      }

   }

   private void writeObject(ObjectOutputStream var1) throws IOException {
      TextComponentPeer var2 = (TextComponentPeer)super.peer;
      if (var2 != null) {
         this.text = var2.getText();
         this.selectionStart = var2.getSelectionStart();
         this.selectionEnd = var2.getSelectionEnd();
      }

      var1.defaultWriteObject();
      AWTEventMulticaster.save(var1, "textL", this.textListener);
      var1.writeObject((Object)null);
   }

   private void readObject(ObjectInputStream var1) throws ClassNotFoundException, IOException {
      var1.defaultReadObject();
      this.text = this.text != null ? this.text : "";
      this.select(this.selectionStart, this.selectionEnd);

      Object var2;
      while(null != (var2 = var1.readObject())) {
         String var3 = ((String)var2).intern();
         if ("textL" == var3) {
            this.addTextListener((TextListener)var1.readObject());
         } else {
            var1.readObject();
         }
      }

      this.enableInputMethodsIfNecessary();
      this.checkSystemClipboardAccess();
   }

   int getIndexAtPoint(Point var1) {
      return -1;
   }

   Rectangle getCharacterBounds(int var1) {
      return null;
   }

   public AccessibleContext getAccessibleContext() {
      if (super.accessibleContext == null) {
         super.accessibleContext = new AccessibleAWTTextComponent(this);
      }

      return super.accessibleContext;
   }

   // $FF: synthetic method
   static Class class$(String var0) {
      try {
         return Class.forName(var0);
      } catch (ClassNotFoundException var2) {
         throw new NoClassDefFoundError(((Throwable)var2).getMessage());
      }
   }
}
