package java.awt;

import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.peer.TextFieldPeer;
import java.io.IOException;
import java.io.ObjectInputStream;
import java.io.ObjectOutputStream;
import java.util.EventListener;
import javax.accessibility.AccessibleContext;

public class TextField extends TextComponent {
   int columns;
   char echoChar;
   transient ActionListener actionListener;
   private static final String base = "textfield";
   private static int nameCounter = 0;
   private static final long serialVersionUID = -2966288784432217853L;
   private int textFieldSerializedDataVersion;
   // $FF: synthetic field
   static Class class$java$awt$event$ActionListener;

   private static native void initIDs();

   public TextField() {
      this("", 0);
   }

   public TextField(String var1) {
      this(var1, var1 != null ? var1.length() : 0);
   }

   public TextField(int var1) {
      this("", var1);
   }

   public TextField(String var1, int var2) {
      super(var1);
      this.textFieldSerializedDataVersion = 1;
      this.columns = var2 >= 0 ? var2 : 0;
   }

   String constructComponentName() {
      Class var1 = this.getClass();
      synchronized(var1) {
         String var2 = "textfield" + nameCounter++;
         return var2;
      }
   }

   public void addNotify() {
      Object var1 = ((Component)this).getTreeLock();
      synchronized(var1) {
         if (super.peer == null) {
            super.peer = ((Component)this).getToolkit().createTextField(this);
         }

         super.addNotify();
      }
   }

   public char getEchoChar() {
      return this.echoChar;
   }

   public void setEchoChar(char var1) {
      this.setEchoCharacter(var1);
   }

   public synchronized void setEchoCharacter(char var1) {
      this.echoChar = var1;
      TextFieldPeer var2 = (TextFieldPeer)super.peer;
      if (var2 != null) {
         var2.setEchoCharacter(var1);
      }

   }

   public void setText(String var1) {
      super.setText(var1);
      if (super.valid) {
         ((Component)this).invalidate();
      }

   }

   public boolean echoCharIsSet() {
      return this.echoChar != 0;
   }

   public int getColumns() {
      return this.columns;
   }

   public synchronized void setColumns(int var1) {
      int var2 = this.columns;
      if (var1 < 0) {
         throw new IllegalArgumentException("columns less than zero.");
      } else {
         if (var1 != var2) {
            this.columns = var1;
            ((Component)this).invalidate();
         }

      }
   }

   public Dimension getPreferredSize(int var1) {
      return this.preferredSize(var1);
   }

   public Dimension preferredSize(int var1) {
      Object var2 = ((Component)this).getTreeLock();
      synchronized(var2) {
         TextFieldPeer var3 = (TextFieldPeer)super.peer;
         Dimension var4 = var3 != null ? var3.preferredSize(var1) : super.preferredSize();
         return var4;
      }
   }

   public Dimension getPreferredSize() {
      return this.preferredSize();
   }

   public Dimension preferredSize() {
      Object var1 = ((Component)this).getTreeLock();
      synchronized(var1) {
         Dimension var2 = this.columns > 0 ? this.preferredSize(this.columns) : super.preferredSize();
         return var2;
      }
   }

   public Dimension getMinimumSize(int var1) {
      return this.minimumSize(var1);
   }

   public Dimension minimumSize(int var1) {
      Object var2 = ((Component)this).getTreeLock();
      synchronized(var2) {
         TextFieldPeer var3 = (TextFieldPeer)super.peer;
         Dimension var4 = var3 != null ? var3.minimumSize(var1) : super.minimumSize();
         return var4;
      }
   }

   public Dimension getMinimumSize() {
      return this.minimumSize();
   }

   public Dimension minimumSize() {
      Object var1 = ((Component)this).getTreeLock();
      synchronized(var1) {
         Dimension var2 = this.columns > 0 ? this.minimumSize(this.columns) : super.minimumSize();
         return var2;
      }
   }

   public synchronized void addActionListener(ActionListener var1) {
      if (var1 != null) {
         this.actionListener = AWTEventMulticaster.add(this.actionListener, var1);
         super.newEventsOnly = true;
      }
   }

   public synchronized void removeActionListener(ActionListener var1) {
      if (var1 != null) {
         this.actionListener = AWTEventMulticaster.remove(this.actionListener, var1);
      }
   }

   public EventListener[] getListeners(Class var1) {
      Object var2 = null;
      if (var1 == (class$java$awt$event$ActionListener == null ? (class$java$awt$event$ActionListener = class$("java.awt.event.ActionListener")) : class$java$awt$event$ActionListener)) {
         ActionListener var3 = this.actionListener;
         return AWTEventMulticaster.getListeners(var3, var1);
      } else {
         return super.getListeners(var1);
      }
   }

   boolean eventEnabled(AWTEvent var1) {
      if (var1.id == 1001) {
         return (super.eventMask & 128L) != 0L || this.actionListener != null;
      } else {
         return super.eventEnabled(var1);
      }
   }

   protected void processEvent(AWTEvent var1) {
      if (var1 instanceof ActionEvent) {
         this.processActionEvent((ActionEvent)var1);
      } else {
         super.processEvent(var1);
      }
   }

   protected void processActionEvent(ActionEvent var1) {
      if (this.actionListener != null) {
         this.actionListener.actionPerformed(var1);
      }

   }

   protected String paramString() {
      String var1 = super.paramString();
      if (this.echoChar != 0) {
         var1 = var1 + ",echo=" + this.echoChar;
      }

      return var1;
   }

   private void writeObject(ObjectOutputStream var1) throws IOException {
      var1.defaultWriteObject();
      AWTEventMulticaster.save(var1, "actionL", this.actionListener);
      var1.writeObject((Object)null);
   }

   private void readObject(ObjectInputStream var1) throws ClassNotFoundException, IOException {
      var1.defaultReadObject();
      if (this.columns < 0) {
         this.columns = 0;
      }

      Object var2;
      while(null != (var2 = var1.readObject())) {
         String var3 = ((String)var2).intern();
         if ("actionL" == var3) {
            this.addActionListener((ActionListener)var1.readObject());
         } else {
            var1.readObject();
         }
      }

   }

   public AccessibleContext getAccessibleContext() {
      if (super.accessibleContext == null) {
         super.accessibleContext = new AccessibleAWTTextField(this);
      }

      return super.accessibleContext;
   }

   // $FF: synthetic method
   static Class class$(String var0) {
      try {
         return Class.forName(var0);
      } catch (ClassNotFoundException var2) {
         throw new NoClassDefFoundError(((Throwable)var2).getMessage());
      }
   }

   static {
      Toolkit.loadLibraries();
      initIDs();
   }
}
