package java.awt.dnd;

import java.awt.Component;
import java.awt.Cursor;
import java.awt.Image;
import java.awt.Point;
import java.awt.Toolkit;
import java.awt.datatransfer.FlavorMap;
import java.awt.datatransfer.SystemFlavorMap;
import java.awt.datatransfer.Transferable;
import java.awt.dnd.peer.DragSourceContextPeer;

public class DragSource {
   public static final Cursor DefaultCopyDrop = load("DnD.Cursor.CopyDrop");
   public static final Cursor DefaultMoveDrop = load("DnD.Cursor.MoveDrop");
   public static final Cursor DefaultLinkDrop = load("DnD.Cursor.LinkDrop");
   public static final Cursor DefaultCopyNoDrop = load("DnD.Cursor.CopyNoDrop");
   public static final Cursor DefaultMoveNoDrop = load("DnD.Cursor.MoveNoDrop");
   public static final Cursor DefaultLinkNoDrop = load("DnD.Cursor.LinkNoDrop");
   private static final FlavorMap defaultFlavorMap = SystemFlavorMap.getDefaultFlavorMap();
   private static DragSource dflt;
   private transient FlavorMap flavorMap;
   // $FF: synthetic field
   static Class class$java$awt$dnd$MouseDragGestureRecognizer;

   private static Cursor load(String var0) {
      try {
         return (Cursor)Toolkit.getDefaultToolkit().getDesktopProperty(var0);
      } catch (Exception var2) {
         ((Throwable)var2).printStackTrace();
         throw new RuntimeException("failed to load system cursor: " + var0 + " : " + ((Throwable)var2).getMessage());
      }
   }

   public static DragSource getDefaultDragSource() {
      if (dflt == null) {
         dflt = new DragSource();
      }

      return dflt;
   }

   public static boolean isDragImageSupported() {
      Toolkit var0 = Toolkit.getDefaultToolkit();

      try {
         Boolean var1 = (Boolean)Toolkit.getDefaultToolkit().getDesktopProperty("DnD.isDragImageSupported");
         return var1;
      } catch (Exception var3) {
         return false;
      }
   }

   public DragSource() {
      this.flavorMap = defaultFlavorMap;
   }

   public void startDrag(DragGestureEvent var1, Cursor var2, Image var3, Point var4, Transferable var5, DragSourceListener var6, FlavorMap var7) throws InvalidDnDOperationException {
      if (var7 != null) {
         this.flavorMap = var7;
      }

      DragSourceContextPeer var8 = Toolkit.getDefaultToolkit().createDragSourceContextPeer(var1);
      DragSourceContext var9 = this.createDragSourceContext(var8, var1, var2, var3, var4, var5, var6);
      if (var9 == null) {
         throw new InvalidDnDOperationException();
      } else {
         var8.startDrag(var9, var9.getCursor(), var3, var4);
      }
   }

   public void startDrag(DragGestureEvent var1, Cursor var2, Transferable var3, DragSourceListener var4, FlavorMap var5) throws InvalidDnDOperationException {
      this.startDrag(var1, var2, (Image)null, (Point)null, var3, var4, var5);
   }

   public void startDrag(DragGestureEvent var1, Cursor var2, Image var3, Point var4, Transferable var5, DragSourceListener var6) throws InvalidDnDOperationException {
      this.startDrag(var1, var2, var3, var4, var5, var6, (FlavorMap)null);
   }

   public void startDrag(DragGestureEvent var1, Cursor var2, Transferable var3, DragSourceListener var4) throws InvalidDnDOperationException {
      this.startDrag(var1, var2, (Image)null, (Point)null, var3, var4, (FlavorMap)null);
   }

   protected DragSourceContext createDragSourceContext(DragSourceContextPeer var1, DragGestureEvent var2, Cursor var3, Image var4, Point var5, Transferable var6, DragSourceListener var7) {
      return new DragSourceContext(var1, var2, var3, var4, var5, var6, var7);
   }

   public FlavorMap getFlavorMap() {
      return this.flavorMap;
   }

   public DragGestureRecognizer createDragGestureRecognizer(Class var1, Component var2, int var3, DragGestureListener var4) {
      return Toolkit.getDefaultToolkit().createDragGestureRecognizer(var1, this, var2, var3, var4);
   }

   public DragGestureRecognizer createDefaultDragGestureRecognizer(Component var1, int var2, DragGestureListener var3) {
      return Toolkit.getDefaultToolkit().createDragGestureRecognizer(class$java$awt$dnd$MouseDragGestureRecognizer == null ? (class$java$awt$dnd$MouseDragGestureRecognizer = class$("java.awt.dnd.MouseDragGestureRecognizer")) : class$java$awt$dnd$MouseDragGestureRecognizer, this, var1, var2, var3);
   }

   // $FF: synthetic method
   static Class class$(String var0) {
      try {
         return Class.forName(var0);
      } catch (ClassNotFoundException var2) {
         throw new NoClassDefFoundError(((Throwable)var2).getMessage());
      }
   }
}
