package java.awt.event;

import java.awt.AWTEvent;
import java.awt.Component;
import java.awt.font.TextHitInfo;
import java.text.AttributedCharacterIterator;

public class InputMethodEvent extends AWTEvent {
   public static final int INPUT_METHOD_FIRST = 1100;
   public static final int INPUT_METHOD_TEXT_CHANGED = 1100;
   public static final int CARET_POSITION_CHANGED = 1101;
   public static final int INPUT_METHOD_LAST = 1101;
   private transient AttributedCharacterIterator text;
   private transient int committedCharacterCount;
   private transient TextHitInfo caret;
   private transient TextHitInfo visiblePosition;

   public InputMethodEvent(Component var1, int var2, AttributedCharacterIterator var3, int var4, TextHitInfo var5, TextHitInfo var6) {
      super(var1, var2);
      if (var2 >= 1100 && var2 <= 1101) {
         if (var2 == 1101 && var3 != null) {
            throw new IllegalArgumentException("text must be null for CARET_POSITION_CHANGED");
         } else {
            this.text = var3;
            int var7 = 0;
            if (var3 != null) {
               var7 = var3.getEndIndex() - var3.getBeginIndex();
            }

            if (var4 >= 0 && var4 <= var7) {
               this.committedCharacterCount = var4;
               this.caret = var5;
               this.visiblePosition = var6;
            } else {
               throw new IllegalArgumentException("committedCharacterCount outside of valid range");
            }
         }
      } else {
         throw new IllegalArgumentException("id outside of valid range");
      }
   }

   public InputMethodEvent(Component var1, int var2, TextHitInfo var3, TextHitInfo var4) {
      this(var1, var2, (AttributedCharacterIterator)null, 0, var3, var4);
   }

   public AttributedCharacterIterator getText() {
      return this.text;
   }

   public int getCommittedCharacterCount() {
      return this.committedCharacterCount;
   }

   public TextHitInfo getCaret() {
      return this.caret;
   }

   public TextHitInfo getVisiblePosition() {
      return this.visiblePosition;
   }

   public void consume() {
      super.consumed = true;
   }

   public boolean isConsumed() {
      return super.consumed;
   }

   public String paramString() {
      String var1;
      switch (super.id) {
         case 1100:
            var1 = "INPUT_METHOD_TEXT_CHANGED";
            break;
         case 1101:
            var1 = "CARET_POSITION_CHANGED";
            break;
         default:
            var1 = "unknown type";
      }

      String var2;
      if (this.text == null) {
         var2 = "no text";
      } else {
         StringBuffer var3 = new StringBuffer("\"");
         int var4 = this.committedCharacterCount;

         char var5;
         for(var5 = this.text.first(); var4-- > 0; var5 = this.text.next()) {
            var3.append(var5);
         }

         var3.append("\" + \"");

         while(var5 != '\uffff') {
            var3.append(var5);
            var5 = this.text.next();
         }

         var3.append("\"");
         var2 = var3.toString();
      }

      String var6 = this.committedCharacterCount + " characters committed";
      String var7;
      if (this.caret == null) {
         var7 = "no caret";
      } else {
         var7 = "caret: " + this.caret.toString();
      }

      String var8;
      if (this.visiblePosition == null) {
         var8 = "no visible position";
      } else {
         var8 = "visible position: " + this.visiblePosition.toString();
      }

      return var1 + ", " + var2 + ", " + var6 + ", " + var7 + ", " + var8;
   }
}
